const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# един хеш за главната позиция",
    "## two hashes for second heading": "два хеша за втората таблица",
    "### three hashes for third heading": "# # # Три хеша за трета позиция",
    "**double star for bold**": "двойна звезда за удебеление",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "относно",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Добавете слой",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Add a new property",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Add image URL": "Add image URL",
    "Add": "Add",
    "Advanced actions": "Разширено действия",
    "Advanced properties": "Разширени свойства",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Всички свойства са внесени.",
    "Allow interactions": "Allow interactions",
    "Allow scroll wheel zoom?": "Мащабиране с колелцето на мишката?",
    "always": "винаги",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to cancel your changes?": "Наистина ли искате да отмените вашите промени?",
    "Are you sure you want to clone this map and all its datalayers?": "Наистина ли искате да клонирате тази карта и всички негови слоеве данни ?",
    "Are you sure you want to delete the feature?": "Сигурни ли сте, че искате да изтриете тази функция?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Сигурни ли сте, че искате да изтриете тази карта?",
    "Are you sure you want to delete this property on all the features?": "Are you sure you want to delete this property on all the features?",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Attach the map to my account",
    "attribution": "приписване",
    "Auto": "Auto",
    "Automatic": "Автоматично",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "топка",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Преглед данни",
    "by": "чрез",
    "Cache proxied request": "Cache proxied request",
    "Cancel edits": "Отмени редакциите",
    "Caption": "Надпис",
    "Center map on your location": "Center map on your location",
    "Change map background": "Промяна фона на картата",
    "Change tilelayers": "Променете слоевете",
    "Change": "Change",
    "Choose the data format": "Изберете формата на данните",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "окръжност",
    "clear": "изчисти",
    "Click last point to finish shape": "Click last point to finish shape",
    "Click to add a marker": "Click to add a marker",
    "Click to continue drawing": "Click to continue drawing",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Click to start drawing a line",
    "Click to start drawing a polygon": "Click to start drawing a polygon",
    "Clone of {name}": "Клонинг на {име}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "клонира тази карта",
    "Clone": "Клонинг",
    "Close": "Close",
    "Clustered": "Клъстер",
    "Clustering radius": "радиус на клъстери",
    "collapsed": "collapsed",
    "color": "цвят",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Continue line",
    "Coordinates": "Координати",
    "copy": "copy",
    "Credits": "приемам като достоверен",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Текущ изглед, вместо по подразбиране вижте карта?",
    "Custom background": "Потребителски фон",
    "Custom overlay": "Custom overlay",
    "dash array": "dash array",
    "Data is browsable": "Data is browsable",
    "Datalayers": "Datalayers",
    "Default interaction options": "Интерактивни функции по подразбиране",
    "Default properties": "По подразбиране свойства",
    "Default shape properties": "Default shape properties",
    "Default view": "Default view",
    "Default zoom level": "Default zoom level",
    "Default": "по подразбиране",
    "Default: name": "Default: name",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "define": "define",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete layer": "Delete layer",
    "Delete this feature": "Изтриване на тази функция",
    "Delete this shape": "Delete this shape",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Delete": "Изтрий",
    "description": "описание",
    "Direct link": "Direct link",
    "Directions from here": "Упътвания от тук",
    "Display label": "Показване на етикет",
    "Display measure": "Display measure",
    "display name": "показвано име",
    "Display on load": "Дисплей на зареждане",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Показване управлението за цял екран",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Показване на търсене",
    "Display the star map button": "Display the star map button",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Искате ли да се покаже надпис бар?",
    "Do you want to display a minimap?": "Искате ли да се покаже миникартата?",
    "Do you want to display a panel on load?": "Искате ли да се покаже панел на зареждане?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Искате ли да се покаже изскачащ колонтитул?",
    "Do you want to display the scale control?": "Искате ли да се показва мащаб контрола?",
    "Do you want to display the «more» control?": "Do you want to display the «more» control?",
    "Download": "Download",
    "Drag to reorder": "Drag to reorder",
    "Draw a marker": "Начертайте маркер",
    "Draw a polygon": "Начертайте полигон",
    "Draw a polyline": "Начертайте полилиния",
    "Drawing": "Drawing",
    "Drop": "маркер",
    "Dynamic properties": "Dynamic properties",
    "Dynamic": "динамичен",
    "Edit feature's layer": "Редактиране функцията на слоя",
    "Edit properties in a table": "Edit properties in a table",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Редактирайте тази характеристика",
    "Edit": "Редактиране",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Вграждане на карта",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Празно",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Грешка в URL адреса на слоя",
    "Exit Fullscreen": "Exit Fullscreen",
    "expanded": "expanded",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "fill color": "попълнете цвят",
    "fill opacity": "попълнете непрозрачност",
    "fill": "запълни",
    "Fit all data": "Fit all data",
    "Format": "формат",
    "From zoom": "От мащабиране",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (само за връзка)",
    "GeoRSS (title + image)": "GeoRSS (заглавие + изображение)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Go to «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "радиус на Топлинна карта",
    "Heatmap": "Топлинна карта",
    "height": "височина",
    "Help": "Помощ",
    "hidden": "hidden",
    "Hide controls": "Скрий контролите",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Колко да опрости полилинията на всяко ниво увеличение (повече = по-добра производителност и по-гладко на вид, по-малко = по-точно)",
    "icon opacity": "icon opacity",
    "Icon shape": "Форма на иконата",
    "Icon symbol": "Символ на иконата",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Изображение с поръчкова ширина (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "изображение: {{http://image.url.com}}",
    "Import data": "Внасям данни",
    "Import in a new layer": "Import in a new layer",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Включи пълна връзка на екрана?",
    "Inherit": "Наследи",
    "inherit": "наследи",
    "Interaction options": "Интерактивни функции",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Invalid umap data": "Invalid umap data",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Keep current visible layers",
    "kilometers": "kilometers",
    "km": "km",
    "Label direction": "Посока на текста на етикета",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "Latest feature": "Latest feature",
    "Latitude": "Latitude",
    "Layer properties": "Layer properties",
    "Layer": "Layer",
    "Licence": "Лиценз",
    "licence": "лиценз",
    "Limit bounds": "Limit bounds",
    "Link to view the map": "Link to view the map",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Връзка с текст: [[http://example.com|текст на връзката]]",
    "Long credits": "Long credits",
    "Longitude": "Longitude",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Manual": "Manual",
    "Map background credits": "Map background credits",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Map has been saved!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "Map user content has been published under licence",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "max East": "максимум Източен",
    "max North": "максимум Северен",
    "max South": "максимум Южен",
    "max West": "максимум Западна",
    "max zoom": "максимум мащабиране",
    "Measure distances": "Measure distances",
    "Merge lines": "Merge lines",
    "mi": "mi",
    "miles": "miles",
    "min zoom": "минимално мащабиране",
    "More controls": "Още контроли",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "name": "име",
    "nautical miles": "nautical miles",
    "never": "никога",
    "new window": "new window",
    "next": "next",
    "NM": "NM",
    "No cache": "No cache",
    "No licence has been set": "No licence has been set",
    "No results": "No results",
    "no": "не",
    "No.": "No.",
    "None": "Нищо",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "Отдолу",
    "On the left": "Вляво",
    "On the right": "Вдясно",
    "On the top": "Отгоре",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "непрозрачност",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Open link in…",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Отворете тази карта в степен редактор на карта, за да предостави по-точни данни,OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "По избор Същото като цвят, ако не е настроена.",
    "Optional.": "Optional.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "parent window": "родителски прозорец",
    "Paste your data here": "Paste your data here",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Моля, бъдете сигурни, че лицензът е съвместим с вашата употреба.",
    "Please choose a format": "Please choose a format",
    "Please enter the name of the property": "Please enter the name of the property",
    "Please enter the new name of this property": "Please enter the new name of this property",
    "Please save the map first": "Please save the map first",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup content template": "Popup content template",
    "Popup shape": "Popup shape",
    "Popup": "Popup",
    "Powered by uMap": "Powered by uMap",
    "previous": "previous",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Внесени свойства:",
    "Provide an URL here": "Представете URL тук",
    "Proxy request": "Proxy request",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "отдалечена база данни",
    "Remove shape from the multi": "Remove shape from the multi",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save current edits": "Запиши текущите редакции",
    "Save map": "Save map",
    "Save this center and zoom": "Запази този център и размер",
    "Save this location as new feature": "Save this location as new feature",
    "Save": "запазвам",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Search location",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Виж на цял екран",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "settings": "settings",
    "Shape properties": "Shape properties",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Short credits",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Покажи / скрий слой",
    "Side panel": "Страничен панел",
    "Simple link: [[http://example.com]]": "проста връзка:[[http://example.com]]",
    "Simplify": "Опрости",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Slideshow": "Slideshow",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Star this map": "Star this map",
    "Start a hole here": "Start a hole here",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Спри редактирането",
    "Stop slideshow": "Stop slideshow",
    "Street": "Street",
    "stroke": "stroke",
    "Supported scheme": "Поддържана схема",
    "Supported variables that will be dynamically replaced": "Поддържаните променливи, които ще бъдат динамично заменени",
    "Symbol": "Symbol",
    "Table": "Table",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "форматиране на текст",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "TMS формат",
    "To use if remote server doesn't allow cross domain (slower)": "За да се използва, ако отдалечен сървър не позволява кръстосан домейн (по-бавно)",
    "To zoom": "За да увеличите",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Трансформация на линии",
    "Transform to polygon": "Трансформация на полигон",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Вид на слой",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Неозаглавен слой",
    "Untitled map": "Неозаглавена карта",
    "Update permissions and editors": "Актуализиране на разрешения и редактори",
    "Update permissions": "Update permissions",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "URL адрес",
    "URL": "URL",
    "Use current bounds": "Use current bounds",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "User content credits",
    "User interface options": "Опции на потребителския интерфейс",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "тегло",
    "Where do we go from here?": "Къде да отидем от тук?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "width": "широчина",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "yes": "да",
    "Zoom in": "Zoom in",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "Намаляване на мащаба",
    "Zoom to layer extent": "Zoom to layer extent",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Увеличаване на тази характеристика",
    "Zoom to this place": "Zoom to this place",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "{delay} seconds": "{забавяне} сек.",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Import helpers:": "Import helpers:",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "My Dashboard ({username})": "My Dashboard ({username})",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control"
}
L.registerLocale("bg", locale)
L.setLocale("bg")
