{% extends "base.html" %}

{% load umap_tags i18n %}

{% block head_title %}
  {{ map.name }} - {{ SITE_NAME }}
{% endblock head_title %}
{% block body_class %}
  map_detail
{% endblock body_class %}
{% block extra_head %}
  {% if preconnect_domains %}
    {% for domain in preconnect_domains %}
      <link rel="preconnect" href="{{ domain }}" />
    {% endfor %}
  {% endif %}
  {% umap_css %}
  {{ block.super }}
  {% umap_js locale=locale %}
  {% if UMAP_DEMO_SITE or object.share_status != object.PUBLIC %}
    <meta name="robots" content="noindex,nofollow">
  {% endif %}
  <link rel="alternate"
        type="application/json+oembed"
        href="{{ oembed_absolute_uri }}?url={{ quoted_absolute_uri }}&format=json"
        title="{{ map.name }} oEmbed URL" />
  <meta property="og:url" content="{{ SITE_URL }}{{ map.get_absolute_url }}" />
  <meta property="og:title" content="{{ map.name }}" />
  <meta property="og:description" content="{{ map.description }}" />
  <meta property="og:site_name" content="{{ SITE_NAME }}" />
{% endblock extra_head %}
{% block content %}
  {% block map_init %}
    {% include "umap/map_init.html" %}
  {% endblock map_init %}
{% endblock content %}
