const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# один знак решітки — основний заголовок",
    "## two hashes for second heading": "## два знаки решітки — підзаголовок",
    "### three hashes for third heading": "### три знаки решітки — підзаголовок підзаголовка",
    "**double star for bold**": "**подвійні зірочки — жирний**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 день",
    "1 hour": "1 година",
    "5 min": "5 хвилин",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Розділені комами числа, що представляють шаблон довжини штрихів та проміжків пунктирної лінії. Напр.: \"5, 10,15\".",
    "About": "Про це",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Активувати режим слайдшоу",
    "Add a layer": "Додати шар",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Додати новий параметр",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Add image URL": "Add image URL",
    "Add": "Add",
    "Advanced actions": "Додаткові дії",
    "Advanced properties": "Розширенні параметри",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Усі параметри імпортовано.",
    "Allow interactions": "Дозволити взаємодію",
    "Allow scroll wheel zoom?": "Дозволити зміну масштабу колесом миші?",
    "always": "завжди",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to cancel your changes?": "Ви впевнені, що хочете скасувати зроблені зміни?",
    "Are you sure you want to clone this map and all its datalayers?": "Ви впевнені, що бажаєте скопіювати цю мапу з її усіма даними",
    "Are you sure you want to delete the feature?": "Ви впевнені, що хочете вилучити об’єкт?",
    "Are you sure you want to delete this layer?": "Ви впевнені, що хочете вилучити цей шар?",
    "Are you sure you want to delete this map?": "Ви впевнені, що хочете вилучити мапу?",
    "Are you sure you want to delete this property on all the features?": "Ви впевнені, що хочете вилучити цей параметр у всіх об’єктів?",
    "Are you sure you want to restore this version?": "Ви впевнені, що хочете відновити цю версію?",
    "Attach the map to my account": "Додати мапу до мого облікового запису",
    "attribution": "attribution",
    "Auto": "Автоматично",
    "Automatic": "Автоматично",
    "Autostart when map is loaded": "Автозапуск при завантаженні мапи",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Шпилька",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Огляд даних",
    "by": "від",
    "Cache proxied request": "Кешувати запити",
    "Cancel edits": "Скасувати правки",
    "Caption": "Заголовок",
    "Center map on your location": "Центрувати мапу за Вашим місцем розташування",
    "Change map background": "Змінити фонову мапу",
    "Change tilelayers": "Вибрати фонові шари",
    "Change": "Change",
    "Choose the data format": "Виберіть формат даних",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Коло",
    "clear": "очистити",
    "Click last point to finish shape": "Клацніть на останній точці, щоб завершити",
    "Click to add a marker": "Клацніть, щоб додати позначку",
    "Click to continue drawing": "Клацайте, щоб продовжити креслення",
    "Click to edit": "Натисніть для редагування",
    "Click to start drawing a line": "Клацайте, щоб продовжити креслення",
    "Click to start drawing a polygon": "Клацніть, щоб почати креслення багатокутника",
    "Clone of {name}": "Копія {name}",
    "Clone this feature": "Клонувати цей об’єкт",
    "Clone this map": "Створити копію мапи",
    "Clone": "Створити копію",
    "Close": "Закрити",
    "Clustered": "Кластеризованний",
    "Clustering radius": "Радіус кластеризації",
    "collapsed": "згорнуто",
    "color": "колір",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Як роздільник використовуються коми, табуляції і крапки з комою.  Застосовується датум WGS84. Імпорт переглядає заголовок на наявність полів «lat» та «lon», регістр не має значення.  Усі інші поля імпортуються як параметри.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Продовжити лінію",
    "Coordinates": "Координати",
    "copy": "copy",
    "Credits": "Авторські права / подяки",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Поточний вид замість типового виду мапи?",
    "Custom background": "Користувацька фонова мапа",
    "Custom overlay": "Custom overlay",
    "dash array": "штрихи",
    "Data is browsable": "Дані можна переглядати",
    "Datalayers": "Datalayers",
    "Default interaction options": "Типові параметри взаємодії",
    "Default properties": "Типові параметри",
    "Default shape properties": "Типові параметри полігону",
    "Default view": "Default view",
    "Default zoom level": "Типовий масштаб",
    "Default": "Типово",
    "Default: name": "Типова назва",
    "Define link to open in a new window on polygon click.": "Задати посилання для відкриття нового вікна при клацанні на полігоні.",
    "define": "визначити",
    "Delay between two transitions when in play mode": "Затримка між переходами в режими відтворення",
    "Delete layer": "Вилучити шар",
    "Delete this feature": "Вилучити цей об’єкт",
    "Delete this shape": "Вилучити цей полігон",
    "Delete this vertex (Alt+Click)": "Вилучити цю вершину (Alt+клік)",
    "Delete": "Вилучити",
    "description": "опис",
    "Direct link": "Direct link",
    "Directions from here": "Маршрут звідси",
    "Display label": "Показувати підписи",
    "Display measure": "Показати вимірювання",
    "display name": "показана назва",
    "Display on load": "Показувати під час завантаження",
    "Display the control to open OpenStreetMap editor": "Показувати кнопку переходу в редактор OpenStreetMap",
    "Display the embed control": "Показувати вбудовані елементи керування",
    "Display the fullscreen control": "Показувати перемикач повноекранного режиму",
    "Display the locate control": "Показувати кнопку визначення місцезнаходження",
    "Display the measure control": "Показувати інструменти вимірювання",
    "Display the search control": "Показувати засоби для пошуку",
    "Display the star map button": "Display the star map button",
    "Display the tile layers control": "Показувати перемикач шарів",
    "Display the zoom control": "Показувати елементи керування масштабуванням",
    "Do you want to display a caption bar?": "Показувати рядок заголовку?",
    "Do you want to display a minimap?": "Показувати мінімапу?",
    "Do you want to display a panel on load?": "Показувати панель керування при завантаженні?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Хочете використовувати спливаючу підказку знизу?",
    "Do you want to display the scale control?": "Показувати шкалу відстаней?",
    "Do you want to display the «more» control?": "Показувати кнопку «Більше»?",
    "Download": "Звантажити",
    "Drag to reorder": "Перетягніть, щоб змінити порядок",
    "Draw a marker": "Додати позначку",
    "Draw a polygon": "Накреслити полігон",
    "Draw a polyline": "Накреслити ламану",
    "Drawing": "Drawing",
    "Drop": "Крапля",
    "Dynamic properties": "Динамічні властивості",
    "Dynamic": "Динамічний",
    "Edit feature's layer": "Змінити шар об’єкту",
    "Edit properties in a table": "Редагувати параметри в таблиці",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Редагувати цей об’єкт",
    "Edit": "Редагувати",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Вбудувати мапу",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Очистити",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Помилка в посиланні на шар мапи",
    "Exit Fullscreen": "Вийти з повноекранного режиму",
    "expanded": "розгорнуто",
    "Extract shape to separate feature": "Виокремити полігон в окремий об’єкт",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Запитувати нові дані під час кожного оновлення мапи.",
    "fill color": "колір заливки",
    "fill opacity": "непрозорість заливки",
    "fill": "заливка",
    "Fit all data": "Fit all data",
    "Format": "Формат",
    "From zoom": "З масштабу",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (лише посилання)",
    "GeoRSS (title + image)": "GeoRSS (заголовок та зображення)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Перейти до «{feature}»",
    "Heatmap intensity property": "Параметр інтенсивності теплової мапи",
    "Heatmap radius": "Радіус для теплової мапи",
    "Heatmap": "Теплова мапа",
    "height": "висота",
    "Help": "Довідка",
    "hidden": "приховано",
    "Hide controls": "Прибрати елементи керування",
    "Home": "Головна",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Наскільки сильно спрощувати лінії на кожному масштабі (більше значення — більша швидкість, але виглядає гірше; менше значення — більш точне зображення)",
    "icon opacity": "icon opacity",
    "Icon shape": "Форма значка",
    "Icon symbol": "Символ значка",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe із зазначенням висоти (в пікселях): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe з власними висотою та шириною (у пікселях): {{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Зображення із зазначенням ширини (в пікселях): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Зображення: {{http://image.url.com}}",
    "Import data": "Імпорт даних",
    "Import in a new layer": "Імпортувати в новий шар",
    "Imports all umap data, including layers and settings.": "Імпортувати всі дані, включаючи інформацію про шари та налаштування.",
    "Include full screen link?": "Долучити посилання на повноекранний вид?",
    "Inherit": "Успадковувати",
    "inherit": "успадковувати",
    "Interaction options": "Параметри взаємодії",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Невірні umap-дані у файлі {filename}",
    "Invalid umap data": "Невірні umap-дані",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Залишити поточні видимі шари",
    "kilometers": "кілометрів",
    "km": "км",
    "Label direction": "Напрямок підпису",
    "Label key": "Підпис ключа",
    "Labels are clickable": "Мітки клікабельні",
    "Latest feature": "Latest feature",
    "Latitude": "Широта",
    "Layer properties": "Параметри шару",
    "Layer": "Шар",
    "Licence": "Ліцензія",
    "licence": "ліцензія",
    "Limit bounds": "Встановлення меж",
    "Link to view the map": "Link to view the map",
    "Link to…": "Послатись…",
    "Link with text: [[http://example.com|text of the link]]": "Посилання з текстом: [[http://example.com|текст для посилання]]",
    "Long credits": "Повний опис прав/подяки",
    "Longitude": "Довгота",
    "Make main shape": "Утворити основну форму",
    "Manage layers": "Керування шарами",
    "Manual": "Manual",
    "Map background credits": "Права/подяки на фонову мапу",
    "Map has been attached to your account": "Мапа була прикріплена до Вашого облікового запису",
    "Map has been saved!": "Мапу збережено!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "Картографічні дані користувача опубліковані згідно ліцензії",
    "Map's editors": "Редактори мапи",
    "Map's owner": "Власник мапи",
    "max East": "макс. на схід",
    "max North": "макс. на північ",
    "max South": "макс. на південь",
    "max West": "макс. на захід",
    "max zoom": "максимальний масштаб",
    "Measure distances": "Виміряти відстань",
    "Merge lines": "Об’єднати лінії",
    "mi": "миля",
    "miles": "миль",
    "min zoom": "мінімальний масштаб",
    "More controls": "Інші елементи керування",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Повинно бути чинне CSS-значення (на кшталт DarkBlue чи #123456)",
    "name": "назва",
    "nautical miles": "морських миль",
    "never": "ніколи",
    "new window": "new window",
    "next": "далі",
    "NM": "NM",
    "No cache": "Кешу немає",
    "No licence has been set": "Ліцензію не було зазначено",
    "No results": "Немає результатів",
    "no": "ні",
    "No.": "No.",
    "None": "Ні",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "Знизу",
    "On the left": "Ліворуч",
    "On the right": "Праворуч",
    "On the top": "Зверху",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "непрозорість",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Відкрити посилання у…",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Відкрийте цю частину мапи в редакторі OpenStreetMap, щоб поліпшити дані",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Додаткові параметри інтенсивності теплової мапи",
    "Optional. Same as color if not set.": "Додатково.  Якщо не вибрано, то як колір.",
    "Optional.": "Необов’язково.",
    "Override clustering radius (default 80)": "Перевизначити радіус кластеризації (типово 80)",
    "Override heatmap radius (default 25)": "Перевизначити радіус для теплової мапи (типово 25)",
    "parent window": "батьківське вікно",
    "Paste your data here": "Вставте ваші дані тут",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Переконайтеся, що ліцензія відповідає правилам використання.",
    "Please choose a format": "Будь ласка, виберіть формат",
    "Please enter the name of the property": "Будь ласка, введіть назву параметра",
    "Please enter the new name of this property": "Будь ласка, введіть нову назву параметра",
    "Please save the map first": "Спочатку збережіть вашу мапу",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup content template": "Шаблон спливаючої підказки",
    "Popup shape": "Popup shape",
    "Popup": "Popup",
    "Powered by uMap": "Powered by uMap",
    "previous": "назад",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Імпортовані параметри:",
    "Provide an URL here": "Вкажіть посилання тут",
    "Proxy request": "Запит проксі",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Віддалені дані",
    "Remove shape from the multi": "Remove shape from the multi",
    "Replace layer content": "Замінити вміст шару",
    "Restore this version": "Відновити цю версію",
    "Save current edits": "Зберегти поточні правки",
    "Save map": "Save map",
    "Save this center and zoom": "Зберегти такі центрування та масштаб",
    "Save this location as new feature": "Зберегти місце розташування як новий об’єкт",
    "Save": "Зберегти",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Пошук місця",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Дивитися в повноекранному режимі",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Встановіть false, щоб приховати шар в слайдшоу, в перегляді даних та навігації…",
    "settings": "settings",
    "Shape properties": "Параметри полігона",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Короткий опис прав/подяки",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Показати/приховати шар",
    "Side panel": "Бічна панель",
    "Simple link: [[http://example.com]]": "Просте посилання: [[http://example.com]]",
    "Simplify": "Спростити",
    "Skipping unknown geometry.type: {type}": "Пропускаємо невідоме значення geometry.type: {type}",
    "Slideshow": "Слайдшоу",
    "Sort key": "Ключ сортування",
    "Split line": "Розрізати лінію",
    "Star this map": "Star this map",
    "Start a hole here": "Почати отвір звідси",
    "Start slideshow": "Почати слайдшоу",
    "Stop editing": "Зупинити редагування",
    "Stop slideshow": "Зупинити слайдшоу",
    "Street": "Street",
    "stroke": "штрихи",
    "Supported scheme": "Підтримувана схема",
    "Supported variables that will be dynamically replaced": "Підтримувані змінні для автоматичної заміни",
    "Symbol": "Symbol",
    "Table": "Таблиця",
    "Text color for the cluster label": "Колір тексту для позначок кластера",
    "Text formatting": "Форматування тексту",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "Формат TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Якщо віддалений сервер не дозволяє крос-домен (повільно)",
    "To zoom": "Масштабувати",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Перетворити полігон у редагований об’єкт",
    "Transform to lines": "Перетворити на лінію",
    "Transform to polygon": "Перетворити на полігон",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Тип шару",
    "Unable to detect format of file {filename}": "Не вдається визначити формат файлу {filename}",
    "Untitled layer": "Шар без назви",
    "Untitled map": "Безіменна мапа",
    "Update permissions and editors": "Налаштувати привілеї та редакторів",
    "Update permissions": "Оновити дозволи",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "Посилання",
    "URL": "URL",
    "Use current bounds": "Використовувати поточні межі",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Використовуйте змінні в дужках з властивостями об’єктів, наприклад, &#123;name&#125;, вони будуть автоматично замінені відповідними значеннями.",
    "User content credits": "Права/подяки на користувацькі дані",
    "User interface options": "Налаштування інтерфейсу",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Версії",
    "View Fullscreen": "Перегляд на повний екран",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "товщина",
    "Where do we go from here?": "Що можна зробити з мапою далі?",
    "Whether to display or not polygons paths.": "Показувати чи ні контур полігону.",
    "Whether to fill polygons with color.": "Зафарбовувати чи ні полігони.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Хто може редагувати",
    "Who can view": "Хто може редагувати",
    "width": "ширина",
    "Will be displayed in the bottom right corner of the map": "Буде показано в правому нижньому кутку мапи",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Буде показано у заголовку мапи",
    "yes": "так",
    "Zoom in": "Збільшити масштаб",
    "Zoom level for automatic zooms": "Рівень масштабу для автоматичного масштабування",
    "Zoom out": "Зменшити масштаб",
    "Zoom to layer extent": "Масштабувати до кордонів шару",
    "Zoom to the next": "Наблизитися до наступного",
    "Zoom to the previous": "Наблизитися до попереднього",
    "Zoom to this feature": "Наблизитися до цього об’єкта",
    "Zoom to this place": "Наблизити до цього місця",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} помилок під час імпорту: {message}",
    "{delay} seconds": "{delay} секунди",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Import helpers:": "Import helpers:",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "My Dashboard ({username})": "My Dashboard ({username})",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control"
}
L.registerLocale("uk_UA", locale)
L.setLocale("uk_UA")
