const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# et hashtag for hovedoverskrift",
    "## two hashes for second heading": "## to hashtags for andet overskriftniveau",
    "### three hashes for third heading": "### tre hashtags for tredje overskriftsniveau",
    "**double star for bold**": "**dobbelt stjerne for fed skrift**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 dag",
    "1 hour": "1 time",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "En kommasepareret nummerliste som definerer stiplingsmønstret. Fx: \"5, 10, 15\".",
    "About": "Om",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Aktiver slideshowtilstand",
    "Add a layer": "Tilføj et lag",
    "Add a line to the current multi": "Tilføj en linje til nuværende multi",
    "Add a new property": "Tilføj en ny egenskab",
    "Add a polygon to the current multi": "Tilføj en polygon til nuværende multi",
    "Add image URL": "Add image URL",
    "Add": "Add",
    "Advanced actions": "Avancerede handlinger",
    "Advanced properties": "Avancerede egenskaber",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Alle egenskaber er importeret.",
    "Allow interactions": "Tillad interaktioner",
    "Allow scroll wheel zoom?": "Tillad zoom med scrollhjul?",
    "always": "altid",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to cancel your changes?": "Er du sikker på du vil fortryde dine ændringer?",
    "Are you sure you want to clone this map and all its datalayers?": "Er du sikker på du vil klone dette kort og alle dets datalag?",
    "Are you sure you want to delete the feature?": "Er du sikker på at du vil slette dette objekt?",
    "Are you sure you want to delete this layer?": "Er du sikker på at du vil slette dette lag?",
    "Are you sure you want to delete this map?": "Er du sikker på at du vil slette dette kort?",
    "Are you sure you want to delete this property on all the features?": "Er du sikker på du vil slette denne egenskab på alle objekter?",
    "Are you sure you want to restore this version?": "Er du sikker på at du vil genskabe denne version?",
    "Attach the map to my account": "Knyt kortet til min konto",
    "attribution": "navngivelse",
    "Auto": "Auto",
    "Automatic": "Automatisk",
    "Autostart when map is loaded": "Start automatisk når kort er indlæst",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Kugle",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Gennemse data",
    "by": "af",
    "Cache proxied request": "Forespørgsel i proxycache",
    "Cancel edits": "Fortryd redigeringer",
    "Caption": "Billedtekst",
    "Center map on your location": "Centrer kort på din placering",
    "Change map background": "Skift kortbaggrund",
    "Change tilelayers": "Skift kortlag",
    "Change": "Change",
    "Choose the data format": "Vælg dataformat",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Cirkel",
    "clear": "tøm",
    "Click last point to finish shape": "Klik på det det sidste punkt for at afslutte figur",
    "Click to add a marker": "Klik for at tilføje en  markør",
    "Click to continue drawing": "Klik for at fortsætte indtegning",
    "Click to edit": "Klik for at redigere",
    "Click to start drawing a line": "Klik for at starte indtegning af linje",
    "Click to start drawing a polygon": "Klik for at starte indtegning af polygon",
    "Clone of {name}": "Klone af {name}",
    "Clone this feature": "Klon dette objekt",
    "Clone this map": "Klon dette kort",
    "Clone": "Kloning",
    "Close": "Luk",
    "Clustered": "Klynge",
    "Clustering radius": "Klyngeradius",
    "collapsed": "klappet sammen",
    "color": "farver",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Komma, tabulering eller semikolon adskiller værdier. SRS WGS84 er underforstået. Kun punktgeometri importeres. Importen vil kigge efter kolonner, der indeholder varianter af \"lat\" eller \"lon\" i begyndelsen af overskriften, uden at tage hensyn til små og store bogstaver. Alle andre kolonner importeres som egenskaber.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Fortsæt linje",
    "Coordinates": "Koordinater",
    "copy": "copy",
    "Credits": "Kreditering",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Nuværende kortudsnit i stedet for standardkortvisning?",
    "Custom background": "Tilpasset baggrund",
    "Custom overlay": "Custom overlay",
    "dash array": "stiplet række",
    "Data is browsable": "Data kan gennemses",
    "Datalayers": "Datalayers",
    "Default interaction options": "Standardinteraktionsindstillinger",
    "Default properties": "Standardegenskaber",
    "Default shape properties": "Standard figur-egenskaber",
    "Default view": "Default view",
    "Default zoom level": "Standardzoomniveau",
    "Default": "Standard",
    "Default: name": "Standard:-navn",
    "Define link to open in a new window on polygon click.": "Definer link der åbnes i et nyt vindue ved klik på polygon.",
    "define": "definer",
    "Delay between two transitions when in play mode": "Forsinkelse mellem to transitioner, når i afspilningstilstand",
    "Delete layer": "Slet lag",
    "Delete this feature": "Slet dette objekt",
    "Delete this shape": "Slet denne figur",
    "Delete this vertex (Alt+Click)": "Slet denne vertex (Alt+Click)",
    "Delete": "Slet",
    "description": "beskrivelse",
    "Direct link": "Direct link",
    "Directions from here": "Kørselsvejledning herfra",
    "Display label": "Visningslabel",
    "Display measure": "Vis opmåling",
    "display name": "visningsnavn",
    "Display on load": "Vis ved indlæsning",
    "Display the control to open OpenStreetMap editor": "Vis kontrollen til åbning af OpenStreetMap-editoren",
    "Display the embed control": "Vis indlejringskontrollen",
    "Display the fullscreen control": "Vis fuldskærmskontrollen",
    "Display the locate control": "Vis lokaliseringskontrollen",
    "Display the measure control": "Vis opmålingskontrollen",
    "Display the search control": "Vis søgekontrollen",
    "Display the star map button": "Display the star map button",
    "Display the tile layers control": "Vis fliselagskontrollen",
    "Display the zoom control": "Vis zoomkontrollen",
    "Do you want to display a caption bar?": "Vil du vise en billedtekst?",
    "Do you want to display a minimap?": "Vil du vise  et miniaturekort?",
    "Do you want to display a panel on load?": "Vil du vise et panel ved indlæsning?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Vil du vise popupnoten?",
    "Do you want to display the scale control?": "Vil du vise målestokskontrollen?",
    "Do you want to display the «more» control?": "Vil du vise \"mere\"-kontrollen?",
    "Download": "Download",
    "Drag to reorder": "Træk for at ændre rækkefølge",
    "Draw a marker": "Tegn en markør",
    "Draw a polygon": "Tegn en polygon",
    "Draw a polyline": "Tegn en polygonlinje",
    "Drawing": "Drawing",
    "Drop": "Drop",
    "Dynamic properties": "Dynamiske egenskaber",
    "Dynamic": "Dynamisk",
    "Edit feature's layer": "Rediger objekts lag",
    "Edit properties in a table": "Rediger egenskaberne i en tabel",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Rediger dette objekt",
    "Edit": "Redigering",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Indlejring af kortet",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Tomt",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Fejl i fliselags-URL'en",
    "Exit Fullscreen": "Afslut fuldskærm",
    "expanded": "udvidet",
    "Extract shape to separate feature": "Udtræk figur for at adskille objekt",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Hent data hver gang kortvisningen ændres.",
    "fill color": "udfyldningsfarve",
    "fill opacity": "udfyldningsgennemsigtighed",
    "fill": "udfyldning",
    "Fit all data": "Fit all data",
    "Format": "Format",
    "From zoom": "Fra zoom",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (kun link)",
    "GeoRSS (title + image)": "GeoRSS (titel + billede)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Gå til \"{feature}\"",
    "Heatmap intensity property": "Heatmaps intensitetsegenskaber",
    "Heatmap radius": "Heatmaps radius",
    "Heatmap": "Heatmap",
    "height": "højde",
    "Help": "Hjælp",
    "hidden": "skjult",
    "Hide controls": "Skjul kontroller",
    "Home": "Hjem",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Hvor meget polylinjen skal forenkles på hvert zoomniveau (mere = bedre ydeevne og jævnere udseende, mindre = mere præcist)",
    "icon opacity": "icon opacity",
    "Icon shape": "Ikonfacon",
    "Icon symbol": "Ikonsymbol",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe med brugerdefineret højde (i px): {{{http://iframe.url.com|højde}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe med tilpasset højde og bredde (i px): {{{http://iframe.url.com|højde*bredde}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Billede med tilpasset bredde (i px): {{http://image.url.com|bredde}}",
    "Image: {{http://image.url.com}}": "Billede:  {{http://image.url.com}}",
    "Import data": "Importer data",
    "Import in a new layer": "Importerer i et nyt lag",
    "Imports all umap data, including layers and settings.": "Importerer alle umapdata, inklusiv lag og indstillinger,",
    "Include full screen link?": "Inkluder fuldskærmslink?",
    "Inherit": "Nedarv",
    "inherit": "nedarvet",
    "Interaction options": "Interaktionsindstillinger",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Ugydige umapdata i {filename}",
    "Invalid umap data": "Ugyldige umapdata",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Behold nuværende synlige lag",
    "kilometers": "kilometer",
    "km": "km",
    "Label direction": "Labelretning",
    "Label key": "Labelnøgle",
    "Labels are clickable": "Labels er klikbare",
    "Latest feature": "Latest feature",
    "Latitude": "Længdegrader",
    "Layer properties": "Lags egenskaber",
    "Layer": "Lag",
    "Licence": "Licens",
    "licence": "licens",
    "Limit bounds": "Afgræsning",
    "Link to view the map": "Link to view the map",
    "Link to…": "Link til…",
    "Link with text: [[http://example.com|text of the link]]": "Link med tekst: [[http://example.com|linktekst]]",
    "Long credits": "Lang kreditering",
    "Longitude": "Breddegrader",
    "Make main shape": "Gør til hovedfigur",
    "Manage layers": "Håndter lag",
    "Manual": "Manual",
    "Map background credits": "Baggrundskortkreditering",
    "Map has been attached to your account": "Kortet er blevet knyttet til din konto",
    "Map has been saved!": "Kortet er blevet gemt!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "Kortbrugerindholdet er udgivet under licensen",
    "Map's editors": "Korts redaktører",
    "Map's owner": "Korts ejer",
    "max East": "max øst",
    "max North": "max nord",
    "max South": "max syd",
    "max West": "max vest",
    "max zoom": "max zoom",
    "Measure distances": "Opmål afstande",
    "Merge lines": "Flet linjer",
    "mi": "mi",
    "miles": "miles",
    "min zoom": "min zoom",
    "More controls": "Vis flere kontroller",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Skal være en gyldig CSS-værdi (fx: DarkBlue eller #123456)",
    "name": "navn",
    "nautical miles": "sømil",
    "never": "aldrig",
    "new window": "nyt vindue",
    "next": "næste",
    "NM": "NM",
    "No cache": "Ingen cache",
    "No licence has been set": "Ingen licens angivet",
    "No results": "Ingen resultater",
    "no": "nej",
    "No.": "No.",
    "None": "Ingen",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "I bunden",
    "On the left": "Til venstre",
    "On the right": "Til højre",
    "On the top": "I toppen",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "gennemsigtighed",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Åbn link i…",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Åbn dette kort i en korteditor for at levere mere nøjagtige data til OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Valgfri intensitetsegenskaber for heatmap",
    "Optional. Same as color if not set.": "Valgfrit. Samme som farve hvis ikke opsat.",
    "Optional.": "Valgfrit.",
    "Override clustering radius (default 80)": "Overskriv klyngeradius (standard 80)",
    "Override heatmap radius (default 25)": "Overskriv heatmapradius (standard 25)",
    "parent window": "forældervindue",
    "Paste your data here": "Indsæt dine data her",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Sørg for at licensen tillader din anvendelse.",
    "Please choose a format": "Vælg et format",
    "Please enter the name of the property": "Angiv egenskabens navn",
    "Please enter the new name of this property": "Angiv egenskabens nye navn",
    "Please save the map first": "Gem først kortet",
    "Popup (large)": "Popup (stor)",
    "Popup content style": "Popupindholdsstil",
    "Popup content template": "Popups indholdsskabelon",
    "Popup shape": "Popupfacon",
    "Popup": "Popup",
    "Powered by uMap": "Powered by uMap",
    "previous": "forrige",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Egenskaber importeret:",
    "Provide an URL here": "Indsæt en URL her",
    "Proxy request": "Proxyforespørgsel",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Fjernudbudte data",
    "Remove shape from the multi": "Fjern figur fra multi",
    "Replace layer content": "Erstat lags indhold",
    "Restore this version": "Genskab denne version",
    "Save current edits": "Gem nuværende redigeringer",
    "Save map": "Save map",
    "Save this center and zoom": "Gem med dette center og zoom",
    "Save this location as new feature": "Gem denne placering som et nyt objekt",
    "Save": "Gem",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Søg efter placering",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Se i fuld skærm",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Sæt den til false, for at skjule dette lag fra slideshowet, databrowseren, popupnavigeringen…",
    "settings": "settings",
    "Shape properties": "Figuregenskaber",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Kort kreditering",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Vis/skjul lag",
    "Side panel": "Sidepanel",
    "Simple link: [[http://example.com]]": "Simpelt link: [[http://example.com]]",
    "Simplify": "Simplificer",
    "Skipping unknown geometry.type: {type}": "Springer over ukendt geometry.type: {type}",
    "Slideshow": "Slideshow",
    "Sort key": "Sorteringsnøgle",
    "Split line": "Opsplit linje",
    "Star this map": "Star this map",
    "Start a hole here": "Start et hul her",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Stop redigering",
    "Stop slideshow": "Stop slideshow",
    "Street": "Street",
    "stroke": "strøg",
    "Supported scheme": "Understøttet skema",
    "Supported variables that will be dynamically replaced": "Understøttede variabler som vil blive dynamisk erstattet",
    "Symbol": "Symbol",
    "Table": "Tabel",
    "Text color for the cluster label": "Tekstfarve for klyngelabel",
    "Text formatting": "Tekstformatering",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "TMS-format",
    "To use if remote server doesn't allow cross domain (slower)": "Anvendes hvis fjernserver ikke tillader krydsdomæne (langsommere)",
    "To zoom": "For at zoome",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Overfør figur til redigeret objekt",
    "Transform to lines": "Transformer til linjer",
    "Transform to polygon": "Transformer til polygon",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Lagtype",
    "Unable to detect format of file {filename}": "Kunne ikke genkende formatet på filen {filename}",
    "Untitled layer": "Unavngivet lag",
    "Untitled map": "Unavngivet kort",
    "Update permissions and editors": "Opdater indstillinger og redaktører",
    "Update permissions": "Opdater tilladelser",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Brug nuværende grænser",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Brug pladsholdere med objektegenskaberne mellem tuborgklammer, fx &#123;navn&#125;, så vil de dynamatisk blive erstattet med de tilhørende værdier.",
    "User content credits": "Brugerindhold-kreditering",
    "User interface options": "Brugergrænsefladeindstillinger",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Versioner",
    "View Fullscreen": "Fuldskærmsvisning",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "vægtning",
    "Where do we go from here?": "Hvor skal vi hen herfra?",
    "Whether to display or not polygons paths.": "Hvorvidt der vises eller ikke vises polygonstier.",
    "Whether to fill polygons with color.": "Hvorvidt polygoner udfyldes med farve.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Hvem kan redigere",
    "Who can view": "Hvem kan se",
    "width": "bredde",
    "Will be displayed in the bottom right corner of the map": "Vil blive vist i kortets nederste højre hjørne",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Vil være synlig i tekstfeltet på kortet",
    "yes": "ja",
    "Zoom in": "Zoom ind",
    "Zoom level for automatic zooms": "Zoomniveau for automatisk zooming",
    "Zoom out": "Zoom ud",
    "Zoom to layer extent": "Zoom til lagudvidelse",
    "Zoom to the next": "Zoom til næste",
    "Zoom to the previous": "Zoom til forrige",
    "Zoom to this feature": "Zoom til dette objekt",
    "Zoom to this place": "Zoom til dette sted",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} fejl under import: {message}",
    "{delay} seconds": "{delay} sekunder",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Import helpers:": "Import helpers:",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "My Dashboard ({username})": "My Dashboard ({username})",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control"
}
L.registerLocale("da", locale)
L.setLocale("da")
