const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# eitt myllumerki fyrir aðalfyrirsögn",
    "## two hashes for second heading": "## tvö myllumerki fyrir aðra fyrirsögn",
    "### three hashes for third heading": "### þrjú myllumerki fyrir þriðju fyrirsögn",
    "**double star for bold**": "**tvöföld stjarna/margföldun fyrir feitletrað**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 dagur",
    "1 hour": "1 klukkustund",
    "5 min": "5 mín",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Kommu-aðgreindur listi með tölum sem skilgreina strikamynstur. Til dæmis: \"5, 10, 15\".",
    "About": "Um hugbúnaðinn",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Virkja skyggnusýningarham",
    "Add a layer": "Bæta við lagi",
    "Add a line to the current multi": "Bæta línu við fyrirliggjandi hóp",
    "Add a new property": "Bæta við nýju eigindi",
    "Add a polygon to the current multi": "Bæta marghyrningi við fyrirliggjandi hóp",
    "Add image URL": "Add image URL",
    "Add": "Add",
    "Advanced actions": "Ítarlegri aðgerðir",
    "Advanced properties": "Ítarlegir eiginleikar",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Öll eigindi voru flutt inn.",
    "Allow interactions": "Leyfa gagnvirkni",
    "Allow scroll wheel zoom?": "Leyfa aðdrátt með skrunhjóli?",
    "always": "alltaf",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to cancel your changes?": "Ertu viss um að þú viljir hætta við breytingarnar þínar?",
    "Are you sure you want to clone this map and all its datalayers?": "Ertu viss um að þú viljir klóna þetta kort og öll gagnalög þess?",
    "Are you sure you want to delete the feature?": "Ertu viss um að þú viljir eyða fitjunni?",
    "Are you sure you want to delete this layer?": "Ertu viss um að þú viljir eyða þessu lagi?",
    "Are you sure you want to delete this map?": "Ertu viss um að þú viljir eyða þessu korti?",
    "Are you sure you want to delete this property on all the features?": "Ertu viss um að þú viljir eyða þessu eigindi á öllum fitjum?",
    "Are you sure you want to restore this version?": "Ertu viss um að vilja endurheimta þessa útgáfu?",
    "Attach the map to my account": "Tengja kortið við notandaaðganginn minn",
    "attribution": "tilvísun í höfund/a",
    "Auto": "Sjálfvirkt",
    "Automatic": "Sjálfvirkt",
    "Autostart when map is loaded": "Sjálfræsa þegar korti er hlaðið inn",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Kúla",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Skoða gögn",
    "by": "eftir",
    "Cache proxied request": "Setja milliþjónabeiðnir í skyndiminni",
    "Cancel edits": "Hætta við breytingar",
    "Caption": "Skýringatexti",
    "Center map on your location": "Miðjusetja kortið á staðsetningu þína",
    "Change map background": "Breyta bakgrunni landakorts",
    "Change tilelayers": "Skipta um kortatíglalög",
    "Change": "Change",
    "Choose the data format": "Veldu gagnasnið",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Hringur",
    "clear": "hreinsa",
    "Click last point to finish shape": "Smelltu á síðasta punktinn til að ljúka lögun",
    "Click to add a marker": "Smella til að bæta við kortamerki",
    "Click to continue drawing": "Smelltu til að halda áfram að teikna",
    "Click to edit": "Smelltu til að breyta",
    "Click to start drawing a line": "Smelltu til að byrja að teikna línu",
    "Click to start drawing a polygon": "Smelltu til að byrja að teikna fláka (marghyrning)",
    "Clone of {name}": "Klónað afrit af {name}",
    "Clone this feature": "Klóna þessa fitju",
    "Clone this map": "Klóna þetta landakort",
    "Clone": "Klóna",
    "Close": "Loka",
    "Clustered": "Í klösum",
    "Clustering radius": "Radíus klasa",
    "collapsed": "samfallið",
    "color": "litur",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Gildi aðgreind með kommu, dálkmerki (tab) eða semíkommu. Miðað við SRS hnattviðmið WGS84. Einungis punktalaganir (geometries) eru fluttar inn. Við innflutning er skoðað í fyrirsögnum dálka hvort minnst sé á «lat» eða «lon» í byrjun fyrirsagna, óháð há-/lágstöfum. Allir aðrir dálkar eru fluttir inn sem eigindi.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Halda áfram með línu",
    "Coordinates": "Hnit",
    "copy": "copy",
    "Credits": "Framlög",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Fyrirliggjandi sýn í stað sjálfgefinnar kortasýnar?",
    "Custom background": "Sérsniðinn bakgrunnur",
    "Custom overlay": "Custom overlay",
    "dash array": "strikafylki",
    "Data is browsable": "Gögn eru vafranleg",
    "Datalayers": "Datalayers",
    "Default interaction options": "Sjálfgefnir valkostir gagnvirkni",
    "Default properties": "Sjálfgefnir eiginleikar",
    "Default shape properties": "Sjálfgefnir eiginleikar lögunar",
    "Default view": "Default view",
    "Default zoom level": "Sjálfgefið aðdráttarstig",
    "Default": "Sjálfgefið",
    "Default: name": "Sjálfgefið: nafn",
    "Define link to open in a new window on polygon click.": "Skilgreindu tengil til að opna í nýjum glugga þegar smellt er á marghyrning.",
    "define": "skilgreina",
    "Delay between two transitions when in play mode": "Hlé milli tveggja millifærslna í afspilunarham",
    "Delete layer": "Eyða lagi",
    "Delete this feature": "Eyða þessari fitju",
    "Delete this shape": "Eyða þessari lögun",
    "Delete this vertex (Alt+Click)": "Eyða þessum brotpunkti (Alt+Smella)",
    "Delete": "Eyða",
    "description": "lýsing",
    "Direct link": "Direct link",
    "Directions from here": "Leiðir héðan",
    "Display label": "Birta skýringu",
    "Display measure": "Birta lengdarmæli",
    "display name": "birtingarnafn",
    "Display on load": "Birta við innhleðslu",
    "Display the control to open OpenStreetMap editor": "Birta hnapp til að opna OpenStreetMap-ritill",
    "Display the embed control": "Birta hnapp fyrir ígræðslukóða",
    "Display the fullscreen control": "Birta hnapp fyrir skjáfylli",
    "Display the locate control": "Birta staðsetningarhnapp",
    "Display the measure control": "Birta mælihnapp",
    "Display the search control": "Birta leitarhnapp",
    "Display the star map button": "Display the star map button",
    "Display the tile layers control": "Birta hnapp fyrir kortatíglalög",
    "Display the zoom control": "Birta aðdráttarhnapp",
    "Do you want to display a caption bar?": "Viltu birta skjástiku með skýringatexta?",
    "Do you want to display a minimap?": "Viltu birta yfirlitskort?",
    "Do you want to display a panel on load?": "Viltu birta hliðarspjald við innhleðslu?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Viltu birta síðufót sem sprettglugga?",
    "Do you want to display the scale control?": "Viltu birta kvarðahnapp?",
    "Do you want to display the «more» control?": "Viltu birta hnapp fyrir «meira»?",
    "Download": "Sækja",
    "Drag to reorder": "Draga til að endurraða",
    "Draw a marker": "Teikna kortamerki",
    "Draw a polygon": "Teikna fláka (marghyrning)",
    "Draw a polyline": "Teikna fjölpunktalínu (polyline)",
    "Drawing": "Drawing",
    "Drop": "Dropi",
    "Dynamic properties": "Breytilegir eiginleikar",
    "Dynamic": "Breytilegt",
    "Edit feature's layer": "Breyta lagi fitjunnar",
    "Edit properties in a table": "Breyta eigindum í töflu",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Breyta þessari fitju",
    "Edit": "Breyta",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Setja landakortið inn á vefsíðu",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Tómt",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Villa í slóð kortatíglalags",
    "Exit Fullscreen": "Hætta í skjáfylli",
    "expanded": "útliðað",
    "Extract shape to separate feature": "Flytja lögun í aðskilda fitju",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Sækja gögn í hvert skipti sem kortasýn breytist",
    "fill color": "fyllilitur",
    "fill opacity": "ógegnsæi fyllingar",
    "fill": "fylling",
    "Fit all data": "Fit all data",
    "Format": "Snið",
    "From zoom": "Frá aðdráttarstigi",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (aðeins tengill)",
    "GeoRSS (title + image)": "GeoRSS (titill + mynd)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Fara á «{feature}»",
    "Heatmap intensity property": "Styrkeigindi fyrir hitakort",
    "Heatmap radius": "Radíus hitakorts",
    "Heatmap": "Hitakort",
    "height": "hæð",
    "Help": "Hjálp",
    "hidden": "falið",
    "Hide controls": "Fela hnappa",
    "Home": "Heim",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Hve mikið eigi að einfalda fjölpunktalínu á hverju aðdráttarstigi (meira = betri afköst og mýkra útlit, minna = nákvæmara)",
    "icon opacity": "icon opacity",
    "Icon shape": "Lögun Táknmyndar",
    "Icon symbol": "Myndtákn",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe með sérsniðinni hæð (í mynddílum/px): {{{http://iframe.url.com|hæð}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe með sérsniðinni hæð og breidd (í mynddílum/px): {{{http://iframe.url.com|hæð*breidd}}}",
    "iframe": "iFrame",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Mynd með sérsniðinni breidd (í mynddílum): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Mynd: {{http://image.url.com}}",
    "Import data": "Flytja inn gögn",
    "Import in a new layer": "Flytja inn í nýtt lag",
    "Imports all umap data, including layers and settings.": "Flytur inn öll umap-gögn, þar með talin lög og stillingar.",
    "Include full screen link?": "Hafa með tengil á að fylla skjá?",
    "Inherit": "Erfa",
    "inherit": "erfa",
    "Interaction options": "Valkostir gagnvirkni",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Ógild umap-gögn í {filename}",
    "Invalid umap data": "Ógild umap-gögn",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Halda fyrirliggjandi sýnilegum lögum",
    "kilometers": "kílómetrar",
    "km": "km",
    "Label direction": "Stefna skýringar",
    "Label key": "Lykill skýringar",
    "Labels are clickable": "Hægt er að smella á skýringar",
    "Latest feature": "Latest feature",
    "Latitude": "Breiddargráða",
    "Layer properties": "Eiginleikar lags",
    "Layer": "Lag",
    "Licence": "Notkunarleyfi",
    "licence": "notkunarleyfi",
    "Limit bounds": "Mörk útjaðars",
    "Link to view the map": "Link to view the map",
    "Link to…": "Tengja við…",
    "Link with text: [[http://example.com|text of the link]]": "Tengill með texta: [[http://example.com|texti tengils]]",
    "Long credits": "Lengra um framlög",
    "Longitude": "Lengdargráða",
    "Make main shape": "Gera að aðallögun",
    "Manage layers": "Sýsla með lög",
    "Manual": "Manual",
    "Map background credits": "Þakkir vegna bakgrunnsmyndar:",
    "Map has been attached to your account": "Kortið hefur verið tengt við notandaaðganginn þinn",
    "Map has been saved!": "Landakortið hefur verið vistað!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "Kortagögn notandans eru gefin út með notkunarleyfinu",
    "Map's editors": "Ritstjórar korts",
    "Map's owner": "Eigandi korts",
    "max East": "Hám. austur",
    "max North": "Hám. norður",
    "max South": "Hám. suður",
    "max West": "Hám. vestur",
    "max zoom": "Hám. aðdráttur",
    "Measure distances": "Mæla vegalengdir",
    "Merge lines": "Sameina línur",
    "mi": "mi",
    "miles": "mílur",
    "min zoom": "lágm. aðdráttur",
    "More controls": "Fleiri hnappar",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Verður að vera gilt CSS-gildi (t.d.: DarkBlue eða #123456)",
    "name": "heiti",
    "nautical miles": "sjómílur",
    "never": "aldrei",
    "new window": "nýr gluggi",
    "next": "næsta",
    "NM": "Sjómílur",
    "No cache": "Ekkert biðminni",
    "No licence has been set": "Ekkert notkunarleyfi hefur verið sett",
    "No results": "Engar niðurstöður",
    "no": "nei",
    "No.": "No.",
    "None": "Ekkert",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "Neðst",
    "On the left": "Vinstra megin",
    "On the right": "Hægra megin",
    "On the top": "Efst",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "ógegnsæi",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Opna tengil í…",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Opna umfang þessa korts í kortavinnsluforriti til að gefa nákvæmari kortagögn til OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Valfrjálst styrkeigindi fyrir hitakort",
    "Optional. Same as color if not set.": "Valfrjálst. Sama og litur ef ekkert er skilgreint.",
    "Optional.": "Valfrjálst.",
    "Override clustering radius (default 80)": "Nota annan radíus klösunar (sjálfgefið 80)",
    "Override heatmap radius (default 25)": "Nota annan radíus hitakorts (sjálfgefið 25)",
    "parent window": "yfirgluggi",
    "Paste your data here": "Límdu gögnin þín hér",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Gakktu úr skugga um að notkunarleyfið samsvari notkunasviði þínu.",
    "Please choose a format": "Veldu snið",
    "Please enter the name of the property": "Settu inn heiti á eigindið",
    "Please enter the new name of this property": "Settu inn nýja heitið á þetta eigindi",
    "Please save the map first": "Vistaðu fyrst kortið",
    "Popup (large)": "Sprettgluggi (stór)",
    "Popup content style": "Stíll efnis í sprettglugga",
    "Popup content template": "Sniðmát efnis í sprettglugga",
    "Popup shape": "Lögun sprettglugga",
    "Popup": "Sprettgluggi",
    "Powered by uMap": "Powered by uMap",
    "previous": "fyrra",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Innflutt eigindi:",
    "Provide an URL here": "Gefðu hér upp URL-slóð",
    "Proxy request": "Beiðni frá milliþjóni",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Fjartengd gögn",
    "Remove shape from the multi": "Fjarlægja lögun úr hópnum",
    "Replace layer content": "Skipta út innihaldi lagsins",
    "Restore this version": "Endurheimta þessa útgáfu",
    "Save current edits": "Vista fyrirliggjandi breytingar",
    "Save map": "Save map",
    "Save this center and zoom": "Vista þessa miðju og aðdrátt",
    "Save this location as new feature": "Vista þessa staðsetningu sem nýja fitju",
    "Save": "Vista",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Leita að staðsetningu",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Fylla skjáinn",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Settu þetta sem ósatt til að fela þetta lag úr skyggnusýningu, gagnavafranum, sprettleiðsögn…",
    "settings": "settings",
    "Shape properties": "Eiginleikar lögunar",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Stutt um framlög",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Birta/Fela lag",
    "Side panel": "Hliðarspjald",
    "Simple link: [[http://example.com]]": "Einfaldur tengill: [[http://example.com]]",
    "Simplify": "Einfalda",
    "Skipping unknown geometry.type: {type}": "Sleppi óþekktu geometry.type: {type}",
    "Slideshow": "Skyggnusýning",
    "Sort key": "Röðunarlykill",
    "Split line": "Skipta línu",
    "Star this map": "Star this map",
    "Start a hole here": "Byrja holu hér",
    "Start slideshow": "Hefja skyggnusýningu",
    "Stop editing": "Hætta breytingum",
    "Stop slideshow": "Stöðva skyggnusýningu",
    "Street": "Street",
    "stroke": "strik",
    "Supported scheme": "Stutt skema",
    "Supported variables that will be dynamically replaced": "Studdar breytur sem verður skipt út eftir þörfum",
    "Symbol": "Symbol",
    "Table": "Tafla",
    "Text color for the cluster label": "Litur á texta fyrir skýringu á klasa",
    "Text formatting": "Snið á texta",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "TMS-snið",
    "To use if remote server doesn't allow cross domain (slower)": "Nota ef fjartengdur þjónn leyfir ekki millivísanir léna (hægvirkara)",
    "To zoom": "Í aðdrátt",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Flytja lögun í breyttu fitjuna",
    "Transform to lines": "Umbreyta í línur",
    "Transform to polygon": "Umbreyta í fláka/marghyrning",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Tegund lags",
    "Unable to detect format of file {filename}": "Tókst ekki að ákvarða sniðið á skránni {filename}",
    "Untitled layer": "Ónefnt lag",
    "Untitled map": "Ónefnt landakort",
    "Update permissions and editors": "Uppfæra heimildir og ritstjóra",
    "Update permissions": "Uppfæra heimildir",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "Slóð",
    "URL": "URL",
    "Use current bounds": "Nota fyrirliggjandi útjaðar",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Notaðu frátökutákn með eigindum fitja innan sviga, t.d. &#123;nafn&#125;, þeim verður skipt út eftir þörfum fyrir samsvarandi gildi.",
    "User content credits": "Framlög notanda á efni",
    "User interface options": "Valkostir notendaviðmóts",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Útgáfur",
    "View Fullscreen": "Fylla skjáinn",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "þykkt",
    "Where do we go from here?": "Hvert förum við héðan?",
    "Whether to display or not polygons paths.": "Hvort birta eigi ferla fláka/marghyrninga.",
    "Whether to fill polygons with color.": "Hvort eigi að fylla fláka með lit.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Hverjir geta breytt",
    "Who can view": "Hverjir geta skoðað",
    "width": "breidd",
    "Will be displayed in the bottom right corner of the map": "Verður birt niðri í hægra horni kortsins",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Verður sýnilegt í skýringatexta kortsins",
    "yes": "já",
    "Zoom in": "Renna að",
    "Zoom level for automatic zooms": "Aðdráttarstig fyrir sjálfvirkan aðdrátt",
    "Zoom out": "Renna frá",
    "Zoom to layer extent": "Renna að útjöðrum lags",
    "Zoom to the next": "Aðdráttur að næsta",
    "Zoom to the previous": "Aðdráttur á fyrra",
    "Zoom to this feature": "Aðdráttur að þessari fitju",
    "Zoom to this place": "Aðdráttur á þennan stað",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} villur við innflutning: {message}",
    "{delay} seconds": "{delay} sekúndur",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Import helpers:": "Import helpers:",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "My Dashboard ({username})": "My Dashboard ({username})",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control"
}
L.registerLocale("is", locale)
L.setLocale("is")
