const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# једна тараба за главни наслов",
    "## two hashes for second heading": "## две тарабе за поднаслов",
    "### three hashes for third heading": "### три тарабе за под-поднаслова",
    "**double star for bold**": "** две звезвдице за подебљање слова**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 дан",
    "1 hour": "1 сат",
    "5 min": "5 минута",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Списак бројева одвојених зарезом који дефинише образац цртице цртице. Нпр .: \"5, 10, 15\".",
    "About": "Више о",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Активирајте режим презентације",
    "Add a layer": "Додај лејер",
    "Add a line to the current multi": "Додајте линију тренутном мулти",
    "Add a new property": "Додајте нови ентитет",
    "Add a polygon to the current multi": "Додајте полигон тренутном мулти",
    "Add image URL": "Add image URL",
    "Add": "Add",
    "Advanced actions": "Напредне акције",
    "Advanced properties": "Напредне поставке",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Све поставке су увезене",
    "Allow interactions": "Дозволи интеракције",
    "Allow scroll wheel zoom?": "Допусти увећање зумом миша",
    "always": "увек",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to cancel your changes?": "Да ли сте сигурне да желите да откажете промене?",
    "Are you sure you want to clone this map and all its datalayers?": "Да ли сте сигурни да желите да умножите мапу и све податке на њој?",
    "Are you sure you want to delete the feature?": "Да ли сте сигурни да желите да обришете елемент?",
    "Are you sure you want to delete this layer?": "Да ли сте сигурни да желите да обришете лејер?",
    "Are you sure you want to delete this map?": "Да ли сте сигурни да желите да обришете мапу?",
    "Are you sure you want to delete this property on all the features?": "Јесте ли сигурни да желите да избришете овај ентитет на свим функцијама?",
    "Are you sure you want to restore this version?": "Јесте ли сигурни да желите да вратите ову верзију?",
    "Attach the map to my account": "Закачи мапу на мој налог.",
    "attribution": "attribution",
    "Auto": "Аутоматски",
    "Automatic": "Аутоматско",
    "Autostart when map is loaded": "Аутоматски покрени када се мапа учита",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Лопта",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Претражи податке",
    "by": "by",
    "Cache proxied request": "Cache proxied request",
    "Cancel edits": "Откажи промене",
    "Caption": "Напомена",
    "Center map on your location": "Центрирај мапу на основу локације",
    "Change map background": "Промени позадину карте",
    "Change tilelayers": "Промени наслов лејера",
    "Change": "Change",
    "Choose the data format": "Одабери формат датума",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Круг",
    "clear": "очисти",
    "Click last point to finish shape": "Кликните на последњу тачку да бисте довршили облик",
    "Click to add a marker": "Клик за додавање ознаке",
    "Click to continue drawing": "Клик да наставите са цртањем",
    "Click to edit": "Клик за уређивање",
    "Click to start drawing a line": "Клик да започнете цртање линије",
    "Click to start drawing a polygon": "Клик да започнете цртање површине",
    "Clone of {name}": "Клон од {име}",
    "Clone this feature": "Дуплирај елемент",
    "Clone this map": "Дуплирај мапу",
    "Clone": "Клон",
    "Close": "Затвори",
    "Clustered": "Груписање",
    "Clustering radius": "Радијус кластера",
    "collapsed": "срушено",
    "color": "боја",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Вредности одвојене зарезима, табом или новим редом. Подразумева се SRS WGS84. Увозе се само тачке геометрије. Увоз ће погледати заглавља ступаца за било које спомињање «лат» и «лон» на почетку заглавља, осетљив на велика и мала слова. Све друге колоне се увозе као својства.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Наставите линију",
    "Coordinates": "Координате",
    "copy": "copy",
    "Credits": "Заслуга",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Тренутни приказ уместо подразумеваног приказа мапе?",
    "Custom background": "Одаберите позадину",
    "Custom overlay": "Custom overlay",
    "dash array": "цртица низ",
    "Data is browsable": "Подаци се могу прегледати",
    "Datalayers": "Datalayers",
    "Default interaction options": "Подразумеване могућности интеракције",
    "Default properties": "Фабричке вредности",
    "Default shape properties": "Подразумевана својства облика",
    "Default view": "Default view",
    "Default zoom level": "Подразумевани ниво зумирања",
    "Default": "Фабричка подешавања",
    "Default: name": "Фабричко: Име",
    "Define link to open in a new window on polygon click.": "Дефинишите везу за отварање у новом прозору на клику полигона.",
    "define": "дефиниши",
    "Delay between two transitions when in play mode": "Одгода између два прелаза у режиму репродукције",
    "Delete layer": "Обриши лејер",
    "Delete this feature": "Обриши елемент",
    "Delete this shape": "Обриши облик",
    "Delete this vertex (Alt+Click)": "Обриши овај врх (Alt+Click)",
    "Delete": "Обриши",
    "description": "опис",
    "Direct link": "Direct link",
    "Directions from here": "Упутства одавде",
    "Display label": "Прикажи ознаку",
    "Display measure": "Мера приказа",
    "display name": "display name",
    "Display on load": "Приказ при учитавању",
    "Display the control to open OpenStreetMap editor": "Прикажи контролу да бисте отворили  OpenStreetMap уређивач",
    "Display the embed control": "Прикажи уграђену контролу",
    "Display the fullscreen control": "Прикажи контроле пуног режима",
    "Display the locate control": "Прикажи контролу лоцирања",
    "Display the measure control": "Прикажи контролу мере",
    "Display the search control": "Прикажи контроле претраге",
    "Display the star map button": "Display the star map button",
    "Display the tile layers control": "Прикажи контроле лејера",
    "Display the zoom control": "Прикажи контроле зумирања",
    "Do you want to display a caption bar?": "Да ли желите да прикажете траку натписа?",
    "Do you want to display a minimap?": "Желите ли приказати малу карту?",
    "Do you want to display a panel on load?": "Да ли желите да прикажете панел при учитавању?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Желите ли приказати скочни прозор у подножју?",
    "Do you want to display the scale control?": "Да ли желите да прикажете размеру?",
    "Do you want to display the «more» control?": "Да ли желите да прикажете контролу «више»?",
    "Download": "Преузимање",
    "Drag to reorder": "Превуците за промену редоследа",
    "Draw a marker": "Цртање ознаке",
    "Draw a polygon": "Цртање површине",
    "Draw a polyline": "Цртање изломљене линије",
    "Drawing": "Drawing",
    "Drop": "Избаци",
    "Dynamic properties": "Динамично подешавање",
    "Dynamic": "Динамично",
    "Edit feature's layer": "Уређивање елемента одабраног лејера",
    "Edit properties in a table": "Edit properties in a table",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Уређивање елемента",
    "Edit": "Уређивање",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Embed the map",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Empty",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Error in the tilelayer URL",
    "Exit Fullscreen": "Умањи увећање",
    "expanded": "проширен",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Feature identifier key": "Тастер идентификатора функцијеFeature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "fill color": "боја испуне",
    "fill opacity": "прозирност испуне",
    "fill": "испуна",
    "Fit all data": "Fit all data",
    "Format": "Формат",
    "From zoom": "From zoom",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (само линк)",
    "GeoRSS (title + image)": "GeoRSS (наслов+ слика)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Go to «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Heatmap radius",
    "Heatmap": "Heatmap",
    "height": "висина",
    "Help": "Помоћ",
    "hidden": "сакриј",
    "Hide controls": "Сакриј контроле",
    "Home": "Почетна страна",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "icon opacity": "icon opacity",
    "Icon shape": "Облик иконе",
    "Icon symbol": "Икона симбола",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "iframe": "облик",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Image with custom width (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Image: {{http://image.url.com}}",
    "Import data": "Увоз података",
    "Import in a new layer": "Увези у новом лејеру",
    "Imports all umap data, including layers and settings.": "Увези све податке из мапе, укључујући лејере и подешавања",
    "Include full screen link?": "Include full screen link?",
    "Inherit": "Наслеђено",
    "inherit": "наследити",
    "Interaction options": "Опција интеракције",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Invalid umap data": "Invalid umap data",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Keep current visible layers",
    "kilometers": "километри",
    "km": "km",
    "Label direction": "Смер ознаке",
    "Label key": "Кључ ознаке",
    "Labels are clickable": "На ознаке је могуће кликнути",
    "Latest feature": "Latest feature",
    "Latitude": "Latitude",
    "Layer properties": "Layer properties",
    "Layer": "Лејер",
    "Licence": "Лиценца",
    "licence": "лиценца",
    "Limit bounds": "Limit bounds",
    "Link to view the map": "Link to view the map",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Линк са текстом [[http://example.com|text of the link]]",
    "Long credits": "Long credits",
    "Longitude": "Longitude",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Manual": "Manual",
    "Map background credits": "Map background credits",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Мапа је сачувана!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "Map user content has been published under licence",
    "Map's editors": "Уређивачи мапе",
    "Map's owner": "Власник мапе",
    "max East": "max East",
    "max North": "max North",
    "max South": "max South",
    "max West": "max West",
    "max zoom": "максимално увећање",
    "Measure distances": "Measure distances",
    "Merge lines": "Merge lines",
    "mi": "mi",
    "miles": "миље",
    "min zoom": "минимално увећање",
    "More controls": "Више опција",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "name": "име",
    "nautical miles": "наутичке миље",
    "never": "никад",
    "new window": "нови прозор",
    "next": "следеће",
    "NM": "NM",
    "No cache": "Нема кеша",
    "No licence has been set": "Лиценца није постављена",
    "No results": "Нема резултата",
    "no": "не",
    "No.": "No.",
    "None": "Ништа",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "На дну",
    "On the left": "На лево",
    "On the right": "На десно",
    "On the top": "На врху",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "прозирност",
    "Opacity": "Opacity",
    "Open current feature on load": "Отворите тренутну функцију при учитавању",
    "Open link in…": "Отвори линк у...",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Optional. Same as color if not set.",
    "Optional.": "Опционо",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "parent window": "искачући прозор",
    "Paste your data here": "Прикачите Ваше податке овде",
    "Permalink": "Трајни линк",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Молимо Вас уверите се да је лиценца компатибилна.",
    "Please choose a format": "Молимо Вас одаберите формат",
    "Please enter the name of the property": "Please enter the name of the property",
    "Please enter the new name of this property": "Please enter the new name of this property",
    "Please save the map first": "Молимо Вас сачувајте мапу претходно",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Искачући стил",
    "Popup content template": "Шаблон за садржај искачућег прозора",
    "Popup shape": "Искачући облик",
    "Popup": "Popup",
    "Powered by uMap": "Powered by uMap",
    "previous": "претходно",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Properties imported:",
    "Provide an URL here": "Упишите URL",
    "Proxy request": "Proxy request",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Remote data",
    "Remove shape from the multi": "Remove shape from the multi",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save current edits": "Сачувај тренутна подешавања",
    "Save map": "Save map",
    "Save this center and zoom": "Сачувај подешавања центра и увећања",
    "Save this location as new feature": "Сачувај локацију као нови елемент",
    "Save": "Сачувај",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Претражи локацију",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Увећана слика",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "settings": "settings",
    "Shape properties": "Својства облика",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Short credits",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Прикажи/сакриј лејер",
    "Side panel": "Бочни панел",
    "Simple link: [[http://example.com]]": "Simple link: [[http://example.com]]",
    "Simplify": "Поједноставити",
    "Skipping unknown geometry.type: {type}": "Прескакање непознате геометрије.type: {type}",
    "Slideshow": "Slideshow",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Star this map": "Star this map",
    "Start a hole here": "Start a hole here",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Заустави уређивања",
    "Stop slideshow": "Stop slideshow",
    "Street": "Street",
    "stroke": "линија",
    "Supported scheme": "Supported scheme",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "Symbol": "Symbol",
    "Table": "Табела",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Text formatting",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "Назив својства који се користи као јединствени идентификатор функције.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "TMS format",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "Увећај",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Transform to lines",
    "Transform to polygon": "Transform to polygon",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Type of layer",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Безимени лејер",
    "Untitled map": "Безимена мапа",
    "Update permissions and editors": "Ажурирај дозволе и уреднике",
    "Update permissions": "Ажурирај дозволе",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Use current bounds",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Заслуге за садржај",
    "User interface options": "User interface options",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Versions",
    "View Fullscreen": "Прикажи увећано",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "дебљина",
    "Where do we go from here?": "Where do we go from here?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "width": "дебљина",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "yes": "да",
    "Zoom in": "Увећај",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "Умањи",
    "Zoom to layer extent": "Zoom to layer extent",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Увећај одабрано",
    "Zoom to this place": "Zoom to this place",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "{delay} seconds": "{губици} секунди",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Import helpers:": "Import helpers:",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "My Dashboard ({username})": "My Dashboard ({username})",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control"
}
L.registerLocale("sr", locale)
L.setLocale("sr")
