const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# ハッシュ1つで主な見出し",
    "## two hashes for second heading": "## ハッシュ2つで第二見出し",
    "### three hashes for third heading": "### ハッシュ3つで第三見出し",
    "**double star for bold**": "**アスタリスク2つで太字**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "カンマで数字を区切り、ストロークの破線パターンを指定。 例: \"5, 10, 15\"",
    "About": "概要",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "レイヤ追加",
    "Add a line to the current multi": "現在のマルチにラインを追加",
    "Add a new property": "プロパティ追加",
    "Add a polygon to the current multi": "現在のマルチにポリゴンを追加",
    "Add image URL": "Add image URL",
    "Add": "Add",
    "Advanced actions": "拡張アクション",
    "Advanced properties": "拡張プロパティ",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "すべてのプロパティがインポートされました。",
    "Allow interactions": "インタラクションを許可",
    "Allow scroll wheel zoom?": "マウスホイールでのスクロールを許可？",
    "always": "常時",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to cancel your changes?": "本当に編集内容を破棄しますか？",
    "Are you sure you want to clone this map and all its datalayers?": "すべてのデータレイヤを含むマップ全体を複製してよいですか？",
    "Are you sure you want to delete the feature?": "地物を削除してよいですか？",
    "Are you sure you want to delete this layer?": "本当にこのレイヤを削除してよいですか？",
    "Are you sure you want to delete this map?": "本当にこのマップを削除してよいですか？",
    "Are you sure you want to delete this property on all the features?": "すべての地物からこのプロパティを削除します。よろしいですか？",
    "Are you sure you want to restore this version?": "本当にこのバージョンを復元してよいですか？",
    "Attach the map to my account": "マップを自分のアカウントに関連付ける",
    "attribution": "著作権表示",
    "Auto": "自動",
    "Automatic": "自動",
    "Autostart when map is loaded": "マップ読み込み時に自動で開始",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "まち針",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "データ内容表示",
    "by": "by",
    "Cache proxied request": "Cache proxied request",
    "Cancel edits": "編集を破棄",
    "Caption": "表題",
    "Center map on your location": "閲覧者の位置をマップの中心に設定",
    "Change map background": "背景地図を変更",
    "Change tilelayers": "タイルレイヤの変更",
    "Change": "Change",
    "Choose the data format": "データ形式選択",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "円形",
    "clear": "クリア",
    "Click last point to finish shape": "クリックでシェイプの作成を終了",
    "Click to add a marker": "クリックでマーカー追加",
    "Click to continue drawing": "クリックで描画を継続",
    "Click to edit": "クリックで編集",
    "Click to start drawing a line": "クリックでラインの描画開始",
    "Click to start drawing a polygon": "クリックでポリゴンの描画開始",
    "Clone of {name}": "{name}の複製",
    "Clone this feature": "この地物を複製",
    "Clone this map": "マップを複製",
    "Clone": "複製",
    "Close": "閉じる",
    "Clustered": "クラスタ化",
    "Clustering radius": "クラスタ包括半径",
    "collapsed": "ボタン",
    "color": "色",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "カンマ、タブ、セミコロンなどで区切られた値。SRSはWGS84が適用されます。ポイントのジオメトリのみがインポート対象です。インポートを行なう際は、カラムの先頭行を対象に «lat» と «lon» という文字列が検索されます。検索は行の最初から順に行われ、大文字と小文字は区別されません。その他のすべてのカラムは、プロパティとしてインポートされます。",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "ラインを延長",
    "Coordinates": "位置情報",
    "copy": "copy",
    "Credits": "制作",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "デフォルトのマップ表示から現在の表示に切り替えますか？",
    "Custom background": "独自背景",
    "Custom overlay": "Custom overlay",
    "dash array": "破線表示",
    "Data is browsable": "Data is browsable",
    "Datalayers": "Datalayers",
    "Default interaction options": "標準のポップアップオプション",
    "Default properties": "標準のプロパティ",
    "Default shape properties": "標準のシェイプ表示プロパティ",
    "Default view": "Default view",
    "Default zoom level": "標準ズームレベル",
    "Default": "デフォルト",
    "Default: name": "デフォルト: 名称",
    "Define link to open in a new window on polygon click.": "ポリゴンクリック時にリンクを新しいウィンドウで開く",
    "define": "指定",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete layer": "レイヤを削除",
    "Delete this feature": "地物を削除",
    "Delete this shape": "このシェイプを削除",
    "Delete this vertex (Alt+Click)": "このポイントを削除(Altを押しながらクリック)",
    "Delete": "削除",
    "description": "概要",
    "Direct link": "Direct link",
    "Directions from here": "ここからの距離",
    "Display label": "ラベルを表示",
    "Display measure": "Display measure",
    "display name": "表示名",
    "Display on load": "読み込み時に表示",
    "Display the control to open OpenStreetMap editor": "OpenStreetMapエディタを起動するパネルを表示",
    "Display the embed control": "サイトへのマップ埋め込みパネルを表示",
    "Display the fullscreen control": "フルスクリーンパネルを表示",
    "Display the locate control": "現在地パネルを表示",
    "Display the measure control": "縮尺パネルを表示",
    "Display the search control": "検索パネルを表示",
    "Display the star map button": "Display the star map button",
    "Display the tile layers control": "タイルレイヤパネルを表示",
    "Display the zoom control": "ズーム変更パネルを表示",
    "Do you want to display a caption bar?": "表題を表示しますか？",
    "Do you want to display a minimap?": "ミニマップを表示しますか？",
    "Do you want to display a panel on load?": "読み込み時にパネルを表示しますか？",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "フッタをポップアップしますか？",
    "Do you want to display the scale control?": "縮尺を表示しますか？",
    "Do you want to display the «more» control?": "«more»操作パネルを表示しますか？",
    "Download": "ダンロード",
    "Drag to reorder": "ドラッグして並べ替える",
    "Draw a marker": "マーカーを配置",
    "Draw a polygon": "ポリゴンを描く",
    "Draw a polyline": "ポリゴンを描く",
    "Drawing": "Drawing",
    "Drop": "しずく型",
    "Dynamic properties": "動的なプロパティ",
    "Dynamic": "ダイナミック",
    "Edit feature's layer": "地物レイヤー編集",
    "Edit properties in a table": "表形式でプロパティを編集",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "地物を編集",
    "Edit": "編集",
    "Embed and link options": "Embed and link options",
    "Embed the map": "マップ埋め込み",
    "Emoji & Character": "Emoji & Character",
    "Empty": "内容なし",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "タイルレイヤのURLに誤りがあります",
    "Exit Fullscreen": "フルスクリーン表示を解除",
    "expanded": "リスト",
    "Extract shape to separate feature": "シェイプを複数の地物に変換",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "地図表示が変更されたらデータを再取得する",
    "fill color": "塗りつぶし色",
    "fill opacity": "塗りつぶし透過度",
    "fill": "塗りつぶし",
    "Fit all data": "Fit all data",
    "Format": "フォーマット",
    "From zoom": "表示開始するズームレベル",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (リンクのみ)",
    "GeoRSS (title + image)": "GeoRSS (タイトル+画像)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "«{feature}»を表示",
    "Heatmap intensity property": "ヒートマップ強調設定",
    "Heatmap radius": "ヒートマップ包括半径",
    "Heatmap": "ヒートマップ",
    "height": "縦幅",
    "Help": "ヘルプ",
    "hidden": "隠す",
    "Hide controls": "操作パネルを非表示",
    "Home": "ホーム",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "各ズームレベルでのポリゴン簡略化 (more = パフォーマンスと滑らかさ重視, less = 正確さ重視)",
    "icon opacity": "icon opacity",
    "Icon shape": "アイコン形状",
    "Icon symbol": "アイコンシンボル",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframeの縦幅を指定(ピクセル): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframeの縦幅および横幅を指定(ピクセル): {{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "画像の横幅カスタム値 (px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "画像:  {{http://image.url.com}}",
    "Import data": "データインポート",
    "Import in a new layer": "新規レイヤをインポート",
    "Imports all umap data, including layers and settings.": "umapのデータをすべてインポート(レイヤ、設定を含む)",
    "Include full screen link?": "フルスクリーンのリンクを含める？",
    "Inherit": "属性継承",
    "inherit": "属性継承",
    "Interaction options": "ポップアップオプション",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "{filename} に不正なumapデータ",
    "Invalid umap data": "不正なumapデータ",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "現在表示しているレイヤを保持",
    "kilometers": "キロメートル",
    "km": "km",
    "Label direction": "ラベルの位置",
    "Label key": "ラベル表示するキー",
    "Labels are clickable": "ラベルをクリックしてポップアップを表示",
    "Latest feature": "Latest feature",
    "Latitude": "緯度",
    "Layer properties": "レイヤープロパティ",
    "Layer": "レイヤ",
    "Licence": "ライセンス",
    "licence": "ライセンス",
    "Limit bounds": "表示範囲の制限",
    "Link to view the map": "Link to view the map",
    "Link to…": "リンク",
    "Link with text: [[http://example.com|text of the link]]": "テキストとリンク: [[http://example.com|リンクのテキスト]]",
    "Long credits": "正式なクレジット",
    "Longitude": "経度",
    "Make main shape": "メインシェイプを作成",
    "Manage layers": "レイヤ管理",
    "Manual": "Manual",
    "Map background credits": "背景地図クレジット",
    "Map has been attached to your account": "あなたのアカウントにマップが関連付けられました",
    "Map has been saved!": "地図の保存完了",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "マップユーザコンテンツのライセンス",
    "Map's editors": "マップの編集者",
    "Map's owner": "マップの所有者",
    "max East": "東端",
    "max North": "北端",
    "max South": "南端",
    "max West": "西端",
    "max zoom": "最大ズーム",
    "Measure distances": "距離を計測",
    "Merge lines": "ラインを結合",
    "mi": "マイル",
    "miles": "マイル",
    "min zoom": "最小ズーム",
    "More controls": "詳細操作パネル",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "CSSで有効な値を指定してください (例: DarkBlue, #123456など)",
    "name": "名称",
    "nautical miles": "海里",
    "never": "表示しない",
    "new window": "新規ウィンドウ",
    "next": "次へ",
    "NM": "NM",
    "No cache": "No cache",
    "No licence has been set": "ライセンス指定がありません",
    "No results": "検索結果なし",
    "no": "いいえ",
    "No.": "No.",
    "None": "なし",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "下寄せ",
    "On the left": "左寄せ",
    "On the right": "右寄せ",
    "On the top": "上寄せ",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "透過度",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "リンクの開き方",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "現在表示中の領域をエディタで編集し、より正確なデータをOpenStreetMapへ書き込む",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "ヒートマップ強調表示オプション",
    "Optional. Same as color if not set.": "オプション。設定がない場合、色指定と同様",
    "Optional.": "Optional.",
    "Override clustering radius (default 80)": "クラスタ包括半径を上書き (基本値 80)",
    "Override heatmap radius (default 25)": "ヒートマップ包括半径を上書き (基本値 25)",
    "parent window": "親ウィンドウ",
    "Paste your data here": "Paste your data here",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "利用目的に沿ったライセンスを選択するようにしてください",
    "Please choose a format": "フォーマットを指定してください",
    "Please enter the name of the property": "プロパティの名称を入力してください",
    "Please enter the new name of this property": "このプロパティに新しい名称を付与してください",
    "Please save the map first": "Please save the map first",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup content template": "ポップアップコンテンツのテンプレート",
    "Popup shape": "Popup shape",
    "Popup": "Popup",
    "Powered by uMap": "Powered by uMap",
    "previous": "前へ",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "インポートされたプロパティ:",
    "Provide an URL here": "URLを入力してください",
    "Proxy request": "プロキシリクエスト",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "サイト外のデータ",
    "Remove shape from the multi": "マルチからシェイプを削除",
    "Replace layer content": "レイヤ内容を差し替える",
    "Restore this version": "このバージョンを復元する",
    "Save current edits": "編集内容を保存",
    "Save map": "Save map",
    "Save this center and zoom": "地図中心点とズームレベルを保存",
    "Save this location as new feature": "この場所を新しい地物として保存",
    "Save": "保存",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "地名で検索",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "フルスクリーン表示",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "settings": "settings",
    "Shape properties": "シェイプ表示プロパティ",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "短縮表示板クレジット",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "レイヤ表示/非表示",
    "Side panel": "サイドパネル",
    "Simple link: [[http://example.com]]": "シンプルリンク: [[http://example.com]]",
    "Simplify": "簡略化",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Slideshow": "スライドショー",
    "Sort key": "並び替えに使うキー",
    "Split line": "ラインを分割",
    "Star this map": "Star this map",
    "Start a hole here": "この部分に穴を作成",
    "Start slideshow": "スライドショーを開始",
    "Stop editing": "編集中断",
    "Stop slideshow": "スライドショーを停止",
    "Street": "Street",
    "stroke": "ストローク",
    "Supported scheme": "対応スキーマ",
    "Supported variables that will be dynamically replaced": "対応する動的な変数",
    "Symbol": "Symbol",
    "Table": "テーブル",
    "Text color for the cluster label": "クラスタラベルのテキスト色",
    "Text formatting": "テキスト形式",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "TMSフォーマット",
    "To use if remote server doesn't allow cross domain (slower)": "外部サーバがクロスドメインを許可していない場合に使用します (処理速度低下)",
    "To zoom": "非表示にするズームレベル",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "シェイプを編集済み地物へ変換",
    "Transform to lines": "ラインへ変換",
    "Transform to polygon": "ポリゴンへ変換",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "レイヤタイプ",
    "Unable to detect format of file {filename}": "ファイル形式を認識できません {filename}",
    "Untitled layer": "名称未定レイヤ",
    "Untitled map": "名称未定マップ",
    "Update permissions and editors": "権限設定とエディタを更新",
    "Update permissions": "権限設定を更新",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "現在の表示範囲を利用",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "波括弧で地物プロパティをくくると(例： &#123;name&#125;)、対応する値に動的に置き換えられます。",
    "User content credits": "ユーザ作成データのクレジット",
    "User interface options": "ユーザインターフェースオプション",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "バージョン",
    "View Fullscreen": "フルスクリーン表示",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "線の太さ",
    "Where do we go from here?": "ここからどこへ向かいますか？",
    "Whether to display or not polygons paths.": "ポリゴンの外周線を表示するかどうか",
    "Whether to fill polygons with color.": "ポリゴンを塗りつぶすかどうか",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "編集できる人",
    "Who can view": "閲覧できる人",
    "width": "横幅",
    "Will be displayed in the bottom right corner of the map": "地図の右下に表示されます",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "地図の脚注として表示されます",
    "yes": "はい",
    "Zoom in": "ズームイン",
    "Zoom level for automatic zooms": "自動ズーム時のズームレベル",
    "Zoom out": "ズームアウト",
    "Zoom to layer extent": "データがある位置を表示",
    "Zoom to the next": "次にズーム",
    "Zoom to the previous": "前にズーム",
    "Zoom to this feature": "この地物にズーム",
    "Zoom to this place": "この場所にズーム",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "インポートで {count} 個のエラー: {message}",
    "{delay} seconds": "{delay} seconds",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Import helpers:": "Import helpers:",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "My Dashboard ({username})": "My Dashboard ({username})",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control"
}
L.registerLocale("ja", locale)
L.setLocale("ja")
