const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# un cancelleto per l'intestazione principale",
    "## two hashes for second heading": "## due cancelletti per le intestazioni di secondo livello",
    "### three hashes for third heading": "### tre cancelletti per intestazione di terzo livello",
    "**double star for bold**": "**due asterischi per il testo marcato**",
    "*single star for italic*": "*un solo asterisco per il corsivo*",
    "--- for a horizontal rule": "--- per una linea orizzontale",
    "1 day": "1 giorno",
    "1 hour": "1 ora",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Una lista di numeri separati da virgola che definisce lo schema del tratto e del trattino. Es.: \"5, 10, 15\".",
    "About": "Informazioni",
    "Action not allowed :(": "Azione non permessa :(",
    "Activate slideshow mode": "Attiva la modalità presentazione",
    "Add a layer": "Aggiungi un layer",
    "Add a line to the current multi": "Aggiungi una linea a quelle correnti",
    "Add a new property": "Aggiungi una nuova proprietà",
    "Add a polygon to the current multi": "Aggiungi un poligono a quell correnti",
    "Add image URL": "Aggiungi URL immagine",
    "Add": "Aggiungi",
    "Advanced actions": "Azioni avanzate",
    "Advanced properties": "Proprietà avanzate",
    "All data and settings of the map": "Tutti i dati e le impostazioni della mappa",
    "All properties are imported.": "Tutte le proprietà sono state importate.",
    "Allow interactions": "Permetti interazioni",
    "Allow scroll wheel zoom?": "Abilitare la rotellina del mouse per lo zoom?",
    "always": "sempre",
    "Animated transitions": "Transizioni animate",
    "Are you sure you want to cancel your changes?": "Vuoi realmente annullare le modifiche fatte?",
    "Are you sure you want to clone this map and all its datalayers?": "Confermi di duplicare questa mappa e tutti i suoi livelli?",
    "Are you sure you want to delete the feature?": "Si è sicuri di voler cancellare questo oggetto?",
    "Are you sure you want to delete this layer?": "Si è certi di volere eliminare questo livello?",
    "Are you sure you want to delete this map?": "Si è certi di voler eliminare questa mappa?",
    "Are you sure you want to delete this property on all the features?": "Si è sicuri di voler cancellare questa proprietà per tutti gli oggetti?",
    "Are you sure you want to restore this version?": "Si vuole veramente ripristinare questa versione?",
    "Attach the map to my account": "Collega la mappa al mio account",
    "attribution": "attribuzione",
    "Auto": "Auto",
    "Automatic": "Automatico",
    "Autostart when map is loaded": "Partenza automatica una volta che la mappa è stata caricata",
    "Back to preview": "Torna all’anteprima",
    "Background overlay url": "URL sfondo in sovrapposizione",
    "Ball": "Palla",
    "Bring feature to center": "Sposta l’oggetto al centro",
    "Browse data": "Visualizza i dati",
    "by": "di",
    "Cache proxied request": "Usa la cache per le richieste proxy",
    "Cancel edits": "Annulla le modifiche",
    "Caption": "Didascalia",
    "Center map on your location": "Centra la mappa sulla tua posizione",
    "Change map background": "Cambia la mappa di sfondo",
    "Change tilelayers": "Cambia i livelli di sfondo",
    "Change": "Cambia",
    "Choose the data format": "Scegli il formato dati",
    "Choropleth breakpoints": "Punti di interruzione coropletici",
    "Choropleth classes": "Classi coropletiche",
    "Choropleth color palette": "Palett dei colori coropletici",
    "Choropleth mode": "Modo coropletico",
    "Choropleth property value": "Valore della proprietà coropletica",
    "Choropleth": "Coropletica",
    "Circle": "Cerchio",
    "clear": "pulisci",
    "Click last point to finish shape": "Click su ultimo punto per completare la geometria",
    "Click to add a marker": "Clicca per aggiungere un marcatore",
    "Click to continue drawing": "Clic per continuare a disegnare",
    "Click to edit": "Clic per la modifica",
    "Click to start drawing a line": "Clic per iniziare a disegnare una linea",
    "Click to start drawing a polygon": "Clicca per iniziare a disegnare un poligono",
    "Clone of {name}": "Clone di {name}",
    "Clone this feature": "Duplica questo oggetto",
    "Clone this map": "Duplica questa mappa",
    "Clone": "Clona",
    "Close": "Chiudi",
    "Clustered": "Raggruppata",
    "Clustering radius": "Raggio del raggruppamento",
    "collapsed": "contratto",
    "color": "colore",
    "Comma separated list of numbers, including min and max values.": "Lista dei numeri separati da virgola, che includono i valori minimi e massimi",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Elenco di proprietà separate da virgole da utilizzare per l'ordinamento degli oggetti. Per invertire l'ordinamento, inserire prima un segno meno (-). Per esempio. miocampo-altrocampo.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Valori separati da virgola, tabulatore o punto e virgola. Il sistema di riferimento spaziale implementato è WGS84. Vengono importati solo punti. La funzione di importazione va a cercare nell'intestazione le colonne  «lat» e «lon» indifferentemente se scritte in maiuscolo o minuscolo. Tutte le altre colonne sono importate come proprietà.",
    "Congratulations, your map has been created!": "Complimenti, la tua mappa è stata creata!!!",
    "Continue line": "Linea continua",
    "Coordinates": "Coordinate",
    "copy": "copia",
    "Credits": "Ringraziamenti",
    "Current map view": "Vista della mappa corrente",
    "Current view instead of default map view?": "Vista attuale invece che quella della mappa preimpostata?",
    "Custom background": "Sfondo personalizzato",
    "Custom overlay": "Sovrapposizione personalizzata",
    "dash array": "tratteggio",
    "Data is browsable": "I dati sono consultabili",
    "Datalayers": "Strati di dati",
    "Default interaction options": "Opzioni di interazione predefinite",
    "Default properties": "Proprietà preimpostate",
    "Default shape properties": "Proprietà predefinite della forma",
    "Default view": "Vista predefinita",
    "Default zoom level": "Livello di zoom predefinito",
    "Default": "Predefinito",
    "Default: name": "Predefinito: nome",
    "Define link to open in a new window on polygon click.": "Definisci un link d'aprire in una nuova finestra al clic sul poligono.",
    "define": "definisci",
    "Delay between two transitions when in play mode": "Ritardo tra le due transizioni in modalità di riproduzione",
    "Delete layer": "Elimina layer",
    "Delete this feature": "Cancella questo oggetto",
    "Delete this shape": "Cancella questa forma",
    "Delete this vertex (Alt+Click)": "Elimina questo vertice (Alt+Clic)",
    "Delete": "Cancella",
    "description": "descrizione",
    "Direct link": "Link diretto",
    "Directions from here": "Indicazioni stradali da qui",
    "Display label": "Mostra etichetta",
    "Display measure": "Calcola le distanze",
    "display name": "visualizza il nome",
    "Display on load": "Mostra al caricamento",
    "Display the control to open OpenStreetMap editor": "Mostra il controllo per aprire l'editor di OpenStreetMap",
    "Display the embed control": "Visualizza il controllo per l'incorporamento",
    "Display the fullscreen control": "Visualizza il controllo di schermo intero",
    "Display the locate control": "Visualizza il controllo di localizzazione",
    "Display the measure control": "Visualizza il controllo di misurazione",
    "Display the search control": "Visualizza il controllo di ricerca",
    "Display the star map button": "Visualizza il pulsante per aggiungere una mappa come speciale",
    "Display the tile layers control": "Visualizza il controllo del livello delle tile",
    "Display the zoom control": "Visualizza il controllo di zoom",
    "Do you want to display a caption bar?": "Visualizzare una didascalia?",
    "Do you want to display a minimap?": "Visualizzare una mappa panoramica?",
    "Do you want to display a panel on load?": "Visualizza un panello al caricamento?",
    "Do you want to display caption menus?": "Si vuole visualizzare le etichette dei menu? ",
    "Do you want to display popup footer?": "Visualizzare la finestra di popup a piè pagina?",
    "Do you want to display the scale control?": "Visualizzare la scala?",
    "Do you want to display the «more» control?": "Vuoi visualizzare il controllo \"altro\"?",
    "Download": "Download",
    "Drag to reorder": "Trascina per riordinare",
    "Draw a marker": "Aggiungi un marcatore",
    "Draw a polygon": "Disegna un poligono",
    "Draw a polyline": "Disegna una polilinea",
    "Drawing": "Disegno",
    "Drop": "Goccia",
    "Dynamic properties": "Proprietà dinamiche",
    "Dynamic": "Dinamico",
    "Edit feature's layer": "Modifica gli oggetti del layer",
    "Edit properties in a table": "Modifica le proprietà in una tabella",
    "Edit the title of the map": "Modifica il titolo della mappa",
    "Edit this feature": "Modifica quest'oggetto",
    "Edit": "Modifica",
    "Embed and link options": "Opzioni di inclusione e collegamento",
    "Embed the map": "Includi la mappa",
    "Emoji & Character": "Emoji & caratteri",
    "Empty": "Vuoto",
    "Equidistant": "Equidistante",
    "Error in the overlay URL": "Errore nell'URL della sovrapposizione",
    "Error in the tilelayer URL": "Errore nell'URL nel servizio di tile",
    "Exit Fullscreen": "Esci da Schermo intero",
    "expanded": "espanso",
    "Extract shape to separate feature": "Dividi la geometria in oggetti separati",
    "Feature identifier key": "Campo di identificativo dell'oggetto",
    "Feature properties": "Proprietà dell'oggetto",
    "Fetch data each time map view changes.": "Recupera i dati ad ogni cambio della visualizzazione della mappa.",
    "fill color": "colore di riempimento",
    "fill opacity": "opacità riempimento",
    "fill": "riempimento",
    "Fit all data": "Adatta tutti i dati",
    "Format": "Formato",
    "From zoom": "Dallo zoom",
    "full backup": "backup completo",
    "Generic": "Generico",
    "GeoRSS (only link)": "GeoRSS (solo il link)",
    "GeoRSS (title + image)": "GeoRSS (titolo + immagine)",
    "Go to \"{coords}\"": "Vai a “{coords}”",
    "Go to the homepage": "Vai all’homepage",
    "Go to «{feature}»": "Vai a «{feature}»",
    "Heatmap intensity property": "Proprietà intensità mappa di densità",
    "Heatmap radius": "Raggio mappa di densità",
    "Heatmap": "Mappa di densità (heatmap)",
    "height": "altezza",
    "Help": "Aiuto",
    "hidden": "nascosto",
    "Hide controls": "Nascondi controlli",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Quanto vuoi semplificare la polilinea per ogni zoom (più = maggiori performance a aspetto più semplificato, meno = maggior dettaglio)",
    "icon opacity": "opacità dell'incona",
    "Icon shape": "Forma dell'icona",
    "Icon symbol": "Simbolo dell'icona",
    "If false, the polygon or line will act as a part of the underlying map.": "Se falso, il poligono o la linea si comporterà come parte della mappa sottostante.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe con altezza (in px) personalizzata: {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe con altezza e larghezza personalizzata (in px): {{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Immagine con larghezza personalizzata (width) (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Immagini: {{http://image.url.com}}",
    "Import data": "Importa dati",
    "Import in a new layer": "Importa in un nuovo layer",
    "Imports all umap data, including layers and settings.": "importa tutti i dati di umap compresi layer e le impostazioni",
    "Include full screen link?": "inserire link per la vista a schemo intero?",
    "Inherit": "Eredita",
    "inherit": "eredita",
    "Interaction options": "Opzioni di interazione",
    "Invalid latitude or longitude": "Latitudine o longitudine non corrette",
    "Invalid umap data in {filename}": "dati umap non validi nel file {filename}",
    "Invalid umap data": "dati di umap non validi",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Mantieni i layer attualmente visibili",
    "kilometers": "chilometri",
    "km": "km",
    "Label direction": "Direzione dell'etichetta",
    "Label key": "Campo etichetta",
    "Labels are clickable": "Etichette cliccabili",
    "Latest feature": "Ultimo oggetto",
    "Latitude": "Latitudine",
    "Layer properties": "Proprietà del layer",
    "Layer": "Layer",
    "Licence": "Licenza",
    "licence": "licenza",
    "Limit bounds": "Limiti di confine",
    "Link to view the map": "Collega per vedere la mappa",
    "Link to…": "Link a…",
    "Link with text: [[http://example.com|text of the link]]": "Link con testo: [[http://example.com|testo del link]]",
    "Long credits": "Ringraziamenti estesi",
    "Longitude": "Longitudine",
    "Make main shape": "Genera geometria generale",
    "Manage layers": "Gestisci layer",
    "Manual": "Manuale",
    "Map background credits": "Riconoscimenti per la mappa di sfondo",
    "Map has been attached to your account": "La mappa è stata associata al tuo account",
    "Map has been saved!": "La mappa è stata salvata",
    "Map has been starred": "La mappa è stata contrassegnata come speciale",
    "Map has been unstarred": "La mappa è stata rimossa dalle speciali",
    "Map user content has been published under licence": "I contenuti della mappa sono rilasciati secondo la licenza",
    "Map's editors": "Contributori alla mappa",
    "Map's owner": "Proprietario della mappa",
    "max East": "max Est",
    "max North": "max Nord",
    "max South": "max Sud",
    "max West": "max Ovest",
    "max zoom": "zoom massimo",
    "Measure distances": "Misura le distanze",
    "Merge lines": "Unisci linee",
    "mi": "mi",
    "miles": "miglia",
    "min zoom": "zoom minimo",
    "More controls": "Maggiori controlli",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Deve avere un valore CSS valido (es.: DarkBlue o #123456)",
    "name": "nome",
    "nautical miles": "miglia nautiche",
    "never": "mai",
    "new window": "nuova finestra",
    "next": "prossimo",
    "NM": "NM",
    "No cache": "Nessuna cache",
    "No licence has been set": "Non è ancora stata impostata una licenza",
    "No results": "Nessun risultato",
    "no": "non",
    "No.": "No.",
    "None": "Nulla",
    "Number of desired classes (default 5)": "Numero di classi desiderate (default 5)",
    "On the bottom": "In basso",
    "On the left": "A sinistra",
    "On the right": "A destra",
    "On the top": "In alto",
    "Only visible layers' data": "Solo i dati dei livelli visibili",
    "opacity": "opacità",
    "Opacity": "Opacità",
    "Open current feature on load": "Apri l'oggetto attuale al caricamento",
    "Open link in…": "Apri link in…",
    "Open share & download panel": "Apri pannello di condivisione & scarico",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Apri quest'area della mappa nell'editor in modo da fornire dati più accurati in OpenStreeetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Proprietà opzionale per la mappa di densità",
    "Optional. Same as color if not set.": "Opzionale. Stesso colore se non assegnato.",
    "Optional.": "Opzionale.",
    "Override clustering radius (default 80)": "Sovrascrivi raggio di raggruppamento (predefinito 80)",
    "Override heatmap radius (default 25)": "Sovrascrivi raggio mappa di intensità (predefinito 25)",
    "parent window": "finestra di origine",
    "Paste your data here": "Incolla i tuoi dati qui",
    "Permalink": "Link permanente",
    "Permanent credits background": "Sfondo ringraziamenti permanenti",
    "Permanent credits": "Ringraziamenti permanenti",
    "Please be sure the licence is compliant with your use.": "Si prega di verificare che la licenza è compatibile con quella in uso.",
    "Please choose a format": "Scegliere un formato",
    "Please enter the name of the property": "Inserire il nome della proprietà",
    "Please enter the new name of this property": "Inserire il nuovo nome per questa proprietà",
    "Please save the map first": "Per favore prima salva la mappa",
    "Popup (large)": "Popup (grande)",
    "Popup content style": "Stile del contenuto del Popup",
    "Popup content template": "Modello del contenuto del popup",
    "Popup shape": "Forma del Popup",
    "Popup": "Popup",
    "Powered by uMap": "Alimentato da uMap",
    "previous": "precedente",
    "Problem in the response": "Problema nella risposta",
    "Properties imported:": "Proprietà importate:",
    "Provide an URL here": "Aggiungi una URL qui",
    "Proxy request": "Richiesta proxy",
    "Quantiles": "Quantili",
    "Recent": "Recente",
    "Remote data": "Dati remoti",
    "Remove shape from the multi": "Rimuovi geometria dalle altre",
    "Replace layer content": "Sostituisci il contenuto del layer",
    "Restore this version": "Ripristina questa versione",
    "Save current edits": "Salva le modifiche effettuate",
    "Save map": "Salva mappa",
    "Save this center and zoom": "Salva il centro e lo zoom",
    "Save this location as new feature": "Salva questa posizione come nuovo oggetto",
    "Save": "Salva",
    "Saved center and zoom": "Centro e zoom salvati",
    "Search location": "Cerca un luogo",
    "Search": "Ricerca",
    "Secret edit link:": "Link segreto per editare:",
    "See full screen": "Visualizza a schermo intero",
    "See on OpenStreetMap": "Vedi su OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Impostalo su false per nascondere questo layer dalla presentazione, dal browser dati, dalla navigazione popup...",
    "settings": "impostazioni",
    "Shape properties": "Proprietà della geometria",
    "Share and download": "Condividi e scarica",
    "Share this link to open a customized map view": "Condividi questo link per aprire una vista personalizzata della mappa",
    "Short credits": "Mostra i ringraziamenti",
    "Short link": "Collegamento corto",
    "Show this layer in the caption": "Mostra questo livello nella didascalia",
    "Show/hide layer": "Mostra/nascondi layer",
    "Side panel": "Pannello laterale",
    "Simple link: [[http://example.com]]": "Link semplice: [[http://example.com]]",
    "Simplify": "Semplifica",
    "Skipping unknown geometry.type: {type}": "Salta le geometrie sconosciute di tipo: {type}",
    "Slideshow": "Presentazione",
    "Sort key": "Campo di ordinamento",
    "Split line": "Dividi linea",
    "Star this map": "Segna come mappa speciale",
    "Start a hole here": "Comincia un buco qui",
    "Start slideshow": "Avvia presentazione",
    "Stop editing": "Ferma la modifica",
    "Stop slideshow": "Ferma presentazione",
    "Street": "Strada",
    "stroke": "tratto",
    "Supported scheme": "Schema supportato",
    "Supported variables that will be dynamically replaced": "Variabili supportate che verranno cambiate dinamicamente",
    "Symbol": "Simbolo",
    "Table": "Tabella",
    "Text color for the cluster label": "Colore di testo per l'etichetta del raggruppamento",
    "Text formatting": "Formattazione testo",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "Nome della proprietà da utilizzare come identificatore univoco per ogni oggetto.",
    "The zoom and center have been modified.": "Lo zoom e il centro sono stati modificati",
    "TMS format": "formato TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Da utilizzare se il server remoto non permette l'accesso incrociato ai domini (lento)",
    "To zoom": "Allo zoom",
    "Toggle edit mode (⇧+Click)": "Attiva/disattiva la modalità di modifica (⇧+clic)",
    "Toggle edit mode": "Commuta modalità di modifica",
    "Transfer shape to edited feature": "Trasforma la geometria in un oggetto modificabile",
    "Transform to lines": "Trasforma in linee",
    "Transform to polygon": "Trasforma in poligono",
    "Type a place name or coordinates": "Inserisci il nome di un luogo o delle coordinate",
    "Type char or paste emoji": "Inserisci carattere o incolla emoji",
    "Type of layer": "Tipo di layer",
    "Unable to detect format of file {filename}": "Impossibile individuare il formato del file {filename}",
    "Untitled layer": "Layer senza nome",
    "Untitled map": "Mappa senza nome",
    "Update permissions and editors": "Cambia i permessi e i contributori",
    "Update permissions": "Aggiorna autorizzazioni",
    "Update who can see and edit the map": "Cambia chi può vedere e modificare la mappa",
    "Url": "Url",
    "URL": "URL",
    "Use current bounds": "Utilizza l'area in uso",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Specificando le proprietà dell'oggetto attraverso le parentesi graffe es. &#123;name&#125; queste saranno automaticamente sostituite con i valori corrispondenti",
    "User content credits": "Riconoscimenti ai contenuti utente",
    "User interface options": "Opzioni interfaccia utente",
    "User location": "Posizione dell'utente",
    "Verify remote URL": "Verifica URL remota",
    "Versions": "Versioni",
    "View Fullscreen": "Visualizza a schermo intero",
    "View": "Vedi",
    "Visibility: {status}": "Visibilità: {status}",
    "weight": "peso",
    "Where do we go from here?": "Da dove ci spostiamo da qui?",
    "Whether to display or not polygons paths.": "Indica se visualizzare o meno i lati dei poligoni.",
    "Whether to fill polygons with color.": "Indica se riempire i poligoni con il colore.",
    "Who can edit \"{layer}\"": "Chi può editare \"{layer}\"",
    "Who can edit": "Chi può modificare",
    "Who can view": "Chi può vedere",
    "width": "larghezza",
    "Will be displayed in the bottom right corner of the map": "Sarà visualizzato in un angolo in basso a destra sulla mappa",
    "Will be permanently visible in the bottom left corner of the map": "Sarà permanentemente visibile nell'angolo in basso a sinistra della mappa",
    "Will be visible in the caption of the map": "Sarà visibile nella didascalia della mappa",
    "yes": "sì",
    "Zoom in": "Ingrandisci",
    "Zoom level for automatic zooms": "Livelli di zoom per zoom automatici",
    "Zoom out": "Rimpicciolisci",
    "Zoom to layer extent": "Zoom alla larghezza massima del layer",
    "Zoom to the next": "Zoom sul prossimo",
    "Zoom to the previous": "Zoom sul precedente",
    "Zoom to this feature": "Zoom su questo oggetto",
    "Zoom to this place": "Zoom in questo posto",
    "{area}&#8239;acres": "{area} acri",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} errori durante l'importazione: {message}",
    "{delay} seconds": "{ritardo} secondi",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miglia",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Import helpers:": "Import helpers:",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "My Dashboard ({username})": "My Dashboard ({username})",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control"
}
L.registerLocale("it", locale)
L.setLocale("it")
