header {
    margin: 14px 0;
}

footer {
    min-height: 140px;
    margin-top: 40px;
    background-color: var(--color-darkBlue);
    color: var(--color-light);
    display: flex;
    align-items: center;
    justify-content: space-evenly;
    flex-wrap: wrap;
}
footer a {
    color: var(--color-light);
    text-decoration: underline;
}
footer a.branding {
    background-image: url("./img/logo_filigree.png");
    background-position: left center;
    background-repeat: no-repeat;
    background-size: 60px auto;
    font-size: 30px;
    height: 60px;
    line-height: 60px;
    font-weight: bold;
    padding-inline-start: 70px;
    display: inline-block;
}
html[dir="rtl"] footer a.branding {
  background-position: right center;
}

footer .i18n_switch {
    display: inline-block;
}


.umap-nav {
    display: flex;
    flex-direction: column;
}
.umap-nav a {
    color: var(--color-darkBlue);
    padding: .4rem;
}
.umap-nav a:hover {
    text-decoration: underline;
}
.umap-nav h1 {
    margin-bottom: 0;
}
.umap-nav h1 a {
    background-image: url("./img/logo.svg");
    background-position: left center;
    background-repeat: no-repeat;
    background-size: 60px auto;
    line-height: 70px;
    padding-inline-start: 80px;
    display: block;
    font-size: 2.5rem;
}
html[dir="rtl"] .umap-nav h1 a {
  background-position: right center;
}
.umap-nav ul {
    text-align: center;
    font-weight: bold;
}
.umap-nav ul li {
    line-height: 2.5rem;
}
.umap-nav .button,
.umap-nav .button:hover {
    text-decoration: none;
    min-width: 150px;
    margin-inline-start: 1rem;
}

@media only screen and (min-width: 500px) {
    .umap-nav ul li {
        display: inline-block;
    }
}
@media only screen and (min-width: 750px) {
    .umap-nav {
        flex-direction: row;
        justify-content: space-between;
        align-items: baseline;
    }
}
