{% load umap_tags %}

{% include "umap/messages.html" %}
<div id="map">
</div>
<!-- djlint:off -->
<script defer type="text/javascript">
  window.addEventListener('DOMContentLoaded', (event) => {
    U.MAP = new U.Map("map", {{ map_settings|notag|safe }})
  })
</script>
<!-- djlint:on -->
