{% load static %}

<link rel="stylesheet"
      href="{% static 'umap/vendors/leaflet/leaflet.css' %}" />
<link rel="stylesheet"
      href="{% static 'umap/vendors/markercluster/MarkerCluster.css' %}" />
<link rel="stylesheet"
      href="{% static 'umap/vendors/markercluster/MarkerCluster.Default.css' %}" />
<link rel="stylesheet"
      href="{% static 'umap/vendors/editinosm/Leaflet.EditInOSM.css' %}" />
<link rel="stylesheet"
      href="{% static 'umap/vendors/minimap/Control.MiniMap.min.css' %}" />
<link rel="stylesheet"
      href="{% static 'umap/vendors/toolbar/leaflet.toolbar.css' %}" />
<link rel="stylesheet"
      href="{% static 'umap/vendors/measurable/Leaflet.Measurable.css' %}" />
<link rel="stylesheet"
      href="{% static 'umap/vendors/fullscreen/leaflet.fullscreen.css' %}" />
<link rel="stylesheet"
      href="{% static 'umap/vendors/locatecontrol/L.Control.Locate.min.css' %}" />
<link rel="stylesheet"
      href="{% static 'umap/vendors/iconlayers/iconLayers.css' %}" />
<link rel="stylesheet" href="{% static 'umap/vars.css' %}" />
<link rel="stylesheet" href="{% static 'umap/font.css' %}" />
<link rel="stylesheet" href="{% static 'umap/css/icon.css' %}" />
<link rel="stylesheet" href="{% static 'umap/base.css' %}" />
<link rel="stylesheet" href="{% static 'umap/content.css' %}" />
<link rel="stylesheet" href="{% static 'umap/nav.css' %}" />
<link rel="stylesheet" href="{% static 'umap/map.css' %}" />
<link rel="stylesheet" href="{% static 'umap/css/slideshow.css' %}" />
<link rel="stylesheet" href="{% static 'umap/css/contextmenu.css' %}" />
<link rel="stylesheet" href="{% static 'umap/css/panel.css' %}" />
<link rel="stylesheet" href="{% static 'umap/css/window.css' %}" />
<link rel="stylesheet" href="{% static 'umap/css/tooltip.css' %}" />
<link rel="stylesheet" href="{% static 'umap/css/dialog.css' %}" />
<link rel="stylesheet" href="{% static 'umap/css/importers.css' %}" />
<link rel="stylesheet" href="{% static 'umap/css/tableeditor.css' %}" />
<link rel="stylesheet" href="{% static 'umap/theme.css' %}" />
