const locale = {
    "(area: {measure})": "(obszar: {measure})",
    "(length: {measure})": "(długość: {measure})",
    "# one hash for main heading": "# jeden krzyżyk – nagłówek pierwszego poziomu",
    "## two hashes for second heading": "## dwa krzyżyki – nagłówek drugiego poziomu",
    "### three hashes for third heading": "### trzy krzyżyki – nagłówek trzeciego poziomu",
    "**double star for bold**": "**podwójna gwiazdka do pogrubienia**",
    "*single star for italic*": "*pojedyncza gwiazdka dla kursywy*",
    "--- for a horizontal rule": "Pozioma linia: ---",
    "1 day": "1 dzień",
    "1 hour": "1 godzina",
    "5 min": "5 minut",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Rozdzielona przecinkami lista liczb, która definiuje wzór kreski linii, np. „5, 10, 15”.",
    "About": "Informacje",
    "Action not allowed :(": "Operacja niedozwolona :(",
    "Activate slideshow mode": "Aktywuj pokaz slajdów",
    "Add a layer": "Dodaj warstwę",
    "Add a line to the current multi": "Dodaj linię do wybranego obszaru",
    "Add a new property": "Dodaj nową właściwość",
    "Add a polygon to the current multi": "Dodaj wielobok do wybranego obszaru",
    "Add image URL": "Dodaj URL obrazka",
    "Add": "Dodawać",
    "Advanced actions": "Zaawansowane operacje",
    "Advanced properties": "Zaawansowane właściwości",
    "All data and settings of the map": "Wszystkie dane i ustawienia mapy",
    "All properties are imported.": "Importowane są wszystkie właściwości.",
    "Allow interactions": "Zezwalaj na interakcję",
    "Allow scroll wheel zoom?": "Pozwalać na przybliżanie kółkiem?",
    "always": "zawsze",
    "Animated transitions": "Animowane przejścia",
    "Are you sure you want to cancel your changes?": "Na pewno chcesz porzucić swoje zmiany?",
    "Are you sure you want to clone this map and all its datalayers?": "Na pewno chcesz sklonować tę mapę razem z jej warstwami?",
    "Are you sure you want to delete the feature?": "Na pewno chcesz usunąć ten obiekt?",
    "Are you sure you want to delete this layer?": "Na pewno chcesz usunąć tę warstwę?",
    "Are you sure you want to delete this map?": "Na pewno chcesz usunąć tą mapę?",
    "Are you sure you want to delete this property on all the features?": "Na pewno chcesz usunąć tę właściwość we wszystkich obiektach?",
    "Are you sure you want to restore this version?": "Na pewno chcesz przywrócić tę wersję?",
    "Attach the map to my account": "Dołącz mapę do mojego konta",
    "attribution": "oznaczenie autorstwa",
    "Auto": "Auto",
    "Automatic": "Automatyczny",
    "Autostart when map is loaded": "Autostart po załadowaniu mapy",
    "Back to preview": "Z powrotem do podglądu",
    "Background overlay url": "Background overlay url",
    "Ball": "Pinezka",
    "Bring feature to center": "Przesuń obiekt na środek",
    "Browse data": "Przeglądaj dane",
    "by": " ",
    "Cache proxied request": "Zapytanie pośredniczące pamięci podręcznej",
    "Cancel edits": "Anuluj edycje",
    "Caption": "Podpis",
    "Center map on your location": "Wyśrodkuj mapę na twojej lokalizacji",
    "Change map background": "Zmień podkład mapy",
    "Change tilelayers": "Zmień podkład",
    "Change": "Zmiana",
    "Choose the data format": "Wybierz format danych",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Kartogram",
    "Circle": "Kółko",
    "clear": "wyczyść",
    "Click last point to finish shape": "Kliknij ostatni punkt, aby zakończyć rysowanie",
    "Click to add a marker": "Kliknij, aby dodać znacznik",
    "Click to continue drawing": "Kliknij, aby kontynuować rysowanie",
    "Click to edit": "Kliknij, aby edytować",
    "Click to start drawing a line": "Kliknij, aby zacząć rysować linię",
    "Click to start drawing a polygon": "Kliknij, aby zacząć rysować obszar",
    "Clone of {name}": "Sklonowane z {name}",
    "Clone this feature": "Sklonuj ten obiekt",
    "Clone this map": "Sklonuj mapę",
    "Clone": "Klonuj",
    "Close": "Zamknij",
    "Clustered": "Zgrupowane",
    "Clustering radius": "Promień grupowania",
    "collapsed": "zwinięty",
    "color": "kolor",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Wartości powinny być oddzielone przecinkiem, średnikiem lub znakiem tabulacji. Układ współrzędnych WGS84 jest wymagany. Tylko geometrie typu punkt zostaną zaimportowane. Import sprawdzi nagłówki kolumn czy zawierają „lat” i „lon” na początku nagłówka, wielkość liter nie ma znaczenia. Wszystkie inne kolumny zostaną zaimportowane jako właściwości tych punktów.",
    "Congratulations, your map has been created!": "Gratulacje, twoja mapa została utworzona!",
    "Continue line": "Kontynuuj linię",
    "Coordinates": "Współrzędne",
    "copy": "skopiuj",
    "Credits": "Źródło",
    "Current map view": "Bieżący widok mapy",
    "Current view instead of default map view?": "Obecny widok mapy zamiast domyślnego?",
    "Custom background": "Własne tło",
    "Custom overlay": "Własna nakładka",
    "dash array": "przerywana linia",
    "Data is browsable": "Dane można przeglądać",
    "Datalayers": "Warstwy danych",
    "Default interaction options": "Domyślne ustawienia interakcji",
    "Default properties": "Domyślne właściwości",
    "Default shape properties": "Domyślne właściwości kształtu",
    "Default view": "Domyślny widok",
    "Default zoom level": "Domyślne przybliżenie",
    "Default": "Domyślne",
    "Default: name": "Domyślnie: name",
    "Define link to open in a new window on polygon click.": "Ustaw odnośnik, który otworzy się w nowym oknie po kliknięciu wielokąta.",
    "define": "określ",
    "Delay between two transitions when in play mode": "Opóźnienie pomiędzy dwoma przejściami w trybie odtwarzania",
    "Delete layer": "Usuń warstwę",
    "Delete this feature": "Usuń ten obiekt",
    "Delete this shape": "Usuń tę figurę",
    "Delete this vertex (Alt+Click)": "Usuń ten wierzchołek (Alt+Klik)",
    "Delete": "Usuń",
    "description": "opis",
    "Direct link": "Bezpośredni link",
    "Directions from here": "Kierunki stąd",
    "Display label": "Wyświetl etykietę",
    "Display measure": "Wyświetl pomiar",
    "display name": "wyświetl nazwę",
    "Display on load": "Wyświetl przy ładowaniu",
    "Display the control to open OpenStreetMap editor": "Wyświetlaj panel otwierający edytor OSM",
    "Display the embed control": "Wyświetlaj panel sterujący osadzaniem",
    "Display the fullscreen control": "Wyświetlaj panel widoku pełnoekranowego",
    "Display the locate control": "Wyświetlaj panel lokalizacji",
    "Display the measure control": "Wyświetlaj panel miarek",
    "Display the search control": "Wyświetlaj panel wyszukiwania",
    "Display the star map button": "Display the star map button",
    "Display the tile layers control": "Wyświetlaj panel warstw kafelków",
    "Display the zoom control": "Wyświetlaj panel sterujący powiększeniem",
    "Do you want to display a caption bar?": "Wyświetlać pasek z nagłówkiem?",
    "Do you want to display a minimap?": "Wyświetlać minimapę?",
    "Do you want to display a panel on load?": "Wyświetlać panel po załadowaniu?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Wyświetlać stopkę dymku?",
    "Do you want to display the scale control?": "Wyświetlać kontrolkę ze skalą?",
    "Do you want to display the «more» control?": "Wyświetlać „więcej kontrolek”?",
    "Download": "Pobieranie",
    "Drag to reorder": "Przeciągnij, by zmienić kolejność",
    "Draw a marker": "Dodaj znacznik",
    "Draw a polygon": "Rysuj obszar",
    "Draw a polyline": "Rysuj linię",
    "Drawing": "Rysowanie",
    "Drop": "Kropla",
    "Dynamic properties": "Właściwości dynamiczne",
    "Dynamic": "Dynamiczne",
    "Edit feature's layer": "Edytuj warstwę z obiektami",
    "Edit properties in a table": "Edytuj właściwości w tabeli",
    "Edit the title of the map": "Edytuj nazwę mapy",
    "Edit this feature": "Edytuj ten obiekt",
    "Edit": "Edytuj",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Osadź mapę na stronie",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Wyczyść",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Błąd w adresie URL podkładu",
    "Exit Fullscreen": "Zamknij pełny ekran",
    "expanded": "rozwinięty",
    "Extract shape to separate feature": "Wydziel figurę jako odrębny obiekt",
    "Feature identifier key": "Klucz identyfikacyjny obiektu",
    "Feature properties": "Właściwości obiektu",
    "Fetch data each time map view changes.": "Załaduj dane za każdym razem, gdy zmienia się widok mapy.",
    "fill color": "kolor wypełnienia",
    "fill opacity": "stopień wypełnienia",
    "fill": "wypełnienie",
    "Fit all data": "Fit all data",
    "Format": "Format",
    "From zoom": "Od przybliżenia",
    "full backup": "pełna kopia zapasowa",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (tylko link)",
    "GeoRSS (title + image)": "GeoRSS (tytuł i obrazek)",
    "Go to \"{coords}\"": "Idź do \"{coords}\"",
    "Go to the homepage": "Idź do strony głównej",
    "Go to «{feature}»": "Idź do „{feature}”",
    "Heatmap intensity property": "Intensywność mapy cieplnej",
    "Heatmap radius": "Promień mapy cieplnej",
    "Heatmap": "Mapa cieplna",
    "height": "wysokość",
    "Help": "Pomoc",
    "hidden": "ukryte",
    "Hide controls": "Ukryj przyciski",
    "Home": "Strona główna",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Jak bardzo uprościć obszar na każdym poziomie przybliżenia (więcej = większa wydajność i gładki wygląd, mniej = większa dokładność)",
    "icon opacity": "nieprzezroczystość ikony",
    "Icon shape": "Kształt ikony",
    "Icon symbol": "Symbol ikony",
    "If false, the polygon or line will act as a part of the underlying map.": "Jeżeli fałsz, wielokąt lub linia będą zachowywały się jak część bazowej mapy.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Ramka z podaną wysokością (w pikselach) {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Ramka z podaną wysokością i szerokością (w pikselach): {{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Ramka: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Obrazek z własną szerokością (w pikselach) {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Obrazek: {{http://image.url.com}}",
    "Import data": "Importuj dane",
    "Import in a new layer": "Importuj do nowej warstwy",
    "Imports all umap data, including layers and settings.": "Import wszystkich danych umap, razem z warstwami i ustawieniami.",
    "Include full screen link?": "Dołączyć link do pełnego ekranu?",
    "Inherit": "Dziedziczne",
    "inherit": "dziedziczny",
    "Interaction options": "Opcje interakcji",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Niepoprawne dane umap w {filename}",
    "Invalid umap data": "Niepoprawne dane umap",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Zachowaj obecnie widoczne warstwy",
    "kilometers": "kilometry",
    "km": "km",
    "Label direction": "Kierunek etykiety",
    "Label key": "Klucz etykiety",
    "Labels are clickable": "Etykiety są klikalne",
    "Latest feature": "Najnowszy obiekt",
    "Latitude": "Szerokość geograficzna",
    "Layer properties": "Ustawienia warstwy",
    "Layer": "Warstwa",
    "Licence": "Licencja",
    "licence": "licencja",
    "Limit bounds": "Limit granic",
    "Link to view the map": "Link do oglądania mapy",
    "Link to…": "Łącze do...",
    "Link with text: [[http://example.com|text of the link]]": "Link z tekstem: [[http://example.com|tekst]]",
    "Long credits": "Długie źródło",
    "Longitude": "Długość geograficzna",
    "Make main shape": "Narysuj główny kształt",
    "Manage layers": "Zarządzaj warstwami",
    "Manual": "Manual",
    "Map background credits": "Źródło tła mapy",
    "Map has been attached to your account": "Mapa została dołączona do twojego konta",
    "Map has been saved!": "Mapa została zapisana!",
    "Map has been starred": "Mapa została oznaczona gwiazdką",
    "Map has been unstarred": "Mapa została usunięta z oznaczonych gwiazdką",
    "Map user content has been published under licence": "Zawartość mapy użytkownika została opublikowana pod licencją",
    "Map's editors": "Edytorzy mapy",
    "Map's owner": "Właściciel mapy",
    "max East": "granica wschodnia",
    "max North": "granica północna",
    "max South": "granica południowa",
    "max West": "granica zachodnia",
    "max zoom": "maksymalne powiększenie",
    "Measure distances": "Pomiar odległości",
    "Merge lines": "Połącz linie",
    "mi": "mi",
    "miles": "mile",
    "min zoom": "minimalne powiększenie",
    "More controls": "Więcej przycisków",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Musi być prawidłową wartością CSS (np. DarkBlue lub #123456)",
    "name": "nazwa",
    "nautical miles": "mile morskie",
    "never": "nigdy",
    "new window": "nowe okno",
    "next": "następne",
    "NM": "NM",
    "No cache": "Brak pamięci podręcznej",
    "No licence has been set": "Nie wybrano licencji",
    "No results": "Brak wyników",
    "no": "nie",
    "No.": "Nie.",
    "None": "Brak",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "Na dole",
    "On the left": "Po lewej",
    "On the right": "Po prawej",
    "On the top": "Na górze",
    "Only visible layers' data": "Tylko dane widocznych warstw",
    "opacity": "przeźroczystość",
    "Opacity": "Nieprzezroczystość",
    "Open current feature on load": "Otwórz bieżący obiekt po załadowaniu",
    "Open link in…": "Otwieraj odnośnik w...",
    "Open share & download panel": "Otwórz panel udostępniania i pobierania",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Otwórz ten zakres mapy w edytorze, by wprowadzić do OpenStreetMap dokładniejsze dane",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Opcjonalna intensywność mapy cieplnej",
    "Optional. Same as color if not set.": "Opcjonalne. Taki sam jak kolor, jeśli nie podano.",
    "Optional.": "Opcjonalnie.",
    "Override clustering radius (default 80)": "Nadpisz promień grupowania (domyślnie 80)",
    "Override heatmap radius (default 25)": "Nadpisz promień mapy cieplnej (domyślnie 25)",
    "parent window": "to samo okno",
    "Paste your data here": "Wklej tutaj swoje dane",
    "Permalink": "Bezpośredni odnośnik.",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Upewnij się, że korzystanie z tych danych jest zgodne z licencją.",
    "Please choose a format": "Wybierz format",
    "Please enter the name of the property": "Podaj nazwę właściwości",
    "Please enter the new name of this property": "Podaj nową nazwę tej właściwości",
    "Please save the map first": "Prosimy najpierw zapisać mapę",
    "Popup (large)": "Wyskakujące okienko (duże)",
    "Popup content style": "Styl zawartości wyskakującego okienka",
    "Popup content template": "Szablon treści dymku",
    "Popup shape": "Kształt wyskakującego okienka",
    "Popup": "Wyskakujące okienko",
    "Powered by uMap": "Napędzane przez uMap",
    "previous": "poprzednie",
    "Problem in the response": "Problem w odpowiedzi",
    "Properties imported:": "Importowane właściwości:",
    "Provide an URL here": "Wprowadź tutaj adres URL",
    "Proxy request": "Żądanie proxy",
    "Quantiles": "Kwantyle",
    "Recent": "Ostatnie",
    "Remote data": "Zdalne dane",
    "Remove shape from the multi": "Usuń figurę z wybranego obszaru",
    "Replace layer content": "Zamień zawartość warstwy",
    "Restore this version": "Przywróć tę wersję",
    "Save current edits": "Zapisz obecne edycje",
    "Save map": "Zapisz mapę",
    "Save this center and zoom": "Zapisz obecną pozycję i przybliżenie",
    "Save this location as new feature": "Zapisz to miejsce jako nowy obiekt",
    "Save": "Zapisz",
    "Saved center and zoom": "Zapisano pozycję i przybliżenie",
    "Search location": "Znajdź miejsce",
    "Search": "Szukaj",
    "Secret edit link:": "Sekretny odnośnik edycji:",
    "See full screen": "Pełny ekran",
    "See on OpenStreetMap": "Zobacz na OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Ustaw „OFF”, żeby ukryć tę warstwę z pokazu slajdów, przeglądarki danych i okienek nawigacji.",
    "settings": "ustawienia",
    "Shape properties": "Właściwości kształtu",
    "Share and download": "Udostępnianie i pobieranie",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Krótkie źródło",
    "Short link": "Krótki link",
    "Show this layer in the caption": "Pokaż tę warstwę w podpisie",
    "Show/hide layer": "Pokaż/ukryj warstwę",
    "Side panel": "Panel boczny",
    "Simple link: [[http://example.com]]": "Prosty link: [[http://example.com]]",
    "Simplify": "Uprość",
    "Skipping unknown geometry.type: {type}": "Pomijanie nieznanego rodzaju geometrii: {type}",
    "Slideshow": "Pokaz slajdów",
    "Sort key": "Klucz sortowania",
    "Split line": "Podziel linię",
    "Star this map": "Oznacz mapę gwiazdką",
    "Start a hole here": "Zacznij dziurę tutaj",
    "Start slideshow": "Rozpocznij pokaz",
    "Stop editing": "Zakończ edycję",
    "Stop slideshow": "Zakończ pokaz",
    "Street": "Ulica",
    "stroke": "obramowanie",
    "Supported scheme": "Obsługiwany schemat",
    "Supported variables that will be dynamically replaced": "Obsługiwane zmienne zostaną dynamicznie zamienione",
    "Symbol": "Symbol",
    "Table": "Tabela",
    "Text color for the cluster label": "Kolor tekstu etykiety grupy",
    "Text formatting": "Formatowanie tekstu",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "Nazwa właściwości używana jako unikalny identyfikator obiektu.",
    "The zoom and center have been modified.": "Przybliżenie i pozycja zostały zmienione.",
    "TMS format": "Format TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Używaj, jeśli zdalny serwer nie zezwala na cross domain (wolne)",
    "To zoom": "Przybliżać",
    "Toggle edit mode (⇧+Click)": "Przełącz tryb edycji (Shift+Klik)",
    "Toggle edit mode": "Przełącz tryb edycji",
    "Transfer shape to edited feature": "Dołącz figurę do edytowanego obiektu",
    "Transform to lines": "Przekształć na linie",
    "Transform to polygon": "Przekształć w wielokąt",
    "Type a place name or coordinates": "Wpisz nazwę miejsca lub współrzędne",
    "Type char or paste emoji": "Wpisz znak lub wklej emoji",
    "Type of layer": "Typ warstwy",
    "Unable to detect format of file {filename}": "Nie można wykryć formatu pliku {filename}",
    "Untitled layer": "Warstwa bez nazwy",
    "Untitled map": "Mapa bez nazwy",
    "Update permissions and editors": "Aktualizuj uprawnienia i edytorów",
    "Update permissions": "Zaktualizuj uprawnienia",
    "Update who can see and edit the map": "Zaktualizuj kto może zobaczyć i edytować mapę",
    "Url": "Adres URL",
    "URL": "URL",
    "Use current bounds": "Użyj bieżących granic",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Użyj nazw pól z właściwości obiektu w klamrach, np. &#123;name&#125;. Zostaną automatycznie zastąpione przez odpowiadające im wartości.",
    "User content credits": "Źródło treści użytkownika",
    "User interface options": "Opcje interfejsu",
    "User location": "Lokalizacja użytkownika",
    "Verify remote URL": "Zweryfikuj zdalny URL",
    "Versions": "Wersje",
    "View Fullscreen": "Włącz tryb pełnoekranowy",
    "View": "Przeglądaj",
    "Visibility: {status}": "Widoczność: {status}",
    "weight": "waga",
    "Where do we go from here?": "Gdzie można stąd pojechać?",
    "Whether to display or not polygons paths.": "Czy wyświetlać obrysy obszarów.",
    "Whether to fill polygons with color.": "Czy wypełniać obszary kolorem.",
    "Who can edit \"{layer}\"": "Kto może edytować \"{layer}\"",
    "Who can edit": "Kto może edytować",
    "Who can view": "Kto może zobaczyć",
    "width": "szerokość",
    "Will be displayed in the bottom right corner of the map": "Będzie wyświetlone w prawym dolnym rogu mapy",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Będzie widoczne w nagłówku mapy",
    "yes": "tak",
    "Zoom in": "Przybliż",
    "Zoom level for automatic zooms": "Poziom automatycznych przybliżeń",
    "Zoom out": "Oddal",
    "Zoom to layer extent": "Przybliż do warstwy",
    "Zoom to the next": "Przybliż do następnego",
    "Zoom to the previous": "Przybliż do poprzedniego",
    "Zoom to this feature": "Przybliż do tego obiektu",
    "Zoom to this place": "Przybliż do tego miejsca",
    "{area}&#8239;acres": "{area} akrów",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} jardów kwadratowych",
    "{count} errors during import: {message}": "{count} błędów podczas importu: {message}",
    "{delay} seconds": "{delay} sekund",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{odległość} m",
    "{distance}&#8239;miles": "{odległość} mil",
    "{distance}&#8239;NM": "{distance} Mm",
    "{distance}&#8239;yd": "{odległość} jardów",
    "Edit map name and caption": "Edytuj nazwę mapy i opis",
    "Map advanced properties": "Zaawansowane właściwości mapy",
    "Edit map details": "Edytuj właściwości mapy",
    "Back to browser": "Z powrotem do przeglądarki",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edytuj w OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Z powrotem do warstw",
    "Filters": "Filtry",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filtruj dane",
    "Search map features…": "Search map features…",
    "Reset all": "Resetuj wszystkie",
    "Open browser": "Otwórz przeglądarkę",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Twoja mapa została utworzona z anonimowego konta!",
    "Real-time collaboration": "Współpraca w czasie rzeczywistym",
    "Cannot parse data": "Nie można sparsować danych",
    "Start typing...": "Zacznij pisać...",
    "No result": "No result",
    "Data browser": "Przeglądarka danych",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "Więcej informacji o składni Overpass",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Wybierz dane",
    "Import helpers:": "Import helpers:",
    "Choose the format": "Wybierz format",
    "Choose the layer": "Wybierz warstwę",
    "Layer name": "Nazwa warstwy",
    "Choose import mode": "Wybierz tryb importu",
    "Copy into the layer": "Skopiuj do tej warstwy",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Warunek",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Czy na pewno chcesz usunąć tę regułę?",
    "empty rule": "pusta reguła",
    "Conditional style rules": "Reguły formatowania warunkowego",
    "Add rule": "Dodaj regułę",
    "Browser: data": "Przeglądarka: dane",
    "Browser: layers": "Przeglądarka: dane",
    "Browser: filters": "Przeglądarka: filtry",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Skopiowane!",
    "Choose a dataset": "Wybierz zbiór danych",
    "Choose this dataset": "Wybierz ten zbiór danych",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Wybierz motyw",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Wybierz te dane",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Wyrażenie",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Wprowadź nazwę obszaru lub pozostaw puste, aby załadować dane dla obecnego widoku mapy",
    "Data successfully imported!": "Pomyślnie zaimportowano dane!",
    "My Dashboard ({username})": "My Dashboard ({username})",
    "Clear data": "Wyczyść dane",
    "Remove layers": "Usuń warstwy",
    "Categorized": "Skategoryzowane",
    "Alphabetical": "Alfabetyczny",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Kategorie",
    "Comma separated list of categories.": "Lista kategorii rozdzielonych przecinkami.",
    "Categories mode": "Tryb kategorii",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Zmień nazwę tej kolumny",
    "Delete this column": "Usuń tę kolumnę",
    "Name “{name}” should not contain a dot.": "Nazwa “{name}” nie powinna zawierać kropki.",
    "This name already exists: “{name}”": "Ta nazwa już istnieje: “{name}”",
    "Delete selected rows": "Usuń wybrane wiersze",
    "Found {count} rows. Are you sure you want to delete all?": "Znaleziono {count} wierszy. Czy na pewno chcesz je wszystkie usunąć?",
    "Expression is empty": "Wyrażenie jest puste",
    "OK": "OK",
    "Cancel": "Anuluj",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control"
}
L.registerLocale("pl", locale)
L.setLocale("pl")
