const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# один шарп — заголовок",
    "## two hashes for second heading": "## два шарпа — подзаголовок",
    "### three hashes for third heading": "### три шарпа — подзаголовок 3-го уровня",
    "**double star for bold**": "**двойные звёздочки — полужирный**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 день",
    "1 hour": "1 час",
    "5 min": "5 мин",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Список значений, определяющих штрихи линии. Напр. «5, 10, 15».",
    "About": "Подробней",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Включить режим слайдшоу",
    "Add a layer": "Добавить слой",
    "Add a line to the current multi": "Добавить линию к текущему мультиполигону",
    "Add a new property": "Добавить новое свойство",
    "Add a polygon to the current multi": "Добавить полигон к текущему мультиполигону",
    "Add image URL": "Add image URL",
    "Add": "Add",
    "Advanced actions": "Дополнительные действия",
    "Advanced properties": "Дополнительные свойства",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Все свойства импортированы.",
    "Allow interactions": "Разрешить взаимодействие",
    "Allow scroll wheel zoom?": "Разрешить изменение масштаба колесом мыши?",
    "always": "всегда",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to cancel your changes?": "Вы уверены, что хотите отменить сделанные изменения?",
    "Are you sure you want to clone this map and all its datalayers?": "Вы уверены, что хотите скопировать эту карту и все её слои данных?",
    "Are you sure you want to delete the feature?": "Вы уверены, что хотите удалить объект?",
    "Are you sure you want to delete this layer?": "Вы уверены что хотите удалить этот слой?",
    "Are you sure you want to delete this map?": "Вы уверены, что хотите удалить карту?",
    "Are you sure you want to delete this property on all the features?": "Вы уверены, что хотите удалить это свойство у всех объектов?",
    "Are you sure you want to restore this version?": "Вы уверены, что хотите восстановить эту версию?",
    "Attach the map to my account": "Прикрепить карту к моей учётной записи",
    "attribution": "назначенные свойства",
    "Auto": "Автоматически",
    "Automatic": "Автоматически",
    "Autostart when map is loaded": "Автозапуск при открытии карты",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Булавка",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Просмотр данных",
    "by": "от",
    "Cache proxied request": "Кэшированный прокси-запрос",
    "Cancel edits": "Отменить правки",
    "Caption": "Заголовок",
    "Center map on your location": "Переместить карту в ваше местоположение",
    "Change map background": "Изменить подложку карты",
    "Change tilelayers": "Выбрать подложку",
    "Change": "Change",
    "Choose the data format": "Выберите формат данных",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Кружок",
    "clear": "очистить",
    "Click last point to finish shape": "Щёлкните на последней точке, чтобы завершить",
    "Click to add a marker": "Щёлкните, чтобы добавить метку",
    "Click to continue drawing": "Щёлкайте, чтобы продолжить рисование",
    "Click to edit": "Щёлкните, чтобы изменить",
    "Click to start drawing a line": "Щёлкните, чтобы начать рисование линии",
    "Click to start drawing a polygon": "Щёлкните, чтобы начать рисование полигона",
    "Clone of {name}": "Копия {name}",
    "Clone this feature": "Скопировать фигуру",
    "Clone this map": "Создать копию карты",
    "Clone": "Создать копию",
    "Close": "Закрыть",
    "Clustered": "Кластеризованный",
    "Clustering radius": "Радиус кластеризации",
    "collapsed": "Свёрнуто",
    "color": "цвет",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "В качестве разделителя используются запятые, табуляции и точки с запятой. Применяется датум WGS84. Импорт просматривает заголовок на наличие полей «lat» и «lon», регистр не имеет значения. Все остальные поля импортируются как свойства.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Продолжить линию",
    "Coordinates": "Координаты",
    "copy": "copy",
    "Credits": "Авторские права",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Использовать текущий вид вместо карты по умолчанию?",
    "Custom background": "Пользовательская подложка карты",
    "Custom overlay": "Custom overlay",
    "dash array": "штрихи",
    "Data is browsable": "Данные можно просматривать",
    "Datalayers": "Datalayers",
    "Default interaction options": "Параметры интерактивности по умолчанию",
    "Default properties": "Свойства по умолчанию",
    "Default shape properties": "Параметры фигуры по умолчанию",
    "Default view": "Default view",
    "Default zoom level": "Масштаб по умолчанию",
    "Default": "По умолчанию",
    "Default: name": "По умолчанию: название",
    "Define link to open in a new window on polygon click.": "Задайте адрес для открытия его в новом окне по клику на полигон.",
    "define": "Задать",
    "Delay between two transitions when in play mode": "Задержка между двумя переходами в режиме проигрывания",
    "Delete layer": "Удалить слой",
    "Delete this feature": "Удалить объект",
    "Delete this shape": "Удалить эту фигуру",
    "Delete this vertex (Alt+Click)": "Удалить эту точку (Alt+клик)",
    "Delete": "Удалить",
    "description": "описание",
    "Direct link": "Direct link",
    "Directions from here": "Навигация отсюда",
    "Display label": "Показывать надпись",
    "Display measure": "Display measure",
    "display name": "отображаемое название",
    "Display on load": "Показывать при загрузке",
    "Display the control to open OpenStreetMap editor": "Отображать кнопку редактора OpenStreetMap",
    "Display the embed control": "Отображать кнопку встраивания",
    "Display the fullscreen control": "Отображать кнопку полноэкранного режима",
    "Display the locate control": "Отображать кнопку определения местоположения",
    "Display the measure control": "Отображать линейку",
    "Display the search control": "Отображать строку поиска",
    "Display the star map button": "Display the star map button",
    "Display the tile layers control": "Отображать кнопку управления слоями подложки",
    "Display the zoom control": "Отображать кнопку масштабирования",
    "Do you want to display a caption bar?": "Показывать строку заголовка?",
    "Do you want to display a minimap?": "Показывать миникарту?",
    "Do you want to display a panel on load?": "Показывать панель управления при загрузке?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Хотите использовать всплывающую подсказку снизу?",
    "Do you want to display the scale control?": "Показывать шкалу расстояний?",
    "Do you want to display the «more» control?": "Показывать кнопку «Ещё»?",
    "Download": "Скачать",
    "Drag to reorder": "Перетащите для изменения порядка",
    "Draw a marker": "Добавить метку",
    "Draw a polygon": "Нарисовать полигон",
    "Draw a polyline": "Нарисовать линию",
    "Drawing": "Drawing",
    "Drop": "Капля",
    "Dynamic properties": "Динамические свойства",
    "Dynamic": "Динамический",
    "Edit feature's layer": "Изменить слой объекта",
    "Edit properties in a table": "Редактировать свойства в таблице",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Редактировать объект",
    "Edit": "Редактировать",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Встроить карту",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Очистить",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Ошибка в ссылке на слой карты",
    "Exit Fullscreen": "Выйти из полноэкранного режима",
    "expanded": "Развёрнуто",
    "Extract shape to separate feature": "Извлечь фигуру в отдельный объект",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Запрашивать данные при каждом изменении отображения карты",
    "fill color": "цвет заливки",
    "fill opacity": "Непрозрачность заливки",
    "fill": "заливка",
    "Fit all data": "Fit all data",
    "Format": "Формат",
    "From zoom": "С масштаба",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (только ссылка)",
    "GeoRSS (title + image)": "GeoRSS (заголовок и изображение)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Перейти к «{feature}»",
    "Heatmap intensity property": "Свойство интенсивности тепловой карты",
    "Heatmap radius": "Радиус для тепловой карты",
    "Heatmap": "Тепловая карта",
    "height": "высота",
    "Help": "Помощь",
    "hidden": "скрыт",
    "Hide controls": "Убрать элементы управления",
    "Home": "Заглавная",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Насколько сильно упрощать линии на каждом масштабе (больше значение — больше скорость, но выглядит хуже; меньше значение — более гладкое отображение)",
    "icon opacity": "icon opacity",
    "Icon shape": "Форма иконки",
    "Icon symbol": "Иконка значка",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe с указанием высоты (в пикселях): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe с заданной высотой и шириной (в px): {{{http://iframe.url.com|height*width}}}",
    "iframe": "Iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Изображение с указанием ширины (в пикселях): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Изображение: {{http://image.url.com}}",
    "Import data": "Импортировать данные",
    "Import in a new layer": "Импортировать в новый слой",
    "Imports all umap data, including layers and settings.": "Импортировать все данные uMap, включая слои и настройки.",
    "Include full screen link?": "Включить ссылку на полноэкранный вид?",
    "Inherit": "Наследовать",
    "inherit": "наследовать",
    "Interaction options": "Параметры взаимодействия",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Неверные данные uMap в файле {filename}",
    "Invalid umap data": "Неверные данные uMap",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Оставить текущие видимые слои",
    "kilometers": "километров",
    "km": "км",
    "Label direction": "Направление метки",
    "Label key": "Кнопка метки",
    "Labels are clickable": "Метки можно нажимать",
    "Latest feature": "Latest feature",
    "Latitude": "Широта",
    "Layer properties": "Свойства слоя",
    "Layer": "Слой",
    "Licence": "Лицензия",
    "licence": "лицензия",
    "Limit bounds": "Установить границы",
    "Link to view the map": "Link to view the map",
    "Link to…": "Связать с...",
    "Link with text: [[http://example.com|text of the link]]": "Ссылка с текстом: [[http://example.com|текст для ссылки]]",
    "Long credits": "Полное описание прав",
    "Longitude": "Долгота",
    "Make main shape": "Сделать главной фигурой",
    "Manage layers": "Управление слоями",
    "Manual": "Manual",
    "Map background credits": "Права на фоновый слой карты",
    "Map has been attached to your account": "Карта была прикреплена к вашей учётной записи",
    "Map has been saved!": "Карта сохранена!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "Пользовательские данные опубликованы под лицензией",
    "Map's editors": "Редакторы карты",
    "Map's owner": "Владелец карты",
    "max East": "Восток",
    "max North": "Север",
    "max South": "Юг",
    "max West": "Запад",
    "max zoom": "максимальный масштаб",
    "Measure distances": "Измерить расстояния",
    "Merge lines": "Соединить линии",
    "mi": "миля",
    "miles": "миль",
    "min zoom": "минимальный масштаб",
    "More controls": "Другие элементы управления",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Должен быть в формате CSS (напр., DarkBlue или #123456)",
    "name": "название",
    "nautical miles": "морских миль",
    "never": "никогда",
    "new window": "Новое окно",
    "next": "следующий",
    "NM": "ММ",
    "No cache": "Не кэшировать",
    "No licence has been set": "Лицензия не была указана",
    "No results": "Нет данных",
    "no": "нет",
    "No.": "No.",
    "None": "Нет",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "Внизу",
    "On the left": "Слева",
    "On the right": "Справа",
    "On the top": "Вверху",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "непрозрачность",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Открыть ссылку в ...",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Откройте эту часть карты в редакторе OpenStreetMap, чтобы улучшить данные",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Дополнительные свойства интенсивности тепловой карты",
    "Optional. Same as color if not set.": "Дополнительно. Если не выбрано, то как цвет.",
    "Optional.": "Необязательный.",
    "Override clustering radius (default 80)": "Переопределить радиус кластеризации (по умолчанию 80)",
    "Override heatmap radius (default 25)": "Переопределить радиус для тепловой карты (по умолчанию 25)",
    "parent window": "Родительское окно",
    "Paste your data here": "Вставить ваши данные сюда",
    "Permalink": "Постоянная ссылка",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Убедитесь, что лицензия соответствует правилам использования.",
    "Please choose a format": "Пожалуйста, выберите формат",
    "Please enter the name of the property": "Введите название свойства",
    "Please enter the new name of this property": "Введите новое название свойства",
    "Please save the map first": "Пожалуйста, сначала сохраните карту",
    "Popup (large)": "Всплывающее окно (большое)",
    "Popup content style": "Стиль содержимого всплывающего окна",
    "Popup content template": "Шаблон всплывающей подсказки",
    "Popup shape": "Форма всплывающего окна",
    "Popup": "Всплывающее окно",
    "Powered by uMap": "Powered by uMap",
    "previous": "предыдущий",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Импортированы свойства:",
    "Provide an URL here": "Укажите ссылку здесь",
    "Proxy request": "Проксировать запрос",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Данные с удаленного сервера",
    "Remove shape from the multi": "Удалить фигуру из мультиполигона",
    "Replace layer content": "Заменить содержимое слоя",
    "Restore this version": "Восстановить эту версию",
    "Save current edits": "Сохранить текущие правки",
    "Save map": "Save map",
    "Save this center and zoom": "Сохранить это положение и масштаб",
    "Save this location as new feature": "Сохранить это местоположение как новый объект",
    "Save": "Сохранить",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Поиск местоположения",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Смотреть в полноэкранном режиме",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Сбросьте, чтобы скрыть слой из слайдшоу, просмотра данных и всплывающей навигации...",
    "settings": "settings",
    "Shape properties": "Свойства фигуры",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Краткое описание прав",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Показать/скрыть слой",
    "Side panel": "Боковая панель",
    "Simple link: [[http://example.com]]": "Простая ссылка: [[http://example.com]]",
    "Simplify": "Упростить",
    "Skipping unknown geometry.type: {type}": "Пропущено неизвестное свойство geometry.type: {type}",
    "Slideshow": "Слайдшоу",
    "Sort key": "Кнопка сортировки",
    "Split line": "Разделить линию",
    "Star this map": "Star this map",
    "Start a hole here": "Начать отверстие отсюда",
    "Start slideshow": "Начать слайдшоу",
    "Stop editing": "Завершить редактирование",
    "Stop slideshow": "Остановить слайдшоу",
    "Street": "Street",
    "stroke": "штрихи",
    "Supported scheme": "Поддерживаемая схема",
    "Supported variables that will be dynamically replaced": "Поддерживаемые переменные для автоматической замены",
    "Symbol": "Symbol",
    "Table": "Таблица",
    "Text color for the cluster label": "Цвет текста для меток кластера",
    "Text formatting": "Форматирование текста",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "Формат TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Если удалённый сервер не позволяет кросс-домен (медленно)",
    "To zoom": "Масштабировать",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Перенести фигуру на редактируемый объект",
    "Transform to lines": "Преобразовать в линию",
    "Transform to polygon": "Преобразовать в полигон",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Тип слоя",
    "Unable to detect format of file {filename}": "Невозможно определить формат файла {filename}",
    "Untitled layer": "Слой без названия",
    "Untitled map": "Безымянная карта",
    "Update permissions and editors": "Настроить права редактирования",
    "Update permissions": "Обновить разрешения",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "Ссылка",
    "URL": "URL",
    "Use current bounds": "Использовать текущие границы",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Используйте переменные в скобках со свойствами объектов, например, &#123;name&#125;, они будут автоматически заменены соответствующими значениями.",
    "User content credits": "Права на пользовательские данные",
    "User interface options": "Настройка интерфейса",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Версии",
    "View Fullscreen": "Полноэкранный режим",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "толщина",
    "Where do we go from here?": "Что можно сделать с картой?",
    "Whether to display or not polygons paths.": "Показывать или нет контур полигона.",
    "Whether to fill polygons with color.": "Заполнять или нет полигон заливкой цветом",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Кто может редактировать",
    "Who can view": "Кто может просматривать",
    "width": "ширина",
    "Will be displayed in the bottom right corner of the map": "Будет показано в правом нижнем углу карты",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Будет показано в заголовке карты",
    "yes": "да",
    "Zoom in": "Увеличить масштаб",
    "Zoom level for automatic zooms": "Масштабировать слой автоматически",
    "Zoom out": "Уменьшить масштаб",
    "Zoom to layer extent": "Масштабировать до границ слоя",
    "Zoom to the next": "Приблизиться к следующему",
    "Zoom to the previous": "Приблизиться к предыдущему",
    "Zoom to this feature": "Приблизиться к этому объекту",
    "Zoom to this place": "Приблизить объект",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} ошибок во время импорта: {message}",
    "{delay} seconds": "{delay} секунд",
    "{distance}&#8239;km": "{distance} км",
    "{distance}&#8239;m": "{distance} м",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Import helpers:": "Import helpers:",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "My Dashboard ({username})": "My Dashboard ({username})",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control"
}
L.registerLocale("ru", locale)
L.setLocale("ru")
