const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# un cancelo para a cabeceira principal",
    "## two hashes for second heading": "## dous cancelos para a cabeceira secundaria",
    "### three hashes for third heading": "### tres cancelos para a cabeceira terciaria",
    "**double star for bold**": "**dous asteriscos para pór negriña**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 día",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Unha listaxe separada por vírgulas que define o patrón de trazos de guión. Ex.: \"5, 10, 15\".",
    "About": "Acerca de",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Engadir unha capa",
    "Add a line to the current multi": "Engadir unha liña para o multi actual",
    "Add a new property": "Engadir unha nova propiedade",
    "Add a polygon to the current multi": "Enhadir un polígono para o multi actual",
    "Add image URL": "Add image URL",
    "Add": "Add",
    "Advanced actions": "Accións avanzadas",
    "Advanced properties": "Propiedades avanzadas",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Tódalas propiedades son importadas.",
    "Allow interactions": "Permitir interaccións",
    "Allow scroll wheel zoom?": "Permitir o achegamento ca roda do rato?",
    "always": "sempre",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to cancel your changes?": "Estás na certeza de que desexas desbotar as túas mudanzas?",
    "Are you sure you want to clone this map and all its datalayers?": "Estás na certeza de que desexas clonar este mapa e tódalas súas capas de datos?",
    "Are you sure you want to delete the feature?": "Estás na certeza de que desexas eliminar este elemento?",
    "Are you sure you want to delete this layer?": "Estás na certeza de que desexas eliminar esta capa?",
    "Are you sure you want to delete this map?": "Estás na certeza de que desexas eliminar este mapa?",
    "Are you sure you want to delete this property on all the features?": "Estás na certeza de que desexas eliminar esta propiedade en tódolos elementos?",
    "Are you sure you want to restore this version?": "Estás na certeza de que desexas restabelecer esta versión?",
    "Attach the map to my account": "Adxuntar o mapa á miña conta",
    "attribution": "atribución",
    "Auto": "Automático",
    "Automatic": "Automático",
    "Autostart when map is loaded": "Autocomezar cando o mapa estea cargado",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Bóla",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Navegar polos datos",
    "by": "por",
    "Cache proxied request": "Solicitude de proxy da caché",
    "Cancel edits": "Desbotar as edicións",
    "Caption": "Subtítulo",
    "Center map on your location": "Centrar o mapa na túa ubicación",
    "Change map background": "Mudar o mapa do fondo",
    "Change tilelayers": "Mudar as capas de teselas",
    "Change": "Change",
    "Choose the data format": "Escoller o formato de datos",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Círculo",
    "clear": "limpar",
    "Click last point to finish shape": "Preme no derradeiro punto para rematar a forma",
    "Click to add a marker": "Preme para engadir unha marcaxe",
    "Click to continue drawing": "Preme para seguir debuxando",
    "Click to edit": "Preme para editar",
    "Click to start drawing a line": "Preme para comezar a debuxar unha liña",
    "Click to start drawing a polygon": "Preme para comezar a debuxar un polígono",
    "Clone of {name}": "Clonado de {name}",
    "Clone this feature": "Clonar este elemento",
    "Clone this map": "Clonar este mapa",
    "Clone": "Clonar",
    "Close": "Pechar",
    "Clustered": "Agrupados",
    "Clustering radius": "Raio de agrupamento",
    "collapsed": "agochado",
    "color": "cor",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Liña continua",
    "Coordinates": "Coordenadas",
    "copy": "copy",
    "Credits": "Cretos",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Vista actual en troques da vista predeterminada?",
    "Custom background": "Fondo persoalizado",
    "Custom overlay": "Custom overlay",
    "dash array": "matriz de guións",
    "Data is browsable": "Os datos son navegábeis",
    "Datalayers": "Datalayers",
    "Default interaction options": "Opcións de interacción predeterminados",
    "Default properties": "Propiedades predeterminadas",
    "Default shape properties": "Propiedades de formas predeterminados",
    "Default view": "Default view",
    "Default zoom level": "Nivel do achegamento predeterminado",
    "Default": "Por defecto",
    "Default: name": "Por defecto: nome",
    "Define link to open in a new window on polygon click.": "Defina unha ligazón para abrir nunha nova xanela ó premer no polígono.",
    "define": "define",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete layer": "Eliminar capa",
    "Delete this feature": "Eliminar este elemento",
    "Delete this shape": "Eliminar esta forma",
    "Delete this vertex (Alt+Click)": "Eliminar este vértice (Alt+Clic)",
    "Delete": "Eliminar",
    "description": "descrición",
    "Direct link": "Direct link",
    "Directions from here": "Direccións dende aquí",
    "Display label": "Amosar etiqueta",
    "Display measure": "Amosar medida",
    "display name": "amosar o nome",
    "Display on load": "Amosar ó cargar",
    "Display the control to open OpenStreetMap editor": "Amosar o control para abrir o editor do OpenStreetMap",
    "Display the embed control": "Amosar o control de incrustado",
    "Display the fullscreen control": "Amosar o control de pantalla completa",
    "Display the locate control": "Amosar o control de ubicación",
    "Display the measure control": "Amosar o control de medida",
    "Display the search control": "Amosar o control de procura",
    "Display the star map button": "Display the star map button",
    "Display the tile layers control": "Amosar o control de capas de teselas",
    "Display the zoom control": "Amosar o control de achegamento",
    "Do you want to display a caption bar?": "Desexas amosar a barra de subtítulos?",
    "Do you want to display a minimap?": "Desexas amosar un minimapa?",
    "Do you want to display a panel on load?": "Desexas amosar un panel ó cargar?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Desexas amosar a xanela emerxente no pé de páxina?",
    "Do you want to display the scale control?": "Desexas amosar o control de escala?",
    "Do you want to display the «more» control?": "Desexas amosar o control «máis»?",
    "Download": "Baixar",
    "Drag to reorder": "Arrastrar para reordenar",
    "Draw a marker": "Debuxa unha marcaxe",
    "Draw a polygon": "Debuxa un polígono",
    "Draw a polyline": "Debuxa unha liña múltiple",
    "Drawing": "Drawing",
    "Drop": "Marcaxe",
    "Dynamic properties": "Propiedades dinámicas",
    "Dynamic": "Dinámico",
    "Edit feature's layer": "Editar a capa do elemento",
    "Edit properties in a table": "Editar propiedades nunha táboa",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Editar este elemento",
    "Edit": "Editar",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Incorporar o mapa",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Baleirar",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Erro na URL da capa de teselas",
    "Exit Fullscreen": "Saír da pantalla completa",
    "expanded": "expandido",
    "Extract shape to separate feature": "Extraer a forma ó elemento separado",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Obter os datos cada vez que a vista do mapa muda.",
    "fill color": "cor de recheo",
    "fill opacity": "rechear a opacidade",
    "fill": "rechear",
    "Fit all data": "Fit all data",
    "Format": "Formato",
    "From zoom": "Dende o achegamento",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (só ligazón)",
    "GeoRSS (title + image)": "GeoRSS (título + imaxe)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Ir cara «{feature}»",
    "Heatmap intensity property": "Propiedade intensidade do mapa de calor",
    "Heatmap radius": "Raio do mapa de calor",
    "Heatmap": "Mapa de calor",
    "height": "altura",
    "Help": "Axuda",
    "hidden": "agochar",
    "Hide controls": "Agochar os controis",
    "Home": "Inicio",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Canto se simplificará a polilínea en cada nivel de achegamento (máis = mellor comportamento e aparencia máis feble, menos = máis preciso)",
    "icon opacity": "icon opacity",
    "Icon shape": "Forma da icona",
    "Icon symbol": "Símbolo da icona",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe con altura persoalizada (en píxeles): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe con alto e ancho (en px) persoalizado: {{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Imaxe con anchura persoalizada (en píxeles): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Imaxe: {{http://image.url.com}}",
    "Import data": "Importar datos",
    "Import in a new layer": "Importar nunha nova capa",
    "Imports all umap data, including layers and settings.": "Importar tódolos datos do umap, incluíndo capas e axustes.",
    "Include full screen link?": "Engadir a ligazón de pantalla completa?",
    "Inherit": "Herdar",
    "inherit": "herdar",
    "Interaction options": "Opcións de interacción",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Dato umap non válido en {filename}",
    "Invalid umap data": "Dato umap non válido",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Gardar capas visíbeis actuais",
    "kilometers": "quilómetros",
    "km": "km",
    "Label direction": "Dirección da etiqueta",
    "Label key": "Etiqueta da clave",
    "Labels are clickable": "Labels are clickable",
    "Latest feature": "Latest feature",
    "Latitude": "Latitude",
    "Layer properties": "Propiedades da capa",
    "Layer": "Capa",
    "Licence": "Licenza",
    "licence": "licenza",
    "Limit bounds": "Limitar os límites",
    "Link to view the map": "Link to view the map",
    "Link to…": "Ligazón cara...",
    "Link with text: [[http://example.com|text of the link]]": "Ligazón con texto: [[http://example.com|text of the link]]",
    "Long credits": "Cretos longos",
    "Longitude": "Lonxitude",
    "Make main shape": "Facer a forma principal",
    "Manage layers": "Xestionar capas",
    "Manual": "Manual",
    "Map background credits": "Cretos do mapa de fondo",
    "Map has been attached to your account": "O mapa adxuntouse á súa conta",
    "Map has been saved!": "Gardouse o mapa!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "O contido do mapa do usuario foi publicado baixo a licenza",
    "Map's editors": "Editores do mapa",
    "Map's owner": "Dono do mapa",
    "max East": "máximo Leste",
    "max North": "máximo Norte",
    "max South": "máximo Sul",
    "max West": "máximo Oeste",
    "max zoom": "achegamento máximo",
    "Measure distances": "Medir distancias",
    "Merge lines": "Combinar liñas",
    "mi": "mi",
    "miles": "millas",
    "min zoom": "achegamento mínimo",
    "More controls": "Máis controis",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Ten que ser un valor CSS válido (por ex.: DarkBlue ou #123456)",
    "name": "nome",
    "nautical miles": "millas náuticas",
    "never": "nunca",
    "new window": "nova xanela",
    "next": "seguinte",
    "NM": "NM",
    "No cache": "Sen caché",
    "No licence has been set": "Ningunha licenza foi estabelecida",
    "No results": "Sen resultados",
    "no": "non",
    "No.": "No.",
    "None": "Ningún",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "Na parte de embaixo",
    "On the left": "Á esquerda",
    "On the right": "Á dereita",
    "On the top": "Na parte de enriba",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "opacidade",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Abrir ligazón en...",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Abre a extensión deste mapa nun editor de mapas para fornecer datos máis precisos ó OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Propiedade de intensidade opcional para o mapa de calor",
    "Optional. Same as color if not set.": "Opcional. A mesma cor se non se estabelece.",
    "Optional.": "Opcional.",
    "Override clustering radius (default 80)": "Sobrescribir o raio de agrupamento (predeterminado 80)",
    "Override heatmap radius (default 25)": "Sobreescribir o raio do mapa de calor (predeterminado 25)",
    "parent window": "xanela pai ou principal",
    "Paste your data here": "Pega os teus datos aquí",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Coide de que a licenza sexa compatíbel co emprego que lle vai a dár.",
    "Please choose a format": "Escolle un formato",
    "Please enter the name of the property": "Insira o nome da propiedade",
    "Please enter the new name of this property": "Insira o novo nome desta propiedade",
    "Please save the map first": "Por favor garda o mapa primeiro",
    "Popup (large)": "Xanela emerxente (grande)",
    "Popup content style": "Estilo do contido da xanela emerxente",
    "Popup content template": "Padrón do contido da xanela emerxente",
    "Popup shape": "Forma da xanela emerxente",
    "Popup": "Xanela emerxente",
    "Powered by uMap": "Powered by uMap",
    "previous": "anterior",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Propiedades importadas:",
    "Provide an URL here": "Forneza unha URL aquí",
    "Proxy request": "Petición a proxy",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Datos remotos",
    "Remove shape from the multi": "Eliminar a forma do 'multi'",
    "Replace layer content": "Substitúe o contido da capa",
    "Restore this version": "Restabelecer esta versión",
    "Save current edits": "Gardar as edicións actuais",
    "Save map": "Save map",
    "Save this center and zoom": "Gardar este centrado e achegamento",
    "Save this location as new feature": "Gardar esta ubicación coma novo elemento",
    "Save": "Gardar",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Procurar localización",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Ollar pantalla completa",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Axústeo a falso para agochar esta capa da presentación ('slideshow'), o navegador de datos, a navegación da xanela emerxente...",
    "settings": "settings",
    "Shape properties": "Propiedades da forma",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Cretos curtos",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Amosar/agochar capa",
    "Side panel": "Lapela lateral",
    "Simple link: [[http://example.com]]": "Ligazón sinxela: [[http://example.com]]",
    "Simplify": "Simplificar",
    "Skipping unknown geometry.type: {type}": "Brincando tipo descoñecido geometry.type: {type}",
    "Slideshow": "Presentación",
    "Sort key": "Orde da clave",
    "Split line": "Liña de división",
    "Star this map": "Star this map",
    "Start a hole here": "Comezar un burato aquí",
    "Start slideshow": "Comezar presentación",
    "Stop editing": "Deter a edición",
    "Stop slideshow": "Deter a presentación",
    "Street": "Street",
    "stroke": "trazo",
    "Supported scheme": "Esquema suportado",
    "Supported variables that will be dynamically replaced": "Variábeis suportadas que serán substituídas de xeito dinámico",
    "Symbol": "Symbol",
    "Table": "Táboa",
    "Text color for the cluster label": "Cor do texto para a etiqueta clúster",
    "Text formatting": "Formato do texto",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "formato TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Para empregar se o servidor remoto non permite dominios cruzados (máis amodo)",
    "To zoom": "Para o achegamento",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Transferir a forma ó elemento editada",
    "Transform to lines": "Transformar a liñas",
    "Transform to polygon": "Transformar a polígono",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Tipo de capa",
    "Unable to detect format of file {filename}": "Non se pode detectar o formato de ficheiro {filename}",
    "Untitled layer": "Capa sen título",
    "Untitled map": "Mapa sen título",
    "Update permissions and editors": "Actualizar permisos e editores",
    "Update permissions": "Actualizar permisos",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "Url",
    "URL": "URL",
    "Use current bounds": "Empregar os límites actuais",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Empregar marcaxes de posición con propiedades do elemento entre paréntesis, exemplo &#123;name&#125;, serán substituídos de xeito dinámico polos valores correspondentes.",
    "User content credits": "Cretos do contido do usuario",
    "User interface options": "Opcións da interface de usuario",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Versións",
    "View Fullscreen": "Ollar en pantalla completa",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "peso",
    "Where do we go from here?": "Onde vamos a partir daquí?",
    "Whether to display or not polygons paths.": "Se desexas amosar ou non as rutas dos polígonos.",
    "Whether to fill polygons with color.": "Se desexas rechear os polígonos con cor.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Quen pode editar",
    "Who can view": "Quen pode ollar",
    "width": "ancho",
    "Will be displayed in the bottom right corner of the map": "Amosarase na esquina inferior esquerda do mapa",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Será visíbel no subtítulo do mapa",
    "yes": "si",
    "Zoom in": "Achegar",
    "Zoom level for automatic zooms": "Nivel de achegamento para achegamentos automáticos",
    "Zoom out": "Afastar",
    "Zoom to layer extent": "Achegar ó nivel da capa",
    "Zoom to the next": "Achegar ó seguinte",
    "Zoom to the previous": "Achegar ó anterior",
    "Zoom to this feature": "Achegar a este elemento",
    "Zoom to this place": "Achegar a este lugar",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} erros durante a importación: {message}",
    "{delay} seconds": "{delay} segundos",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Import helpers:": "Import helpers:",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "My Dashboard ({username})": "My Dashboard ({username})",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control"
}
L.registerLocale("gl", locale)
L.setLocale("gl")
