# Generated by Django 2.1.5 on 2019-04-07 07:19

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("umap", "0005_remove_map_tilelayer"),
    ]

    operations = [
        migrations.AlterField(
            model_name="map",
            name="settings",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                blank=True, default=dict, null=True, verbose_name="settings"
            ),
        ),
    ]
