const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# یک هش برای عنوان اصلی",
    "## two hashes for second heading": "## دو هش برای عنوان دوم",
    "### three hashes for third heading": "### سه هش برای عنوان سوم",
    "**double star for bold**": "**ستاره‌های دوتایی برای ضخیم**",
    "*single star for italic*": "*ستاره‌های تکی برای مورب*",
    "--- for a horizontal rule": "--- برای یک خط افقی",
    "1 day": "1 روز",
    "1 hour": "1 ساعت",
    "5 min": "5 دقیقه",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "فهرستی از اعداد که الگوی خط‌چین را تعریف می‌کنند (جداشده با کاما) مثال: \"5, 10, 15\".",
    "About": "درباره",
    "Action not allowed :(": "کنش غیرمجاز :(",
    "Activate slideshow mode": "حالت نمایش اسلاید را فعال کنید",
    "Add a layer": "یک لایه اضافه کنید",
    "Add a line to the current multi": "یک خط به مولتی فعلی اضافه کنید",
    "Add a new property": "افزودن ویژگی جدید",
    "Add a polygon to the current multi": "یک چندضلعی به مولتی فعلی اضافه کنید",
    "Add image URL": "نشانی تصویر را بدهید",
    "Add": "افزودن",
    "Advanced actions": "کنش‌های پیشرفته",
    "Advanced properties": "ویژگی‌های پیشرفته",
    "All data and settings of the map": "همهٔ داده‌ها و تنظیمات نقشه",
    "All properties are imported.": "همه ویژگی‌ها درون‌برد شد.",
    "Allow interactions": "اجازهٔ تعامل دهید",
    "Allow scroll wheel zoom?": "زوم با چرخانک موشواره مجاز باشد؟",
    "always": "همیشه",
    "Animated transitions": "گذارهای پویانما",
    "Are you sure you want to cancel your changes?": "آیا تغییرات خود را لغو می‌کنید؟",
    "Are you sure you want to clone this map and all its datalayers?": "آیا از این نقشه و همهٔ لایه‌های دادهٔ آن همانند می‌سازید؟",
    "Are you sure you want to delete the feature?": "آیا این عنصر را حذف می‌کنید؟",
    "Are you sure you want to delete this layer?": "آیا این لایه را حذف می‌کنید؟",
    "Are you sure you want to delete this map?": "آیا این نقشه را حذف می‌کنید؟",
    "Are you sure you want to delete this property on all the features?": "آیا این ویژگی را از همهٔ عناصر حذف می‌کنید؟",
    "Are you sure you want to restore this version?": "آیا این نسخه را بازیابی می‌کنید؟",
    "Attach the map to my account": "نقشه را به حساب من وصل کن",
    "attribution": "انتساب",
    "Auto": "خودکار",
    "Automatic": "خودکار",
    "Autostart when map is loaded": "پس از بارشدن نقشه، خودکار آغاز شود",
    "Back to preview": "بازگشت به حالت نمایش",
    "Background overlay url": "نشانی رولایهٔ پس‌زمینه",
    "Ball": "توپ",
    "Bring feature to center": "آوردن عنصر به مرکز",
    "Browse data": "مرور داده‌ها",
    "by": "از",
    "Cache proxied request": "حفظ موقت درخواست پراکسی‌شده",
    "Cancel edits": "لغو ویرایش‌ها",
    "Caption": "درباره",
    "Center map on your location": "تنظیم مرکز نقشه روی موقعیت شما",
    "Change map background": "تغییر پس‌زمینهٔ نقشه",
    "Change tilelayers": "لایهٔ کاشی را تغییر دهید",
    "Change": "تغییر",
    "Choose the data format": "قالب داده را انتخاب کنید",
    "Choropleth breakpoints": "نقاط شکست",
    "Choropleth classes": "دسته‌ها",
    "Choropleth color palette": "تخته رنگ",
    "Choropleth mode": "حالت",
    "Choropleth property value": "مقدار ویژگی",
    "Choropleth": "ناحیه‌مقدار (Choropleth)",
    "Circle": "دایره",
    "clear": "حذف",
    "Click last point to finish shape": "برای تکمیل شکل روی آخرین نقطه کلیک کنید",
    "Click to add a marker": "برای افزودن نشانگر کلیک کنید",
    "Click to continue drawing": "برای ادامهٔ ترسیم کلیک کنید",
    "Click to edit": "برای ویرایش کلیک کنید",
    "Click to start drawing a line": "برای شروع رسم خط کلیک کنید",
    "Click to start drawing a polygon": "برای شروع ترسیم چندضلعی کلیک کنید",
    "Clone of {name}": "همانندساخته از {name}",
    "Clone this feature": "از این عنصر همانند بسازید",
    "Clone this map": "از این نقشه همانند بسازید",
    "Clone": "همانندسازی",
    "Close": "بستن",
    "Clustered": "خوشه‌ای",
    "Clustering radius": "شعاع خوشه‌بندی",
    "collapsed": "جمع‌شده",
    "color": "رنگ",
    "Comma separated list of numbers, including min and max values.": "فهرست اعداد جداشده با کاما، شامل مقدارهای کمینه و بیشینه.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "فهرست ویژگی‌ها برای استفاده در مرتب‌سازی عنصرها (جداشده با کاما). برای ترتیب معکوس، یک منها قبل آن بگذارید. مثلاًmykey, -othrekey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "مقادیر جداشده با کاما، تب یا سمی‌کالن. SRS WGS84 پیشفرض است. فقط نقطه‌ها درون‌برد می‌شوند. درون‌بردکننده به سرستون‌ها نگاه می‌کند تا هرگونه ذکر عبارت «lat» و «lon» را در ابتدای سرستون بیابد. به بزرگی و کوچکی حروف حساس نیست. همهٔ ستون‌های دیگر به عنوان ویژگی درون‌برد می‌شوند.",
    "Congratulations, your map has been created!": "تبریک، نقشهٔ شما ساخته شد!",
    "Continue line": "ادامه‌دادن به خط",
    "Coordinates": "مختصات",
    "copy": "رونوشت",
    "Credits": "سپاسگزاری",
    "Current map view": "نمای کنونی نقشه",
    "Current view instead of default map view?": "نمای فعلی به جای نمای پیشفرض نقشه؟",
    "Custom background": "پس‌زمینهٔ سفارشی",
    "Custom overlay": "پیش‌زمینهٔ سفارشی",
    "dash array": "خط‌چین",
    "Data is browsable": "داده‌ها قابل‌مرور هستند",
    "Datalayers": "لایه‌های داده",
    "Default interaction options": "گزینه‌های پیشفرض تعامل",
    "Default properties": "ویژگی‌های پیشفرض",
    "Default shape properties": "ویژگی‌های پیشفرض شکل",
    "Default view": "نمای پیشفرض",
    "Default zoom level": "سطح بزرگنمایی پیشفرض",
    "Default": "پیشفرض",
    "Default: name": "پیشفرض: name",
    "Define link to open in a new window on polygon click.": "پیوندی تعریف کنید تا با کلیک روی چندضلعی، در پنجرهٔ جدید باز شود.",
    "define": "تعريف",
    "Delay between two transitions when in play mode": "تأخیر بین دو گذار در حالت پخش",
    "Delete layer": "حذف لایه",
    "Delete this feature": "حذف این عنصر",
    "Delete this shape": "حذف این شکل",
    "Delete this vertex (Alt+Click)": "حذف این رأس (Alt+Click)",
    "Delete": "حذف",
    "description": "شرح",
    "Direct link": "پیوند مستقیم",
    "Directions from here": "مسیریابی از اینجا",
    "Display label": "نمایش برچسب",
    "Display measure": "نمایش اندازه‌گیری",
    "display name": "نام نمایشی",
    "Display on load": "نمایش هنگام بارشدن",
    "Display the control to open OpenStreetMap editor": "نمایش دکمه برای بازکردن ویرایشگر اوپن‌استریت‌مپ ",
    "Display the embed control": "نمایش دکمهٔ همرسانی",
    "Display the fullscreen control": "نمایش دکمهٔ تمام‌صفحه",
    "Display the locate control": "نمایش دکمهٔ مکان‌یابی",
    "Display the measure control": "نمایش دکمهٔ اندازه‌گیری",
    "Display the search control": "نمایش دکمهٔ جستجو",
    "Display the star map button": "نمایش دکمهٔ ستاره‌دارکردن نقشه",
    "Display the tile layers control": "نمایش دکمهٔ لایه‌های کاشی",
    "Display the zoom control": "نمایش دکمهٔ زوم",
    "Do you want to display a caption bar?": "آیا نوار زیرنویس نشان داده شود؟",
    "Do you want to display a minimap?": "آیا نقشهٔ کوچک نشان داده شود؟",
    "Do you want to display a panel on load?": "آیا یک صفحه پس از بارشدن نشان داده شود؟",
    "Do you want to display caption menus?": "آیا منوهای زیرنویس نشان داده شود؟",
    "Do you want to display popup footer?": "آیا در پنجرک بازشو پاورقی نشان داده شود؟",
    "Do you want to display the scale control?": "آیا نوار مقیاس نشان داده شود؟",
    "Do you want to display the «more» control?": "آیا دکمهٔ «بیشتر» نمایش داده شود؟",
    "Download": "بارگیری",
    "Drag to reorder": "برای مرتب‌سازی بکشید",
    "Draw a marker": "رسم نشانگر",
    "Draw a polygon": "رسم چندضلعی",
    "Draw a polyline": "رسم چندخطی",
    "Drawing": "Drawing",
    "Drop": "قطره",
    "Dynamic properties": "ویژگی‌های پویا",
    "Dynamic": "پویا",
    "Edit feature's layer": "لایهٔ عنصر را ویرایش کنید",
    "Edit properties in a table": "ویژگی‌ها را در جدول ویرایش کنید",
    "Edit the title of the map": "عنوان نقشه را ویرایش کنید",
    "Edit this feature": "این عنصر را ویرایش کنید",
    "Edit": "ویرایش",
    "Embed and link options": "گزینه‌های جاسازی و پیوند",
    "Embed the map": "نقشه را جاسازی کنید",
    "Emoji & Character": "شکلک و نویسه",
    "Empty": "خالی",
    "Equidistant": "هم‌فاصله",
    "Error in the overlay URL": "خطا در نشانی پیش‌زمینه",
    "Error in the tilelayer URL": "خطا در نشانی لایهٔ کاشی",
    "Exit Fullscreen": "خروج از تمام‌صفحه",
    "expanded": "گسترده‌شده",
    "Extract shape to separate feature": "استخراج شکل به عنصر جدا",
    "Feature identifier key": "کلید شناسایی عنصر",
    "Feature properties": "ویژگی‌های عنصر",
    "Fetch data each time map view changes.": "هر بار که نمای نقشه تغییر می‌کند، داده‌ها واکشی شود.",
    "fill color": "رنگ پرکردن",
    "fill opacity": "شفافیت پرشدگی",
    "fill": "پرکردن",
    "Fit all data": "گنجیدن همهٔ داده‌ها",
    "Format": "قالب",
    "From zoom": "از زوم",
    "full backup": "پشتیبان کامل",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (فقط پیوند)",
    "GeoRSS (title + image)": "GeoRSS (عنوان + تصویر)",
    "Go to \"{coords}\"": "برو به «{coords}»",
    "Go to the homepage": "برو به صفحهٔ اصلی",
    "Go to «{feature}»": "برو به «{feature}»",
    "Heatmap intensity property": "ویژگی برای شدت نقشهٔ حرارتی",
    "Heatmap radius": "شعاع نقشهٔ حرارتی",
    "Heatmap": "نقشهٔ حرارتی",
    "height": "ارتفاع",
    "Help": "راهنما",
    "hidden": "پنهان",
    "Hide controls": "مخفی‌کردن دکمه‌ها",
    "Home": "خانه",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "میزان ساده‌‌سازی چندخطی در هر سطح بزرگنمایی (بیشتر = اجرای روان‌تر، کمتر = دقیق‌تر)",
    "icon opacity": "شفافیت نشانگر",
    "Icon shape": "شکل نشانگر",
    "Icon symbol": "نماد نشانگر",
    "If false, the polygon or line will act as a part of the underlying map.": "اگر خاموش باشد، چندضلعی یا خط به عنوان بخشی از نقشهٔ زمینه رفتار می‌کند.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe با ارتفاع دلخواه (به px):\n{{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "iframe با ارتفاع و عرض دلخواه (به px):\n{{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe:\n{{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "تصویر با عرض دلخواه (به px):\n{{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "تصویر:\n{{http://image.url.com}}",
    "Import data": "درون‌برد داده",
    "Import in a new layer": "درون‌برد در لایه‌ای جدید",
    "Imports all umap data, including layers and settings.": "همهٔ داده‌های umap ، شامل لایه‌ها و تنظیمات را وارد می‌کند.",
    "Include full screen link?": "شامل پیوند تمام‌صفحه باشد؟",
    "Inherit": "ارث‌بردن",
    "inherit": "به ارث می برند",
    "Interaction options": "گزینه‌های تعامل",
    "Invalid latitude or longitude": "طول یا عرض جغرافیایی نامعتبر",
    "Invalid umap data in {filename}": "داده‌های نامعتبر umap در {filename}",
    "Invalid umap data": "داده‌های نامعتبر umap",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-میانگین",
    "Keep current visible layers": "لایه‌های نمایان فعلی حفظ شود",
    "kilometers": "کیلومتر",
    "km": "km",
    "Label direction": "جهت برچسب",
    "Label key": "کلید برچسب",
    "Labels are clickable": "برچسب‌ها قابل‌کلیک هستند",
    "Latest feature": "آخرین عنصر",
    "Latitude": "عرض جغرافیایی",
    "Layer properties": "ویژگی‌های لایه",
    "Layer": "لایه",
    "Licence": "مجوز",
    "licence": "مجوز",
    "Limit bounds": "حدود نقشه",
    "Link to view the map": "پیوند به نمایش نقشه",
    "Link to…": "پیوند به…",
    "Link with text: [[http://example.com|text of the link]]": "پیوند با متن:\n[[http://example.com|text of the link]]",
    "Long credits": "یادکردهای بلند",
    "Longitude": "طول جغرافیایی",
    "Make main shape": "شکل اصلی را ایجاد کنید",
    "Manage layers": "مدیریت لایه‌ها",
    "Manual": "دستی",
    "Map background credits": "یادکردهای پس‌زمینهٔ نقشه",
    "Map has been attached to your account": "نقشه به حساب شما وصل شد",
    "Map has been saved!": "نقشه ذخیره شد!",
    "Map has been starred": "نقشه ستاره‌دار شد",
    "Map has been unstarred": "نقشه بی‌ستاره شد",
    "Map user content has been published under licence": "محتوای کاربر در نقشه، تحت این مجوز منتشر شده است: ",
    "Map's editors": "ویرایشگران نقشه",
    "Map's owner": "مالک نقشه",
    "max East": "کران شرقی",
    "max North": "کران شمالی",
    "max South": "کران جنوبی",
    "max West": "کران غربی",
    "max zoom": "بیشینهٔ بزرگنمایی",
    "Measure distances": "اندازه‌گیری مسافت‌ها",
    "Merge lines": "ادغام خطوط",
    "mi": "mi",
    "miles": "مایل",
    "min zoom": "کمینهٔ بزرگنمایی",
    "More controls": "دکمه‌های بیشتر",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "باید یک مقدار CSS معتبر باشد (مثال: DarkBlue یا #123456)",
    "name": "نام",
    "nautical miles": "مایل دریایی",
    "never": "هرگز",
    "new window": "پنجرهٔ جدید",
    "next": "بعدی",
    "NM": "NM",
    "No cache": "بدون حافظهٔ موقت",
    "No licence has been set": "مجوزی تنظیم نشده است",
    "No results": "بی‌نتیجه",
    "no": "نه",
    "No.": "شمارهٔ",
    "None": "هیچکدام",
    "Number of desired classes (default 5)": "تعداد دسته‌های موردنیاز (پیشفرض 5)",
    "On the bottom": "پایین",
    "On the left": "چپ",
    "On the right": "راست",
    "On the top": "بالا",
    "Only visible layers' data": "فقط دادهٔ لایه‌های نمایان",
    "opacity": "شفافیت",
    "Opacity": "شفافیت",
    "Open current feature on load": "عنصر فعلی هنگام بارشدن باز شود",
    "Open link in…": "بازکردن پیوند در…",
    "Open share & download panel": "پنجرهٔ همرسانی و بارگیری باز شود",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "این محدوده از نقشه را در یکی از ویرایشگرهای نقشه باز کنید تا داده‌های درست‌تری در اوپن‌استریت‌مپ ارائه کنید",
    "OpenStreetMap": "اوپن‌استریت‌مپ",
    "Optional intensity property for heatmap": "ویژگی اختیاری برای شدت در نقشهٔ حرارتی",
    "Optional. Same as color if not set.": "اختیاری. اگر تنظیم نشود با رنگ یکسان است.",
    "Optional.": "اختیاری.",
    "Override clustering radius (default 80)": "شعاع خوشه‌بندی (پیشفرض 80)",
    "Override heatmap radius (default 25)": "شعاع نقشهٔ حرارتی (پیشفرض 25)",
    "parent window": "پنجرهٔ والد",
    "Paste your data here": "داده‌های خود را اینجا بچسبانید",
    "Permalink": "پایاپیوند",
    "Permanent credits background": "پس‌زمینه برای یادکردهای دائمی",
    "Permanent credits": "یادکردهای دائمی",
    "Please be sure the licence is compliant with your use.": "لطفاً مطمئن شوید مجوز با استفادهٔ شما سازگار است.",
    "Please choose a format": "لطفاً یک قالب انتخاب کنید",
    "Please enter the name of the property": "لطفاً نام ویژگی را وارد کنید",
    "Please enter the new name of this property": "لطفاً نام جدید این ویژگی را وارد کنید",
    "Please save the map first": "لطفاً ابتدا نقشه را ذخیره کنید",
    "Popup (large)": "پنجرک بازشو (بزرگ)",
    "Popup content style": "سبک محتوای پنجرک بازشو",
    "Popup content template": "الگوی محتوای پنجرک بازشو",
    "Popup shape": "شکل پنجرک بازشو",
    "Popup": "پنجرک بازشو",
    "Powered by uMap": "نیروگرفته از uMap",
    "previous": "قبلی",
    "Problem in the response": "در پاسخگویی مشکلی رخ داد",
    "Properties imported:": "ویژگی‌های واردشده:",
    "Provide an URL here": "در اینجا یک نشانی اینترنتی ارائه دهید",
    "Proxy request": "پراکسی‌کردن درخواست",
    "Quantiles": "چندک‌ها",
    "Recent": "اخیر",
    "Remote data": "دادهٔ دوردست",
    "Remove shape from the multi": "حذف شکل از مولتی",
    "Replace layer content": "جایگزینی محتوای لایه",
    "Restore this version": "بازیابی این نسخه",
    "Save current edits": "ویرایش‌های جاری را ذخیره کنید",
    "Save map": "نقشه را ذخیره کنید",
    "Save this center and zoom": "ذخیره‌سازی این مرکزیت و بزرگنمایی",
    "Save this location as new feature": "این مکان را به عنوان عنصر جدید ذخیره کنید",
    "Save": "ذخیره",
    "Saved center and zoom": "مرکزیت و بزرگنمایی ذخیره‌شده",
    "Search location": "جستجوی مکان",
    "Search": "جستجو",
    "Secret edit link:": "پیوند محرمانه برای ویرایش:",
    "See full screen": "تمام‌صفحه ببینید",
    "See on OpenStreetMap": "در اوپن‌استریت‌مپ ببینید",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "روی خاموش تنظیم کنید تا این لایه در نمایش اسلایدی، مرورگر داده و ناوبری پنجرک بازشو نیاید...",
    "settings": "تنظیمات",
    "Shape properties": "ویژگی‌های شکل",
    "Share and download": "همرسانی و بارگیری",
    "Share this link to open a customized map view": "این پیوند را همرسانی کنید تا نقشه در یک نمای سفارشی باز شود",
    "Short credits": "یادکردهای کوتاه",
    "Short link": "پیوند کوتاه",
    "Show this layer in the caption": "این لایه در درباره نشان داده شود",
    "Show/hide layer": "آشکار/پنهان‌کردن لایه",
    "Side panel": "پنجرک کناری",
    "Simple link: [[http://example.com]]": "پیوند ساده:\n[[http://example.com]]",
    "Simplify": "ساده‌سازی",
    "Skipping unknown geometry.type: {type}": "نادیده‌گرفتن geometry.type ناشناخته: {type}",
    "Slideshow": "نمایش اسلاید",
    "Sort key": "کلید مرتب‌سازی",
    "Split line": "تقسیم خط",
    "Star this map": "ستاره‌دارکردن این نقشه",
    "Start a hole here": "از اینجا یک حفره ایجاد کنید",
    "Start slideshow": "شروع نمایش اسلاید",
    "Stop editing": "ویرایش را متوقف کنید",
    "Stop slideshow": "نمایش اسلاید را متوقف کنید",
    "Street": "خیابان",
    "stroke": "لبه",
    "Supported scheme": "طرح پشتیبانی‌شده",
    "Supported variables that will be dynamically replaced": "متغیرهای پشتیبانی‌شده که به صورت پویا جایگزین می‌شوند",
    "Symbol": "نماد",
    "Table": "جدول",
    "Text color for the cluster label": "رنگ متن برای برچسب خوشه",
    "Text formatting": "قالب‌بندی متن",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "نام ویژگی‌ای که به عنوان برچسب عنصر استفاده خواهد شد (مثال: name). همچنین می‌توانید نام هر ویژگی را درون آکولاد بگذارید تا ویژگی‌های بیشتری را، یا به صورت ترکیبی با متن ثابت به کار ببرید (مثال: \"&lcub;name&rcub; در &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "نام ویژگی برای استفاده به عنوان شناسهٔ یکتای عنصر.",
    "The zoom and center have been modified.": "مرکزیت و زوم تغییر کرد.",
    "TMS format": "قالب TMS",
    "To use if remote server doesn't allow cross domain (slower)": "برای استفاده در زمانی که سرور دوردست به درخواست‌های cross domain اجازه نمی‌دهد (کندتر)",
    "To zoom": "تا زوم",
    "Toggle edit mode (⇧+Click)": "حالت ویرایش (⇧+کلیک)",
    "Toggle edit mode": "حالت ویرایش",
    "Transfer shape to edited feature": "انتقال شکل به عنصر ویرایش‌شده",
    "Transform to lines": "تبدیل به خطوط",
    "Transform to polygon": "تبدیل به چندضلعی",
    "Type a place name or coordinates": "نام یک مکان یا یک مختصات بنویسید",
    "Type char or paste emoji": "نویسه‌ای بنویسید یا شکلکی بچسبانید",
    "Type of layer": "نوع لایه",
    "Unable to detect format of file {filename}": "قالب فایل {filename} تشخیص داده نشد",
    "Untitled layer": "لایهٔ بی‌عنوان",
    "Untitled map": "نقشهٔ بی‌عنوان",
    "Update permissions and editors": "روزآمدسازی مجوزها و ویرایشگران",
    "Update permissions": "روزآمدسازی مجوزها",
    "Update who can see and edit the map": "چه کسی می‌تواند نقشه را ببیند و ویرایش کند",
    "Url": "نشانی اینترنتی",
    "URL": "URL",
    "Use current bounds": "استفاده از کران‌های فعلی",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "هر کدام از ویژگی‌های عنصر را بین آکولاد قرار دهید و جانگهدار بسازید. مثال: &#123;name&#125;. این جانگهدارها به طور پویا به مقدار متناظرشان تغییر می‌کنند.",
    "User content credits": "یادکردهای محتوای کاربر",
    "User interface options": "گزینه‌های رابط کاربری",
    "User location": "مکان کاربر",
    "Verify remote URL": "صحت‌سنجی URL دوردست",
    "Versions": "نسخه‌ها",
    "View Fullscreen": "مشاهدهٔ تمام‌صفحه",
    "View": "نمایش",
    "Visibility: {status}": "نمایانی: {status}",
    "weight": "ضخامت",
    "Where do we go from here?": "از اینجا به کجا می‌رویم؟",
    "Whether to display or not polygons paths.": "اینکه آیا خط دور چندضلعی‌ها نمایش داده شود یا خیر.",
    "Whether to fill polygons with color.": "اینکه آیا چندضلعی‌ها با رنگ پر شوند یا خیر.",
    "Who can edit \"{layer}\"": "آن‌که می‌تواند «{layer}» را ویرایش کند",
    "Who can edit": "آن‌که می‌تواند ویرایش کند",
    "Who can view": "آن‌که می‌تواند ببیند",
    "width": "عرض",
    "Will be displayed in the bottom right corner of the map": "در گوشهٔ پایین سمت راست نقشه نمایش داده می‌شود",
    "Will be permanently visible in the bottom left corner of the map": "به‌طور دائمی در گوشهٔ پایین سمت چپ نقشه قابل‌مشاهده خواهد بود",
    "Will be visible in the caption of the map": "در زیرنویس نقشه قابل‌مشاهده خواهد بود",
    "yes": "بله",
    "Zoom in": "بزرگنمایی",
    "Zoom level for automatic zooms": "سطح زوم برای زوم‌های خودکار",
    "Zoom out": "کوچکنمایی",
    "Zoom to layer extent": "زوم به محدودهٔ لایه",
    "Zoom to the next": "تمرکز روی بعدی",
    "Zoom to the previous": "تمرکز روی قبلی",
    "Zoom to this feature": "تمرکز روی این عنصر",
    "Zoom to this place": "تمرکز روی این مکان",
    "{area}&#8239;acres": "{area} هکتار",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} خطا هنگام درون‌برد: {message}",
    "{delay} seconds": "{delay} ثانیه",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} مایل",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "ویرایش نام نقشه و درباره",
    "Map advanced properties": "ویژگی‌های پیشرفتهٔ نقشه",
    "Edit map details": "ویرایش جزئیات نقشه",
    "Back to browser": "بازگشت به مرورگر",
    "Toggle size": "تغییر اندازه",
    "Display the caption control": "نمایش دکمهٔ درباره",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "از",
    "Until": "تا",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "مثال: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "ویرایش در اوپن‌استریت‌مپ",
    "Cannot determine latitude and longitude columns.": "ستون‌های latitude و longitude تشخیص داده نشد.",
    "Back to layers": "بازگشت به لایه‌ها",
    "Filters": "پالایه‌ها",
    "Comma separated list of properties to use when filtering features by text input": "فهرستی از ویژگی‌ها (جداشده با کاما) که هنگام پالایش عنصرها با متن ورودی در آن‌ها جستجو می‌شود",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "فهرست جداشده با کاما از ویژگی‌ها برای استفاده در پالایه‌ها (مثال: mykey,otherkey). برای کنترل برچسب، آن را پس از یک | اضافه کنید (مثال: mykey|My Key,otherkey|Other Key). برای کنترل نوع خانهٔ ورودی، آن را پس از یک | دیگر اضافه کنید (مثال: mykey|My Key|checkbox,otherkey|Other Key|datetime). مقدارهای مجاز برای نوع خانهٔ ورودی عبارت‌اند از checkbox (پیشفرض)، radio،‏ number،‏ date و datetime.",
    "Search keys": "کلیدهای جستجو",
    "Filters keys": "کلیدهای پالایه‌ها",
    "Filter data": "پالایش داده",
    "Search map features…": "بین عنصرهای نقشه جستجو کنید...",
    "Reset all": "بازنشانی همه",
    "Open browser": "بازکردن مرورگر",
    "Open caption": "بازکردن درباره",
    "Your map has been created with an anonymous account!": "نقشهٔ شما با یک حساب کاربری گمنام ساخته شد!",
    "Real-time collaboration": "همکاری همزمان",
    "Cannot parse data": "داده تجزیه نشد",
    "Start typing...": "Start typing...",
    "No result": "بی‌نتیجه",
    "Data browser": "مرورگر داده",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "هنگامی که URL ارائه شود، uMap می‌تواند دادهٔ دوردست را در یک لایه کپی کند یا اینکه این URL را به عنوان منبع دوردست برای لایه اضافه کند. در حالت دوم، داده همواره از URL دریافت می‌شود و در نتیجه روزآمد خواهد بود، اما نمی‌توانید این داده را در uMap ویرایش کنید.",
    "Overpass supported expressions": "عبارت‌های پشتیبانی‌شدهٔ Overpass",
    "key (eg. building)": "key (مثال: building)",
    "!key (eg. !name)": "!key (مثال: !name)",
    "key=value (eg. building=yes)": "key=value (مثال: building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (مثال: building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (مثال: name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (مثال: name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "اطلاعات بیشتر دربارهٔ نحو Overpass",
    "For more complex needs, see": "برای نیازهای پیچیده‌تر، بنگرید به",
    "Choose data": "انتخاب داده",
    "Import helpers:": "یاری‌گران درون‌برد:",
    "Choose the format": "انتخاب قالب",
    "Choose the layer": "انتخاب لایه",
    "Layer name": "نام لایه",
    "Choose import mode": "انتخاب حالت درون‌برد",
    "Copy into the layer": "کپی درون لایه",
    "Link to the layer as remote data": "افزودن پیوند به لایه به‌عنوان دادهٔ دوردست",
    "Condition": "شرط",
    "key=value or key!=value": "key=value یا key!=value",
    "Are you sure you want to delete this rule?": "آیا این قاعده را حذف می‌کنید؟",
    "empty rule": "قاعدهٔ خالی",
    "Conditional style rules": "قواعد سبک‌دهی شرطی",
    "Add rule": "افزودن قاعده",
    "Browser: data": "مرورگر: داده",
    "Browser: layers": "مرورگر: لایه‌ها",
    "Browser: filters": "مرورگر: پالایه‌ها",
    "Enable real-time collaboration": "فعال‌سازی همکاری همزمان",
    "✅ Copied!": "✅ کپی شد!",
    "Choose a dataset": "یک مجموعه‌داده انتخاب کنید",
    "Choose this dataset": "انتخاب این مجموعه‌داده",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine:داده‌های موضوعی از اوپن‌استریت‌مپ",
    "Choose a theme": "یک موضوع انتخاب کنید",
    "Symplify all geometries to points": "همهٔ هندسه‌ها به نقطه ساده شوند",
    "Choose this data": "انتخاب این داده",
    "Search admin boundary": "جستجوی تقسیمات (admin boundary)",
    "Please choose a theme and a boundary first.": "لطفاً ابتدا یک موضوع و یک تقسیمات انتخاب کنید.",
    "Expression": "عبارت",
    "Geometry mode": "حالت شکل هندسی",
    "Only geometry centers": "فقط مرکز اشکال هندسی",
    "Search area": "محدودهٔ جستجو",
    "Type area name, or let empty to load data in current map view": "نام محدوده را بنویسید، یا خالی بگذارید تا برای نمای فعلی نقشه داده‌ها بار شود",
    "Data successfully imported!": "داده با موفقیت درون‌برد شد!",
    "Clear data": "حذف داده",
    "Remove layers": "حذف لایه‌ها",
    "Categorized": "دسته‌بندی‌شده",
    "Alphabetical": "الفبایی",
    "Category property": "ویژگی مورداستفاده برای دسته",
    "Color palette": "تخته رنگ",
    "Categories": "دسته‌ها",
    "Comma separated list of categories.": "فهرست جداشده با کاما از دسته‌ها.",
    "Categories mode": "حالت دسته‌ها",
    "Remove filter for this column": "حذف پالایهٔ این ستون",
    "Add filter for this column": "افزودن پالایه برای این ستون",
    "Rename this column": "تغییرنام این ستون",
    "Delete this column": "حذف این ستون",
    "Name “{name}” should not contain a dot.": "نام «{name}» نباید حاوی نقطه باشد.",
    "This name already exists: “{name}”": "این نام وجود دارد: «{name}»",
    "Delete selected rows": "حذف ردیف‌های انتخابی",
    "Found {count} rows. Are you sure you want to delete all?": "{count} ردیف پیدا شد. آیا همهٔ آن‌ها را حذف می‌کنید؟",
    "Expression is empty": "عبارت خالی است",
    "OK": "تأیید",
    "Cancel": "لغو",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "دایره‌های نسبی",
    "Property name to compute circles": "نام ویژگی برای محاسبهٔ دایره‌ها",
    "Min circle radius": "کمترین شعاع دایره",
    "Max circle radius": "بیشتری شعاع دایره",
    "Display the open browser control": "نمایش دکمهٔ بازکردن مرورگر",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "لطفاً برای ویرایش هندسه زوم کنید",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators"
}
L.registerLocale("fa_IR", locale)
L.setLocale("fa_IR")
