const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "單個 # 代表主標題",
    "## two hashes for second heading": "兩個 # 代表次標題",
    "### three hashes for third heading": "三個 # 代表第三標題",
    "**double star for bold**": "** 重複兩次星號代表粗體 **",
    "*single star for italic*": "*一個星代表斜體*",
    "--- for a horizontal rule": "--- 代表水平線",
    "1 day": "1日",
    "1 hour": "1小時",
    "5 min": "5分",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "用逗號來分隔一列列的虛線模式，例如：\"5, 10, 15\"。",
    "About": "關於",
    "Action not allowed :(": "未被允許的動作 :(",
    "Activate slideshow mode": "開啟幻燈片模式",
    "Add a layer": "新增圖層",
    "Add a line to the current multi": "新增線段",
    "Add a new property": "新增屬性",
    "Add a polygon to the current multi": "新增多邊形",
    "Add image URL": "新增圖片URL",
    "Add": "新增",
    "Advanced actions": "進階動作",
    "Advanced properties": "進階屬性",
    "All data and settings of the map": "地圖的所有資料與設定",
    "All properties are imported.": "所有物件皆已匯入",
    "Allow interactions": "允許互動",
    "Allow scroll wheel zoom?": "允許捲動放大？",
    "always": "經常",
    "Animated transitions": "動畫轉換",
    "Are you sure you want to cancel your changes?": "您確定要取消您所做的變更？",
    "Are you sure you want to clone this map and all its datalayers?": "您確定要複製此地圖及所有資料圖層？",
    "Are you sure you want to delete the feature?": "您確定要刪除該圖徵？",
    "Are you sure you want to delete this layer?": "你確定要刪除這個圖層嗎？",
    "Are you sure you want to delete this map?": "您確定要刪除此地圖？",
    "Are you sure you want to delete this property on all the features?": "您確定要刪除所有圖徵中的此項屬性？",
    "Are you sure you want to restore this version?": "您確定要回復此一版本嗎？",
    "Attach the map to my account": "將地圖加入到我的帳號",
    "attribution": "表彰",
    "Auto": "自動",
    "Automatic": "自動",
    "Autostart when map is loaded": "當讀取地圖時自動啟動",
    "Back to preview": "回到預纜",
    "Background overlay url": "背景套疊網址",
    "Ball": "球",
    "Bring feature to center": "置中圖徵",
    "Browse data": "瀏覽資料",
    "by": "由",
    "Cache proxied request": "快取代理請求",
    "Cancel edits": "取消編輯",
    "Caption": "標題",
    "Center map on your location": "將您的位置設為地圖中心",
    "Change map background": "更改地圖背景",
    "Change tilelayers": "改變地圖磚圖層",
    "Change": "變動",
    "Choose the data format": "選擇資料格式",
    "Choropleth breakpoints": "等時線圖點",
    "Choropleth classes": "等時線圖類型",
    "Choropleth color palette": "等時線圖色彩盤",
    "Choropleth mode": "等時線圖模式",
    "Choropleth property value": "等時線圖屬性數值",
    "Choropleth": "等時線圖",
    "Circle": "圓圈",
    "clear": "清除",
    "Click last point to finish shape": "點下最後一點後完成外形",
    "Click to add a marker": "點選以新增標記",
    "Click to continue drawing": "點擊以繼續繪製",
    "Click to edit": "點擊開始編輯",
    "Click to start drawing a line": "點擊以開始繪製直線",
    "Click to start drawing a polygon": "點選開始繪製多邊形",
    "Clone of {name}": "複製 {name}",
    "Clone this feature": "複製此項目",
    "Clone this map": "複製此地圖",
    "Clone": "複製",
    "Close": "關閉",
    "Clustered": "群集後",
    "Clustering radius": "群集分析半徑",
    "collapsed": "收起",
    "color": "色彩",
    "Comma separated list of numbers, including min and max values.": "用逗號分隔數字，包括最小與最大值。",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "用逗號分隔屬性清單來排序圖徵。要保存排序，在槊面加上減號 (-1)，例如 mykey,-otherkey。",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "使用逗號、定位鍵或是分號分隔的地理數據。預設座標系為 SRS WGS84。只會匯入地理座標點。匯入時抓取 «lat» 與 «lon» 開頭的欄位資料，不分大小寫。其他欄位則歸入屬性資料。",
    "Congratulations, your map has been created!": "恭喜您的地圖已經新增完成",
    "Continue line": "連續線段",
    "Coordinates": "座標",
    "copy": "複製",
    "Credits": "工作人員名單",
    "Current map view": "目前地圖檢視",
    "Current view instead of default map view?": "將目前視點設為預設視點？",
    "Custom background": "自訂背景",
    "Custom overlay": "客制套疊",
    "dash array": "虛線排列",
    "Data is browsable": "資料是可檢視的",
    "Datalayers": "資料圖層",
    "Default interaction options": "預設互動選項",
    "Default properties": "預設屬性",
    "Default shape properties": "預設形狀屬性",
    "Default view": "預設檢視",
    "Default zoom level": "預設縮放等級",
    "Default": "預設",
    "Default: name": "預設: name",
    "Define link to open in a new window on polygon click.": "指定點多邊形連結時開新視窗。",
    "define": "定義",
    "Delay between two transitions when in play mode": "播放模式下兩個轉換間會延遲",
    "Delete layer": "刪除圖層",
    "Delete this feature": "刪除此圖徵",
    "Delete this shape": "刪除外形",
    "Delete this vertex (Alt+Click)": "刪除頂點 (Alt+Click)",
    "Delete": "刪除",
    "description": "描述",
    "Direct link": "直接連結",
    "Directions from here": "從此處開始導航",
    "Display label": "顯示標籤",
    "Display measure": "Display measure",
    "display name": "顯示名稱",
    "Display on load": "載入時顯示",
    "Display the control to open OpenStreetMap editor": "顯示開啟開放街圖編輯器的按鍵",
    "Display the embed control": "顯示嵌入鍵",
    "Display the fullscreen control": "顯示全螢幕鍵",
    "Display the locate control": "顯示定位鍵",
    "Display the measure control": "顯示比例尺鍵",
    "Display the search control": "顯示搜尋鍵",
    "Display the star map button": "顯示星號地圖按鈕",
    "Display the tile layers control": "顯示圖層鍵",
    "Display the zoom control": "顯示縮放鍵",
    "Do you want to display a caption bar?": "您是否要顯示標題列？",
    "Do you want to display a minimap?": "您想要顯示小型地圖嗎？",
    "Do you want to display a panel on load?": "您是否要顯示",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "您是否要顯示註腳彈出？",
    "Do you want to display the scale control?": "您是否要顯示尺標？",
    "Do you want to display the «more» control?": "您是否要顯示 《更多》？",
    "Download": "下載",
    "Drag to reorder": "拖拽以排序",
    "Draw a marker": "描繪標記",
    "Draw a polygon": "描繪多邊形",
    "Draw a polyline": "描繪折線",
    "Drawing": "繪製",
    "Drop": "中止",
    "Dynamic properties": "動態屬性",
    "Dynamic": "動態",
    "Edit feature's layer": "編輯圖徵的圖層",
    "Edit properties in a table": "在表格中編輯屬性",
    "Edit the title of the map": "編輯地圖標題",
    "Edit this feature": "編輯此圖徵",
    "Edit": "編輯",
    "Embed and link options": "嵌入與連結選項",
    "Embed the map": "嵌入地圖",
    "Emoji & Character": "表情符號和字元",
    "Empty": "空白",
    "Equidistant": "等距",
    "Error in the overlay URL": "套疊網址錯誤",
    "Error in the tilelayer URL": "地圖磚圖層 URL 錯誤",
    "Exit Fullscreen": "結束全螢幕模式",
    "expanded": "展開",
    "Extract shape to separate feature": "由外形分離出圖徵",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "圖徵屬性",
    "Fetch data each time map view changes.": "每次地圖檢視改變時截取資料。",
    "fill color": "填入色彩",
    "fill opacity": "填入不透明度",
    "fill": "填入",
    "Fit all data": "檢視所有資料",
    "Format": "格式",
    "From zoom": "由縮放大小",
    "full backup": " 完全備份",
    "Generic": "一般常用符號",
    "GeoRSS (only link)": "GeoRSS (只有連結)",
    "GeoRSS (title + image)": "GeoRSS (標題與圖片)",
    "Go to \"{coords}\"": "去  \"{coords}\"",
    "Go to the homepage": "前往首頁",
    "Go to «{feature}»": "轉至 «{feature}»",
    "Heatmap intensity property": "熱點圖強度屬性",
    "Heatmap radius": "熱點圖半徑",
    "Heatmap": "熱點圖",
    "height": "高度",
    "Help": "幫助",
    "hidden": "隱藏",
    "Hide controls": "隱藏控制列",
    "Home": "首頁",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "在不同縮放比例下，多邊形的精簡程度 (精簡越多有較好的效率、多邊形越平滑，精簡越少圖形越精確)",
    "icon opacity": "圖示透明度",
    "Icon shape": "圖示圖形",
    "Icon symbol": "圖示標誌",
    "If false, the polygon or line will act as a part of the underlying map.": "選擇「否」時，多邊形物件會被當成為底圖的一部分。",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "自訂 iframe 高度 (以 px 為單位): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "自訂 iframe 高度和寬度 (以 px 為單位)：{{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "自訂圖像的寬度（像素）: {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "圖像: {{http://image.url.com}}",
    "Import data": "匯入資料",
    "Import in a new layer": "匯入至新圖層",
    "Imports all umap data, including layers and settings.": "匯入所有 umap 資料，包含圖層與設定。",
    "Include full screen link?": "是否包含全螢幕的連結？",
    "Inherit": "繼承",
    "inherit": "繼承",
    "Interaction options": "互動選項",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "無效的 umap 資料於檔案 {filename}",
    "Invalid umap data": "無效的 umap 資料",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K平均",
    "Keep current visible layers": "保留目前可見圖層",
    "kilometers": "公里",
    "km": "km",
    "Label direction": "標籤方向",
    "Label key": "標籤鍵",
    "Labels are clickable": "標籤可點擊",
    "Latest feature": "最新功能",
    "Latitude": "緯度",
    "Layer properties": "圖層屬性",
    "Layer": "圖層",
    "Licence": "授權",
    "licence": "授權",
    "Limit bounds": "限制範圍",
    "Link to view the map": "檢視地圖的連結",
    "Link to…": "連結至...",
    "Link with text: [[http://example.com|text of the link]]": "帶有超連結的文字: [[http://example.com|text of the link]]",
    "Long credits": "詳細工作人員名單",
    "Longitude": "經度",
    "Make main shape": "設為主要外形",
    "Manage layers": "管理圖層",
    "Manual": "手動",
    "Map background credits": "地圖背景取自",
    "Map has been attached to your account": "地圖已經加入至你的帳號",
    "Map has been saved!": "地圖儲存已完成",
    "Map has been starred": "地圖已經打星號",
    "Map has been unstarred": "已經取消地圖打星號",
    "Map user content has been published under licence": "使用者地圖資訊內容已經以以下授權發佈",
    "Map's editors": "地圖編輯者",
    "Map's owner": "地圖擁有者",
    "max East": "最東方",
    "max North": "最北方",
    "max South": "最南方",
    "max West": "最西方",
    "max zoom": "放到最大",
    "Measure distances": "測量距離",
    "Merge lines": "合併線段",
    "mi": "mi",
    "miles": "英里",
    "min zoom": "縮至最小",
    "More controls": "更多控制項目",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "必須是有效的 CSS 值 (例如：DarkBlue 或是 #123456)",
    "name": "名稱",
    "nautical miles": "海里",
    "never": "永不",
    "new window": "新視窗",
    "next": "下一個",
    "NM": "NM",
    "No cache": "沒有快取内容",
    "No licence has been set": "尚未設定授權條例",
    "No results": "沒有結果",
    "no": "否",
    "No.": "無。",
    "None": "以上皆非",
    "Number of desired classes (default 5)": "偏好的類別數量 (預設為 5)",
    "On the bottom": "在底部",
    "On the left": "在左側",
    "On the right": "在右側",
    "On the top": "在頂部",
    "Only visible layers' data": "只有可見圖層的資料",
    "opacity": "不透明度",
    "Opacity": "不透明度",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "開啓連結於...",
    "Open share & download panel": "開啟分享與下載面板",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "在地圖編輯器中打開此地圖，提供更多準確資料給 OpenStreetMap",
    "OpenStreetMap": "開放街圖",
    "Optional intensity property for heatmap": "選用的熱圖 heatmap 強度屬性",
    "Optional. Same as color if not set.": "可選，若您未選取顏色，則採用預設值",
    "Optional.": "可選",
    "Override clustering radius (default 80)": "覆蓋群集分析半徑 (預設80)",
    "Override heatmap radius (default 25)": "覆蓋指定熱圖 heatmap 半徑 (預設 25)",
    "parent window": "父視窗",
    "Paste your data here": "請在此貼上你的資料",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "請再次確認所選的授權方式符合您的需求",
    "Please choose a format": "請選擇地圖格式",
    "Please enter the name of the property": "請輸入物件名稱",
    "Please enter the new name of this property": "請輸入新的物件名稱",
    "Please save the map first": "請先儲存地圖",
    "Popup (large)": "彈出式視窗 (大)",
    "Popup content style": "彈出式視窗内容樣式",
    "Popup content template": "彈出內文範本",
    "Popup shape": "彈出式視窗形狀",
    "Popup": "彈出式視窗",
    "Powered by uMap": "由 uMap 驅動",
    "previous": "前一個",
    "Problem in the response": "回應的問題",
    "Properties imported:": "屬性匯入完成",
    "Provide an URL here": "提供 URL網址",
    "Proxy request": "使用代理請求",
    "Quantiles": "數量",
    "Recent": "目前",
    "Remote data": "遠端資料",
    "Remove shape from the multi": "移除外形",
    "Replace layer content": "取代圖層內容",
    "Restore this version": "回復此版本",
    "Save current edits": "儲存近期的變更",
    "Save map": "儲存地圖",
    "Save this center and zoom": "保存地圖中心點位置與縮放大小",
    "Save this location as new feature": "將地點存為新的圖徵",
    "Save": "儲存",
    "Saved center and zoom": "儲存地圖中心點位置與縮放大小",
    "Search location": "搜尋地點",
    "Search": "搜尋",
    "Secret edit link:": "祕密編輯連結：",
    "See full screen": "觀看全螢幕",
    "See on OpenStreetMap": "在開放街圖檢視",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "設定為假時，在幻燈片時、資料檢視器和彈出式導航中可將此圖層隱藏...",
    "settings": "設定",
    "Shape properties": "形狀屬性",
    "Share and download": "分享與下載",
    "Share this link to open a customized map view": "分享這連結來開啟客製化地圖檢視",
    "Short credits": "簡短工作人員名單",
    "Short link": "短網址",
    "Show this layer in the caption": "在標題顯示此圖層",
    "Show/hide layer": "顯示/隱藏圖層",
    "Side panel": "側邊框",
    "Simple link: [[http://example.com]]": "簡單連結: [[http://example.com]]",
    "Simplify": "簡化",
    "Skipping unknown geometry.type: {type}": "略過不明的 geometry.type: {type}",
    "Slideshow": "投影片",
    "Sort key": "排序鍵",
    "Split line": "分隔線",
    "Star this map": "地圖打星號",
    "Start a hole here": "開始一個凹洞",
    "Start slideshow": "開啟投影片",
    "Stop editing": "停止編輯",
    "Stop slideshow": "中止投影片",
    "Street": "道路",
    "stroke": "筆畫粗細",
    "Supported scheme": "支援的模板",
    "Supported variables that will be dynamically replaced": "支援的物件將直接動態轉換",
    "Symbol": "符號",
    "Table": "表格",
    "Text color for the cluster label": "叢集標籤的文字顏色",
    "Text formatting": "文字格式",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "場所的名稱會用做圖徵標籤 (例如：\"nom\")。你也可以使用場地內的括號一個或多個靜態內容 (例如 \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "已變動完成置中及切換功能。",
    "TMS format": "TMS 格式",
    "To use if remote server doesn't allow cross domain (slower)": "如果遠端伺服器不允許跨網域存取時使用 (效率較差)",
    "To zoom": "至縮放大小",
    "Toggle edit mode (⇧+Click)": "切換編輯模式 (⇧+Click)",
    "Toggle edit mode": "切換編輯模式",
    "Transfer shape to edited feature": "將外形加到編輯中的特徵",
    "Transform to lines": "轉換為線條",
    "Transform to polygon": "轉換為多邊形",
    "Type a place name or coordinates": "輸入地點名稱或是座標",
    "Type char or paste emoji": "輸入字元或是貼上顏文字",
    "Type of layer": "圖層類型",
    "Unable to detect format of file {filename}": "無法偵測 {filename} 的檔案格式",
    "Untitled layer": "未命名圖層",
    "Untitled map": "未命名地圖",
    "Update permissions and editors": "更新可編輯權限及編輯者",
    "Update permissions": "更新權限",
    "Update who can see and edit the map": "更新誰能檢視與編輯地圖的權限",
    "Url": "網址",
    "URL": "URL",
    "Use current bounds": "使用目前範圍",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "以圖徵的屬性加上括弧作為標記，例如 &#123;name&#125;，這樣子就可以動態被取代成對應的數值。",
    "User content credits": "使用者內容清單",
    "User interface options": "使用者界面選項",
    "User location": "使用者位置",
    "Verify remote URL": "驗證遠端網址",
    "Versions": "版本",
    "View Fullscreen": "以全屏幕模式顯示",
    "View": "檢視",
    "Visibility: {status}": "是否公開：{status}",
    "weight": "寬度",
    "Where do we go from here?": "我們要去哪裡？",
    "Whether to display or not polygons paths.": "是否顯示多邊形的路徑。",
    "Whether to fill polygons with color.": "是否將多邊形填入色彩。",
    "Who can edit \"{layer}\"": "誰有權限編輯 \"{layer}\"",
    "Who can edit": "誰可以編輯",
    "Who can view": "誰可以檢視",
    "width": "寬度",
    "Will be displayed in the bottom right corner of the map": "將會顯示在地圖的右下角",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "標題將出現在地圖上",
    "yes": "是",
    "Zoom in": "放大",
    "Zoom level for automatic zooms": "自動縮放的比例大小",
    "Zoom out": "縮小",
    "Zoom to layer extent": "切換至圖層範圍",
    "Zoom to the next": "切換至下一頁",
    "Zoom to the previous": "切換至前一頁",
    "Zoom to this feature": "縮放至圖徵範圍",
    "Zoom to this place": "縮放到這個地方",
    "{area}&#8239;acres": "{area} 英畝",
    "{area}&#8239;ha": "{area} 公頃",
    "{area}&#8239;m&sup2;": "{area} 平方公尺",
    "{area}&#8239;mi&sup2;": "{area} 平方英哩",
    "{area}&#8239;yd&sup2;": "{area} 平方英呎",
    "{count} errors during import: {message}": "於匯入時發生 {count} 項錯誤: {message}",
    "{delay} seconds": "{delay} 秒",
    "{distance}&#8239;km": "{area} 公里",
    "{distance}&#8239;m": "{distance} 公尺",
    "{distance}&#8239;miles": "{distance} 英哩",
    "{distance}&#8239;NM": "{distance} 海浬",
    "{distance}&#8239;yd": "{distance} 英呎",
    "Edit map name and caption": "編輯地圖名稱與標題",
    "Map advanced properties": "地圖進階屬性",
    "Edit map details": "編輯地圖詳情",
    "Back to browser": "回到瀏覽器",
    "Toggle size": "縮放大小",
    "Display the caption control": "顯示標題控制",
    "<empty value>": "<empty value>",
    "Min": "最小",
    "Max": "最大",
    "From": "從",
    "Until": "至",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "例如：key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "在開放街圖編輯",
    "Cannot determine latitude and longitude columns.": "無法決定緯度與經度欄。",
    "Back to layers": "回到圖層",
    "Filters": "篩選",
    "Comma separated list of properties to use when filtering features by text input": "逗號分隔清單的屬性，用在文字輸入時篩選用途",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "為了用在篩選的逗號分隔清單屬性 (例如：mykey,otherkey)。要控制標籤，在後面加上 | (例如：mykey|My Key,otherkey|Other Key)。要控制輸入欄位類型，則在後面加另一個 | (例如：mykey|My Key|checkbox,otherkey|Other Key|datetime)。允許輸入欄位類型的值有核取方塊 (預設)、頻率、數字、日期以及時間日期。",
    "Search keys": "搜尋鍵",
    "Filters keys": "篩選鍵",
    "Filter data": "篩選資料",
    "Search map features…": "搜尋地圖圖徵",
    "Reset all": "重設所有",
    "Open browser": "開啟瀏覽器",
    "Open caption": "開啟標題",
    "Your map has been created with an anonymous account!": "你用暱名方式創建地圖！",
    "Real-time collaboration": "即時合作模式",
    "Cannot parse data": "無法解析資料",
    "Start typing...": "開始輸入...",
    "No result": "沒有結果",
    "Data browser": "資料瀏覽器",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "當你提供 URL，uMap 能夠複製遠端資料成為圖層，或是用這一 URL 來當作遠端來源的圖層。在這一例子，資料總能從 URL 取得，能夠維持即時狀態，但仍不能直接在 uMap 裡編輯。",
    "Overpass supported expressions": "Overpass 支援的表示式",
    "key (eg. building)": "key (例如 building)",
    "!key (eg. !name)": "!key (例如 !name)",
    "key=value (eg. building=yes)": "key=value (例如 building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (例如 building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (例如 name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (例如 name=\"Paris|berlin\")",
    "More info about Overpass syntax": "更多 Overpass 語法資訊",
    "For more complex needs, see": "而更多複雜的需求，請見",
    "Choose data": "選擇日期",
    "Import helpers:": "匯入幫手：",
    "Choose the format": "選擇格式",
    "Choose the layer": "選擇圖層",
    "Layer name": "圖層名稱",
    "Choose import mode": "選擇匯入模式",
    "Copy into the layer": "複製到圖層",
    "Link to the layer as remote data": "以遠端資料型式連結到圖層",
    "Condition": "條件",
    "key=value or key!=value": "key=value 或是 key!=value",
    "Are you sure you want to delete this rule?": "你確定要刪除這一規則？",
    "empty rule": "空白規則",
    "Conditional style rules": "條件樣式規則",
    "Add rule": "增加規則",
    "Browser: data": "瀏覽：資料",
    "Browser: layers": "瀏覽：圖層",
    "Browser: filters": "瀏覽：篩選",
    "Enable real-time collaboration": "啟用即時合作模式",
    "✅ Copied!": "✅ 已複製！",
    "Choose a dataset": "選擇資料集",
    "Choose this dataset": "選擇這個資料集",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine：從開放街圖來的主題資料",
    "Choose a theme": "選擇主題",
    "Symplify all geometries to points": "簡化所有地理範圍的節點",
    "Choose this data": "選擇這個資料",
    "Search admin boundary": "搜尋行政邊界",
    "Please choose a theme and a boundary first.": "請先選擇主題與邊界。",
    "Expression": "表示式",
    "Geometry mode": "地理範圍模式",
    "Only geometry centers": "只有地理範圍中心",
    "Search area": "搜尋區域",
    "Type area name, or let empty to load data in current map view": "輸入區域名稱，或是保持空白載入目前地圖檢視",
    "Data successfully imported!": "成功匯入資料",
    "Clear data": "清除資料",
    "Remove layers": "移除圖層",
    "Categorized": "分類化",
    "Alphabetical": "字母排列",
    "Category property": "分類屬性",
    "Color palette": "色盤",
    "Categories": "分類",
    "Comma separated list of categories.": "逗號分隔清單的分類。",
    "Categories mode": "分類模式",
    "Remove filter for this column": "移除這一欄的篩選",
    "Add filter for this column": "增加這一欄的篩選",
    "Rename this column": "重新命名這一欄",
    "Delete this column": "刪除這一欄",
    "Name “{name}” should not contain a dot.": "名稱 {name}\" 內不應該有點。",
    "This name already exists: “{name}”": "這個名稱已經存在了：\"{name}\"",
    "Delete selected rows": "刪除選擇的行",
    "Found {count} rows. Are you sure you want to delete all?": "找到 {count} 行。你確定要刪除全部嗎？",
    "Expression is empty": "表示式為空白",
    "OK": "確認",
    "Cancel": "取消",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators"
}
L.registerLocale("zh_TW", locale)
L.setLocale("zh_TW")
